@@ -8,35 +8,41 @@ template customization, OpenAPI-specific options, and general options.
 from __future__ import annotations
 
 import json
-import locale
 from argparse import ArgumentParser, ArgumentTypeError, BooleanOptionalAction, Namespace, RawDescriptionHelpFormatter
 from operator import attrgetter
 from pathlib import Path
 from typing import TYPE_CHECKING, cast
 
-from datamodel_code_generator import (
+from datamodel_code_generator.enums import (
     DEFAULT_SHARED_MODULE_NAME,
     AllExportsCollisionStrategy,
     AllExportsScope,
+    AllOfClassHierarchy,
     AllOfMergeMode,
+    ClassNameAffixScope,
+    CollapseRootModelsNameStrategy,
     DataclassArguments,
     DataModelType,
+    FieldTypeCollisionStrategy,
     InputFileType,
+    InputModelRefStrategy,
     ModuleSplitMode,
+    NamingStrategy,
     OpenAPIScope,
     ReadOnlyWriteOnlyModelType,
     ReuseScope,
+    StrictTypes,
+    TargetPydanticVersion,
+    UnionMode,
 )
-from datamodel_code_generator.format import DatetimeClassType, Formatter, PythonVersion
-from datamodel_code_generator.model.pydantic_v2 import UnionMode
+from datamodel_code_generator.format import DateClassType, DatetimeClassType, Formatter, PythonVersion
 from datamodel_code_generator.parser import LiteralType
-from datamodel_code_generator.types import StrictTypes
 
 if TYPE_CHECKING:
     from argparse import Action
     from collections.abc import Iterable
 
-DEFAULT_ENCODING = locale.getpreferredencoding()
+DEFAULT_ENCODING = "utf-8"
 
 namespace = Namespace(no_color=False)
 
@@ -83,8 +89,8 @@ class SortingHelpFormatter(RawDescriptionHelpFormatter):
 arg_parser = ArgumentParser(
     usage="\n  datamodel-codegen [options]",
     description="Generate Python data models from schema definitions or structured data\n\n"
-    "For detailed usage, see: https://koxudaxi.github.io/datamodel-code-generator",
-    epilog="Documentation: https://koxudaxi.github.io/datamodel-code-generator\n"
+    "For detailed usage, see: https://datamodel-code-generator.koxudaxi.dev",
+    epilog="Documentation: https://datamodel-code-generator.koxudaxi.dev\n"
     "GitHub: https://github.com/koxudaxi/datamodel-code-generator",
     formatter_class=SortingHelpFormatter,
     add_help=False,
@@ -97,6 +103,7 @@ model_options = arg_parser.add_argument_group("Model customization")
 extra_fields_model_options = model_options.add_mutually_exclusive_group()
 template_options = arg_parser.add_argument_group("Template customization")
 openapi_options = arg_parser.add_argument_group("OpenAPI-only options")
+graphql_options = arg_parser.add_argument_group("GraphQL-only options")
 general_options = arg_parser.add_argument_group("General options")
 
 # ======================================================================================
@@ -120,13 +127,23 @@ base_options.add_argument(
     action="store_true",
     default=None,
 )
+base_options.add_argument(
+    "--http-timeout",
+    type=float,
+    default=None,
+    help="Timeout in seconds for HTTP requests to remote hosts (default: 30)",
+)
 base_options.add_argument(
     "--input",
     help="Input file/directory (default: stdin)",
 )
 base_options.add_argument(
     "--input-file-type",
-    help="Input file type (default: auto)",
+    help=(
+        "Input file type (default: auto). "
+        "Use 'jsonschema', 'openapi', or 'graphql' for schema definitions. "
+        "Use 'json', 'yaml', or 'csv' for raw sample data to infer a schema automatically."
+    ),
     choices=[i.value for i in InputFileType],
 )
 base_options.add_argument(
@@ -142,6 +159,26 @@ base_options.add_argument(
     "--url",
     help="Input file URL. `--input` is ignored when `--url` is used",
 )
+base_options.add_argument(
+    "--input-model",
+    action="append",
+    help="Python import path to a Pydantic v2 model or schema dict "
+    "(e.g., 'mypackage.module:ClassName' or 'mypackage.schemas:SCHEMA_DICT'). "
+    "Can be specified multiple times for related models with inheritance. "
+    "For dict input, --input-file-type is required. "
+    "Cannot be used with --input or --url.",
+    metavar="MODULE:NAME",
+)
+base_options.add_argument(
+    "--input-model-ref-strategy",
+    help="Strategy for referenced types in --input-model. "
+    "'regenerate-all': Regenerate all types. "
+    "'reuse-foreign': Reuse types from different families (Enum, etc.), regenerate same-family. "
+    "'reuse-all': Reuse all referenced types via import. "
+    "If not specified, defaults to regenerate-all behavior.",
+    choices=[s.value for s in InputModelRefStrategy],
+    default=None,
+)
 
 # ======================================================================================
 # Customization options for generated models
@@ -163,12 +200,50 @@ model_options.add_argument(
     help="Set class name of root model",
     default=None,
 )
+model_options.add_argument(
+    "--class-name-prefix",
+    help="Prefix to add to generated class names (e.g., 'Api' produces 'ApiUser'). "
+    "Does not apply to root model when --class-name is specified.",
+    type=str,
+    default=None,
+)
+model_options.add_argument(
+    "--class-name-suffix",
+    help="Suffix to add to generated class names (e.g., 'Schema' produces 'UserSchema'). "
+    "Does not apply to root model when --class-name is specified.",
+    type=str,
+    default=None,
+)
+model_options.add_argument(
+    "--class-name-affix-scope",
+    help="Scope for applying --class-name-prefix/--class-name-suffix. "
+    "'all': Apply to all classes including enums (default). "
+    "'models': Apply only to model classes. "
+    "'enums': Apply only to enum classes.",
+    choices=[s.value for s in ClassNameAffixScope],
+    default=None,
+)
 model_options.add_argument(
     "--collapse-root-models",
     action="store_true",
     default=None,
     help="Models generated with a root-type field will be merged into the models using that root-type model",
 )
+model_options.add_argument(
+    "--collapse-root-models-name-strategy",
+    help="Strategy for naming when collapsing root models that reference other models. "
+    "'child': Keep inner model's name (default). 'parent': Use wrapper's name for inner model. "
+    "Requires --collapse-root-models to be set.",
+    choices=[s.value for s in CollapseRootModelsNameStrategy],
+    default=None,
+)
+model_options.add_argument(
+    "--collapse-reuse-models",
+    action="store_true",
+    default=None,
+    help="When used with --reuse-model, collapse duplicate models by replacing references instead of creating "
+    "empty inheritance subclasses. This eliminates 'class Foo(Bar): pass' patterns",
+)
 model_options.add_argument(
     "--skip-root-model",
     action="store_true",
@@ -263,9 +338,25 @@ model_options.add_argument(
     help="target python version",
     choices=[v.value for v in PythonVersion],
 )
+model_options.add_argument(
+    "--target-pydantic-version",
+    help="Target Pydantic version for generated code. "
+    "'2': Pydantic 2.0+ compatible (default, uses populate_by_name). "
+    "'2.11': Pydantic 2.11+ (uses validate_by_name).",
+    choices=[v.value for v in TargetPydanticVersion],
+    default=None,
+)
 model_options.add_argument(
     "--treat-dot-as-module",
-    help="treat dotted module names as modules",
+    help="Treat dotted schema names as module paths, creating nested directory structures (e.g., 'foo.bar.Model' "
+    "becomes 'foo/bar.py'). Use --no-treat-dot-as-module to keep dots in names as underscores for single-file output.",
+    action=BooleanOptionalAction,
+    default=None,
+)
+model_options.add_argument(
+    "--use-generic-base-class",
+    help="Generate a shared base class with model configuration (e.g., extra='forbid') "
+    "instead of repeating the configuration in each model. Keeps code DRY.",
     action="store_true",
     default=None,
 )
@@ -287,6 +378,14 @@ model_options.add_argument(
     action="store_true",
     default=None,
 )
+model_options.add_argument(
+    "--use-standard-primitive-types",
+    help="Use Python standard library types for string formats (UUID, IPv4Address, etc.) "
+    "instead of str. Affects dataclass, msgspec, TypedDict output. "
+    "Pydantic already uses these types by default.",
+    action="store_true",
+    default=None,
+)
 model_options.add_argument(
     "--use-exact-imports",
     help='import exact types instead of modules, for example: "from .foo import Bar" instead of '
@@ -296,17 +395,47 @@ model_options.add_argument(
 )
 model_options.add_argument(
     "--output-datetime-class",
-    help="Choose Datetime class between AwareDatetime, NaiveDatetime or datetime. "
+    help="Choose Datetime class between AwareDatetime, NaiveDatetime, PastDatetime, FutureDatetime or datetime. "
     "Each output model has its default mapping (for example pydantic: datetime, dataclass: str, ...)",
     choices=[i.value for i in DatetimeClassType],
     default=None,
 )
+model_options.add_argument(
+    "--output-date-class",
+    help="Choose Date class between PastDate, FutureDate or date. (Pydantic v2 only) "
+    "Each output model has its default mapping.",
+    choices=[i.value for i in DateClassType],
+    default=None,
+)
 model_options.add_argument(
     "--parent-scoped-naming",
-    help="Set name of models defined inline from the parent model",
+    help="[Deprecated: use --naming-strategy parent-prefixed] Set name of models defined inline from the parent model",
     action="store_true",
     default=None,
 )
+model_options.add_argument(
+    "--naming-strategy",
+    help="Strategy for generating unique model names when duplicates occur. "
+    "'numbered' (default): Append numeric suffix (Address, Address1, Address2). "
+    "Simple but names don't indicate context. "
+    "'parent-prefixed': Prefix with parent model name using underscore "
+    "(Company_Address, Company_Employee_Address for nested). Names show hierarchy. "
+    "'full-path': Similar to parent-prefixed but joins with CamelCase "
+    "(CompanyAddress, CompanyEmployeeAddress). More readable for deep nesting. "
+    "'primary-first': Keep clean names for primary definitions (in /definitions/ or "
+    "/components/schemas/), only add suffix to inline/nested duplicates.",
+    choices=[s.value for s in NamingStrategy],
+    default=None,
+)
+model_options.add_argument(
+    "--duplicate-name-suffix",
+    help="JSON mapping of type to suffix for resolving duplicate name conflicts. "
+    'Example: \'{"model": "Schema"}\' changes Address1 to AddressSchema. '
+    "Keys: 'model' (for classes), 'enum' (for enums), 'default' (fallback). "
+    "When not specified, uses numeric suffix (Address1, Address2).",
+    type=str,
+    default=None,
+)
 model_options.add_argument(
     "--all-exports-scope",
     help="Generate __all__ in __init__.py with re-exports. "
@@ -339,6 +468,14 @@ typing_options.add_argument(
     help="Base Class (default: pydantic.BaseModel)",
     type=str,
 )
+typing_options.add_argument(
+    "--base-class-map",
+    help="Model-specific base class mapping (JSON). "
+    'Example: \'{"MyModel": "custom.BaseA", "OtherModel": "custom.BaseB"}\'. '
+    "Priority: base-class-map > customBasePath (in schema) > base-class.",
+    type=json.loads,
+    default=None,
+)
 typing_options.add_argument(
     "--enum-field-as-literal",
     help="Parse enum field as literal. "
@@ -348,6 +485,15 @@ typing_options.add_argument(
     choices=[lt.value for lt in LiteralType],
     default=None,
 )
+typing_options.add_argument(
+    "--enum-field-as-literal-map",
+    help="Per-field override for enum/literal generation. "
+    "Format: JSON object mapping field names to 'literal' or 'enum'. "
+    'Example: \'{"status": "literal", "priority": "enum"}\'. '
+    "Overrides --enum-field-as-literal for matched fields.",
+    type=json.loads,
+    default=None,
+)
 typing_options.add_argument(
     "--ignore-enum-constraints",
     help="Ignore enum constraints and use the base type (e.g., str, int) instead of generating Enum classes",
@@ -446,6 +592,12 @@ typing_options.add_argument(
     action="store_true",
     default=None,
 )
+typing_options.add_argument(
+    "--use-tuple-for-fixed-items",
+    help="Generate tuple types for arrays with items array syntax when minItems equals maxItems equals items length",
+    action="store_true",
+    default=None,
+)
 typing_options.add_argument(
     "--allof-merge-mode",
     help="Mode for field merging in allOf schemas. "
@@ -455,12 +607,27 @@ typing_options.add_argument(
     choices=[m.value for m in AllOfMergeMode],
     default=None,
 )
+typing_options.add_argument(
+    "--allof-class-hierarchy",
+    help="How to map allOf references to class hierarchies. "
+    "'if-no-conflict': only create subclasses when parent class has no conflicting property definition. "
+    "'always': always create subclasses. ",
+    choices=[m.value for m in AllOfClassHierarchy],
+    default=None,
+)
 typing_options.add_argument(
     "--use-type-alias",
     help="Use TypeAlias instead of root models (experimental)",
     action="store_true",
     default=None,
 )
+typing_options.add_argument(
+    "--use-root-model-type-alias",
+    help="Use type alias format for RootModel (e.g., Foo = RootModel[Bar]) "
+    "instead of class inheritance (Pydantic v2 only)",
+    action="store_true",
+    default=None,
+)
 typing_options.add_argument(
     "--disable-future-imports",
     help="Disable __future__ imports",
@@ -477,6 +644,15 @@ typing_options.add_argument(
     type=str,
     default=None,
 )
+typing_options.add_argument(
+    "--type-overrides",
+    help="Replace schema model types with custom Python types. "
+    "Format: JSON object mapping model names to Python import paths. "
+    'Model-level: \'{"CustomType": "my_app.types.MyType"}\' replaces all references. '
+    'Scoped: \'{"User.field": "my_app.Type"}\' replaces specific field only.',
+    type=json.loads,
+    default=None,
+)
 
 # ======================================================================================
 # Customization options for generated model fields
@@ -511,6 +687,19 @@ field_options.add_argument(
     action="store_true",
     default=None,
 )
+field_options.add_argument(
+    "--model-extra-keys",
+    help="Add extra keys from schema extensions (x-* fields) to model_config json_schema_extra",
+    type=str,
+    nargs="+",
+)
+field_options.add_argument(
+    "--model-extra-keys-without-x-prefix",
+    help="Add extra keys with `x-` prefix to model_config json_schema_extra. "
+    "The extra keys are stripped of the `x-` prefix.",
+    type=str,
+    nargs="+",
+)
 field_options.add_argument(
     "--force-optional",
     help="Force optional for required fields",
@@ -539,6 +728,12 @@ field_options.add_argument(
     help="Set field name prefix when first character can't be used as Python field name (default:  `field`)",
     default=None,
 )
+field_options.add_argument(
+    "--strict-nullable",
+    help="Treat default field as a non-nullable field",
+    action="store_true",
+    default=None,
+)
 field_options.add_argument(
     "--strip-default-none",
     help="Strip default None on fields",
@@ -563,6 +758,12 @@ field_options.add_argument(
     action="store_true",
     default=None,
 )
+field_options.add_argument(
+    "--use-field-description-example",
+    help="Use schema example to populate field docstring",
+    action="store_true",
+    default=None,
+)
 field_options.add_argument(
     "--use-attribute-docstrings",
     help="Set use_attribute_docstrings=True in Pydantic v2 ConfigDict",
@@ -588,12 +789,34 @@ field_options.add_argument(
     action="store_true",
     default=None,
 )
+field_options.add_argument(
+    "--use-serialization-alias",
+    help="Use serialization_alias instead of alias for field aliasing (Pydantic v2 only). "
+    "This allows setting values using the Pythonic field name while serializing to the original name.",
+    action="store_true",
+    default=None,
+)
 field_options.add_argument(
     "--use-frozen-field",
     help="Use Field(frozen=True) for readOnly fields (Pydantic v2) or Field(allow_mutation=False) (Pydantic v1)",
     action="store_true",
     default=None,
 )
+field_options.add_argument(
+    "--use-default-factory-for-optional-nested-models",
+    help="Use default_factory for optional nested model fields instead of None default. "
+    "E.g., `field: Model | None = Field(default_factory=Model)` instead of `field: Model | None = None`",
+    action="store_true",
+    default=None,
+)
+field_options.add_argument(
+    "--field-type-collision-strategy",
+    help="Strategy for handling field name and type name collisions (Pydantic v2 only). "
+    "'rename-field': rename field with suffix and add alias (default). "
+    "'rename-type': rename type class with suffix to preserve field name.",
+    choices=[s.value for s in FieldTypeCollisionStrategy],
+    default=None,
+)
 
 # ======================================================================================
 # Options for templating output
@@ -601,11 +824,25 @@ field_options.add_argument(
 template_options.add_argument(
     "--aliases",
     help="Alias mapping file (JSON) for renaming fields. "
+    "Format: {'<schema_field>': '<python_name>'} - the schema field name becomes the Pydantic alias. "
     "Supports hierarchical formats: "
-    "Flat: {'field': 'alias'} applies to all occurrences. "
-    "Scoped: {'ClassName.field': 'alias'} applies to specific class. "
+    "Flat: {'id': 'id_'} applies to all occurrences. "
+    "Scoped: {'User.name': 'user_name'} applies to specific class. "
     "Priority: scoped > flat. "
-    "Example: {'User.name': 'user_name', 'Address.name': 'addr_name', 'id': 'id_'}",
+    "Multiple aliases (Pydantic v2 only): {'field': ['alt1', 'alt2']} uses AliasChoices for validation. "
+    "Example: {'User.name': 'user_name', 'id': 'id_'} generates `id_: ... = Field(alias='id')`.",
+    type=Path,
+)
+template_options.add_argument(
+    "--default-values",
+    help="Default value overrides file (JSON). "
+    "Supports hierarchical formats: "
+    "Flat: {'field': value} applies to all occurrences. "
+    "Scoped: {'ClassName.field': value} applies to specific class. "
+    "Priority: scoped > flat. "
+    "Note: Scoped keys use the generated class name for JSON Schema/OpenAPI. "
+    "Required fields remain required unless --use-default is also specified. "
+    "Example: {'User.status': 'active', 'page': 1, 'limit': 10}",
     type=Path,
 )
 template_options.add_argument(
@@ -658,6 +895,14 @@ base_options.add_argument(
     type=str,
     default=None,
 )
+base_options.add_argument(
+    "--class-decorators",
+    help="Custom decorators for generated model classes (delimited list input). "
+    'For example "@dataclass_json(letter_case=LetterCase.CAMEL)". '
+    'The "@" prefix is optional and will be added automatically if missing.',
+    type=str,
+    default=None,
+)
 base_options.add_argument(
     "--formatters",
     help="Formatters for output (default: [black, isort])",
@@ -687,12 +932,6 @@ openapi_options.add_argument(
     nargs="+",
     default=None,
 )
-openapi_options.add_argument(
-    "--strict-nullable",
-    help="Treat default field as a non-nullable field (Only OpenAPI)",
-    action="store_true",
-    default=None,
-)
 openapi_options.add_argument(
     "--use-operation-id-as-name",
     help="use operation id of OpenAPI as class names of models",
@@ -705,6 +944,18 @@ openapi_options.add_argument(
     action="store_true",
     default=None,
 )
+openapi_options.add_argument(
+    "--openapi-include-paths",
+    nargs="+",
+    metavar="PATTERN",
+    help=(
+        "Include only OpenAPI paths matching fnmatch patterns. "
+        "Use wildcards: '*' matches any chars, '?' matches single char. "
+        "Example: '/users/*' '/products'. "
+        "Requires '--openapi-scopes' to include 'paths'."
+    ),
+    default=None,
+)
 openapi_options.add_argument(
     "--validation",
     help="Deprecated: Enable validation (Only OpenAPI). this option is deprecated. it will be removed in future "
@@ -727,6 +978,17 @@ openapi_options.add_argument(
     default=None,
 )
 
+# ======================================================================================
+# Options specific to GraphQL input schemas
+# ======================================================================================
+graphql_options.add_argument(
+    "--graphql-no-typename",
+    help="Exclude __typename field from generated GraphQL models. "
+    "Useful when using generated models for GraphQL mutations.",
+    action="store_true",
+    default=None,
+)
+
 # ======================================================================================
 # General options
 # ======================================================================================
@@ -775,6 +1037,20 @@ general_options.add_argument(
     default=None,
     help="Generate CLI command from pyproject.toml configuration and exit",
 )
+general_options.add_argument(
+    "--generate-prompt",
+    type=str,
+    nargs="?",
+    const="",
+    default=None,
+    metavar="QUESTION",
+    help=(
+        "Generate a prompt for consulting LLMs about CLI options. "
+        "Optionally provide your question as an argument. "
+        "Pipe to CLI tools (e.g., `| claude -p`, `| codex exec`) "
+        "or copy to clipboard (e.g., `| pbcopy`, `| xclip`) for web LLM chats."
+    ),
+)
 general_options.add_argument(
     "--ignore-pyproject",
     action="store_true",
