@@ -6,7 +6,9 @@ along with PythonVersion enum and DatetimeClassType for output configuration.
 
 from __future__ import annotations
 
+import shutil
 import subprocess  # noqa: S404
+import sys
 from enum import Enum
 from functools import cached_property, lru_cache
 from importlib import import_module
@@ -51,6 +53,16 @@ class DatetimeClassType(Enum):
     Datetime = "datetime"
     Awaredatetime = "AwareDatetime"
     Naivedatetime = "NaiveDatetime"
+    Pastdatetime = "PastDatetime"
+    Futuredatetime = "FutureDatetime"
+
+
+class DateClassType(Enum):
+    """Output date class type options."""
+
+    Date = "date"
+    Pastdate = "PastDate"
+    Futuredate = "FutureDate"
 
 
 class PythonVersion(Enum):
@@ -74,6 +86,10 @@ class PythonVersion(Enum):
     def _is_py_312_or_later(self) -> bool:  # pragma: no cover
         return self.value not in {self.PY_310.value, self.PY_311.value}
 
+    @cached_property
+    def _is_py_313_or_later(self) -> bool:
+        return self.value not in {self.PY_310.value, self.PY_311.value, self.PY_312.value}
+
     @cached_property
     def _is_py_314_or_later(self) -> bool:
         return self.value not in {
@@ -93,6 +109,11 @@ class PythonVersion(Enum):
         """Check if Python version supports TypedDict NotRequired."""
         return self._is_py_311_or_later
 
+    @property
+    def has_typed_dict_read_only(self) -> bool:
+        """Check if Python version supports TypedDict ReadOnly (PEP 705)."""
+        return self._is_py_313_or_later
+
     @property
     def has_kw_only_dataclass(self) -> bool:
         """Check if Python version supports kw_only in dataclasses."""
@@ -162,7 +183,7 @@ DEFAULT_FORMATTERS = [Formatter.BLACK, Formatter.ISORT]
 class CodeFormatter:
     """Formats generated code using black, isort, ruff, and custom formatters."""
 
-    def __init__(  # noqa: PLR0912, PLR0913, PLR0917
+    def __init__(  # noqa: PLR0912, PLR0913, PLR0915, PLR0917
         self,
         python_version: PythonVersion,
         settings_path: Path | None = None,
@@ -172,9 +193,21 @@ class CodeFormatter:
         custom_formatters: list[str] | None = None,
         custom_formatters_kwargs: dict[str, Any] | None = None,
         encoding: str = "utf-8",
-        formatters: list[Formatter] = DEFAULT_FORMATTERS,
+        formatters: list[Formatter] | None = None,
+        defer_formatting: bool = False,  # noqa: FBT001, FBT002
     ) -> None:
         """Initialize code formatter with configuration for black, isort, ruff, and custom formatters."""
+        if formatters is None:
+            warn(
+                "The default formatters (black, isort) will be replaced by ruff in a future version. "
+                "To prepare for this change, consider using: formatters=[Formatter.RUFF_FORMAT, Formatter.RUFF_CHECK]. "
+                "Install ruff with: pip install 'datamodel-code-generator[ruff]'. "
+                "To suppress this warning, specify formatters explicitly.",
+                FutureWarning,
+                stacklevel=2,
+            )
+            formatters = list(DEFAULT_FORMATTERS)
+
         if not settings_path:
             settings_path = Path.cwd()
         elif settings_path.is_file():
@@ -187,64 +220,75 @@ class CodeFormatter:
             else:
                 settings_path = Path.cwd()  # pragma: no cover
 
-        root = black_find_project_root((settings_path,))
-        path = root / "pyproject.toml"
-        if path.is_file():
-            pyproject_toml = load_toml(path)
-            config = pyproject_toml.get("tool", {}).get("black", {})
-        else:
-            config = {}
-
-        black = _get_black()
-        black_mode = _get_black_mode()
-        isort = _get_isort()
-
-        black_kwargs: dict[str, Any] = {}
-        if wrap_string_literal is not None:
-            experimental_string_processing = wrap_string_literal
-        elif black.__version__ < "24.1.0":
-            experimental_string_processing = config.get("experimental-string-processing")
-        else:
-            experimental_string_processing = config.get("preview", False) and (  # pragma: no cover
-                config.get("unstable", False) or "string_processing" in config.get("enable-unstable-feature", [])
-            )
-
-        if experimental_string_processing is not None:  # pragma: no cover
-            if black.__version__.startswith("19."):
-                warn(
-                    f"black doesn't support `experimental-string-processing` option"
-                    f" for wrapping string literal in {black.__version__}",
-                    stacklevel=2,
-                )
-            elif black.__version__ < "24.1.0":
-                black_kwargs["experimental_string_processing"] = experimental_string_processing
-            elif experimental_string_processing:
-                black_kwargs["preview"] = True
-                black_kwargs["unstable"] = config.get("unstable", False)
-                black_kwargs["enabled_features"] = {black_mode.Preview.string_processing}
-
-        self.black_mode = black.FileMode(
-            target_versions={_get_black_python_version_map()[python_version]},
-            line_length=config.get("line-length", black.DEFAULT_LINE_LENGTH),
-            string_normalization=not skip_string_normalization or not config.get("skip-string-normalization", True),
-            **black_kwargs,
-        )
-
         self.settings_path: str = str(settings_path)
+        self.formatters = formatters
+        self.defer_formatting = defer_formatting
+        self.encoding = encoding
 
-        self.isort_config_kwargs: dict[str, Any] = {}
-        if known_third_party:
-            self.isort_config_kwargs["known_third_party"] = known_third_party
+        use_black = Formatter.BLACK in formatters
+        use_isort = Formatter.ISORT in formatters
 
-        if isort.__version__.startswith("4."):  # pragma: no cover
-            self.isort_config = None
+        if use_black:
+            root = black_find_project_root((settings_path,))
+            path = root / "pyproject.toml"
+            if path.is_file():
+                pyproject_toml = load_toml(path)
+                config = pyproject_toml.get("tool", {}).get("black", {})
+            else:
+                config = {}
+
+            black = _get_black()
+            black_mode = _get_black_mode()
+
+            black_kwargs: dict[str, Any] = {}
+            if wrap_string_literal is not None:
+                experimental_string_processing = wrap_string_literal
+            elif black.__version__ < "24.1.0":
+                experimental_string_processing = config.get("experimental-string-processing")
+            else:
+                experimental_string_processing = config.get("preview", False) and (  # pragma: no cover
+                    config.get("unstable", False) or "string_processing" in config.get("enable-unstable-feature", [])
+                )
+
+            if experimental_string_processing is not None:  # pragma: no cover
+                if black.__version__.startswith("19."):
+                    warn(
+                        f"black doesn't support `experimental-string-processing` option"
+                        f" for wrapping string literal in {black.__version__}",
+                        stacklevel=2,
+                    )
+                elif black.__version__ < "24.1.0":
+                    black_kwargs["experimental_string_processing"] = experimental_string_processing
+                elif experimental_string_processing:
+                    black_kwargs["preview"] = True
+                    black_kwargs["unstable"] = config.get("unstable", False)
+                    black_kwargs["enabled_features"] = {black_mode.Preview.string_processing}
+
+            self.black_mode = black.FileMode(
+                target_versions={_get_black_python_version_map()[python_version]},
+                line_length=config.get("line-length", black.DEFAULT_LINE_LENGTH),
+                string_normalization=not skip_string_normalization or not config.get("skip-string-normalization", True),
+                **black_kwargs,
+            )
         else:
-            self.isort_config = isort.Config(settings_path=self.settings_path, **self.isort_config_kwargs)
+            self.black_mode = None  # type: ignore[assignment]
+
+        if use_isort:
+            isort = _get_isort()
+            self.isort_config_kwargs: dict[str, Any] = {}
+            if known_third_party:
+                self.isort_config_kwargs["known_third_party"] = known_third_party
+
+            if isort.__version__.startswith("4."):  # pragma: no cover
+                self.isort_config = None
+            else:
+                self.isort_config = isort.Config(settings_path=self.settings_path, **self.isort_config_kwargs)
+        else:
+            self.isort_config_kwargs = {}
+            self.isort_config = None
 
         self.custom_formatters_kwargs = custom_formatters_kwargs or {}
         self.custom_formatters = self._check_custom_formatters(custom_formatters)
-        self.encoding = encoding
-        self.formatters = formatters
 
     def _load_custom_formatter(self, custom_formatter_import: str) -> CustomCodeFormatter:
         """Load and instantiate a custom formatter from a module path."""
@@ -279,11 +323,15 @@ class CodeFormatter:
         if Formatter.BLACK in self.formatters:
             code = self.apply_black(code)
 
-        if Formatter.RUFF_CHECK in self.formatters:
-            code = self.apply_ruff_lint(code)
-
-        if Formatter.RUFF_FORMAT in self.formatters:
-            code = self.apply_ruff_formatter(code)
+        if not self.defer_formatting:
+            has_ruff_check = Formatter.RUFF_CHECK in self.formatters
+            has_ruff_format = Formatter.RUFF_FORMAT in self.formatters
+            if has_ruff_check and has_ruff_format:
+                code = self.apply_ruff_check_and_format(code)
+            elif has_ruff_check:
+                code = self.apply_ruff_lint(code)
+            elif has_ruff_format:
+                code = self.apply_ruff_formatter(code)
 
         for formatter in self.custom_formatters:
             code = formatter.apply(code)
@@ -301,7 +349,7 @@ class CodeFormatter:
     def apply_ruff_lint(self, code: str) -> str:
         """Run ruff check with auto-fix on code."""
         result = subprocess.run(
-            ("ruff", "check", "--fix", "-"),
+            ("ruff", "check", "--fix", "--unsafe-fixes", "-"),
             input=code.encode(self.encoding),
             capture_output=True,
             check=False,
@@ -320,6 +368,41 @@ class CodeFormatter:
         )
         return result.stdout.decode(self.encoding)
 
+    def apply_ruff_check_and_format(self, code: str) -> str:
+        """Run ruff check and format in a single pipeline for better performance."""
+        ruff_path = self._find_ruff_path()
+        check_proc = subprocess.Popen(  # noqa: S603
+            [ruff_path, "check", "--fix", "--unsafe-fixes", "-"],
+            stdin=subprocess.PIPE,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+            cwd=self.settings_path,
+        )
+        format_proc = subprocess.Popen(  # noqa: S603
+            [ruff_path, "format", "-"],
+            stdin=check_proc.stdout,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+            cwd=self.settings_path,
+        )
+        if check_proc.stdout:  # pragma: no branch
+            check_proc.stdout.close()
+        check_proc.stdin.write(code.encode(self.encoding))  # type: ignore[union-attr]
+        check_proc.stdin.close()  # type: ignore[union-attr]
+        stdout, _ = format_proc.communicate()
+        check_proc.wait()
+        return stdout.decode(self.encoding)
+
+    @staticmethod
+    def _find_ruff_path() -> str:
+        """Find ruff executable path, checking virtual environment first."""
+        bin_dir = Path(sys.executable).parent
+        ruff_name = "ruff.exe" if sys.platform == "win32" else "ruff"
+        ruff_in_venv = bin_dir / ruff_name
+        if ruff_in_venv.exists():
+            return str(ruff_in_venv)
+        return shutil.which("ruff") or "ruff"  # pragma: no cover
+
     def apply_isort(self, code: str) -> str:
         """Sort imports using isort."""
         isort = _get_isort()
@@ -331,6 +414,23 @@ class CodeFormatter:
             ).output
         return isort.code(code, config=self.isort_config)
 
+    def format_directory(self, directory: Path) -> None:
+        """Apply ruff formatting to all Python files in a directory."""
+        if Formatter.RUFF_CHECK in self.formatters:
+            subprocess.run(  # noqa: S603
+                ("ruff", "check", "--fix", "--unsafe-fixes", str(directory)),
+                capture_output=True,
+                check=False,
+                cwd=self.settings_path,
+            )
+        if Formatter.RUFF_FORMAT in self.formatters:
+            subprocess.run(  # noqa: S603
+                ("ruff", "format", str(directory)),
+                capture_output=True,
+                check=False,
+                cwd=self.settings_path,
+            )
+
 
 class CustomCodeFormatter:
     """Base class for custom code formatters.
