@@ -10,22 +10,22 @@ import re
 from abc import ABC, abstractmethod
 from collections import defaultdict
 from copy import deepcopy
-from dataclasses import dataclass
 from functools import cached_property, lru_cache
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, ClassVar, Optional, TypeVar, Union
 from warnings import warn
 
-from jinja2 import Environment, FileSystemLoader, Template
 from pydantic import Field
 from typing_extensions import Self
 
+from datamodel_code_generator import cached_path_exists
 from datamodel_code_generator.imports import (
     IMPORT_ANNOTATED,
     IMPORT_OPTIONAL,
     IMPORT_UNION,
     Import,
 )
+from datamodel_code_generator.model._types import WrappedDefault
 from datamodel_code_generator.reference import Reference, _BaseModel
 from datamodel_code_generator.types import (
     ANY,
@@ -37,16 +37,48 @@ from datamodel_code_generator.types import (
     chain_as_tuple,
     get_optional_type,
 )
-from datamodel_code_generator.util import PYDANTIC_V2, ConfigDict
+from datamodel_code_generator.util import ConfigDict, is_pydantic_v2, model_copy, model_dump, model_validate
+
+__all__ = ["WrappedDefault"]
 
 if TYPE_CHECKING:
     from collections.abc import Iterator
 
+    from jinja2 import Environment, Template
+
     from datamodel_code_generator import DataclassArguments
 
 TEMPLATE_DIR: Path = Path(__file__).parents[0] / "template"
 
+
+def escape_docstring(value: str | None) -> str | None:
+    r"""Escape special characters in a docstring to prevent syntax errors.
+
+    Handles:
+    - Backslashes: `\\` -> `\\\\` (must be escaped first)
+    - Triple quotes: `\"\"\"` -> `\\\"\\\"\\\"` (would terminate docstring)
+
+    Args:
+        value: The string to escape, or None.
+
+    Returns:
+        The escaped string, or None if input was None.
+    """
+    if value is None:
+        return None
+    # Escape backslashes first, then triple quotes
+    return value.replace("\\", "\\\\").replace('"""', '\\"\\"\\"')
+
+
 ALL_MODEL: str = "#all#"
+GENERIC_BASE_CLASS_PATH: str = "#/__datamodel_code_generator__/generic_base_class__"
+GENERIC_BASE_CLASS_NAME: str = "__generic_base_class__"
+
+
+def _copy_all_model_data(source: dict[str, Any], target: dict[str, Any]) -> None:
+    """Copy ALL_MODEL data to target dict, deep copying mutable containers only."""
+    for key, value in source.items():
+        target[key] = deepcopy(value) if isinstance(value, (dict, list, set)) else value
 
 
 def repr_set_sorted(value: set[Any]) -> str:
@@ -71,7 +103,7 @@ class ConstraintsBase(_BaseModel):
 
     unique_items: Optional[bool] = Field(None, alias="uniqueItems")  # noqa: UP045
     _exclude_fields: ClassVar[set[str]] = {"has_constraints"}
-    if PYDANTIC_V2:
+    if is_pydantic_v2():
         model_config = ConfigDict(  # pyright: ignore[reportAssignmentType]
             arbitrary_types_allowed=True, ignored_types=(cached_property,)
         )
@@ -86,20 +118,20 @@ class ConstraintsBase(_BaseModel):
     @cached_property
     def has_constraints(self) -> bool:
         """Check if any constraint values are set."""
-        return any(v is not None for v in self.dict().values())
+        return any(v is not None for v in model_dump(self).values())
 
     @staticmethod
     def merge_constraints(a: ConstraintsBaseT | None, b: ConstraintsBaseT | None) -> ConstraintsBaseT | None:
         """Merge two constraint objects, with b taking precedence over a."""
         constraints_class = None
         if isinstance(a, ConstraintsBase):  # pragma: no cover
-            root_type_field_constraints = {k: v for k, v in a.dict(by_alias=True).items() if v is not None}
+            root_type_field_constraints = {k: v for k, v in model_dump(a, by_alias=True).items() if v is not None}
             constraints_class = a.__class__
         else:
             root_type_field_constraints = {}  # pragma: no cover
 
         if isinstance(b, ConstraintsBase):  # pragma: no cover
-            model_field_constraints = {k: v for k, v in b.dict(by_alias=True).items() if v is not None}
+            model_field_constraints = {k: v for k, v in model_dump(b, by_alias=True).items() if v is not None}
             constraints_class = constraints_class or b.__class__
         else:
             model_field_constraints = {}
@@ -107,28 +139,19 @@ class ConstraintsBase(_BaseModel):
         if constraints_class is None or not issubclass(constraints_class, ConstraintsBase):  # pragma: no cover
             return None
 
-        return constraints_class.parse_obj({
-            **root_type_field_constraints,
-            **model_field_constraints,
-        })
-
-
-@dataclass(repr=False)
-class WrappedDefault:
-    """Represents a default value wrapped with its type constructor."""
-
-    value: Any
-    type_name: str
-
-    def __repr__(self) -> str:
-        """Return type constructor representation, e.g., 'CountType(10)'."""
-        return f"{self.type_name}({self.value!r})"
+        return model_validate(
+            constraints_class,
+            {
+                **root_type_field_constraints,
+                **model_field_constraints,
+            },
+        )
 
 
 class DataModelFieldBase(_BaseModel):
     """Base class for model field representation and rendering."""
 
-    if PYDANTIC_V2:
+    if is_pydantic_v2():
         model_config = ConfigDict(  # pyright: ignore[reportAssignmentType]
             arbitrary_types_allowed=True,
             defer_build=True,
@@ -144,6 +167,7 @@ class DataModelFieldBase(_BaseModel):
     default: Optional[Any] = None  # noqa: UP045
     required: bool = False
     alias: Optional[str] = None  # noqa: UP045
+    validation_aliases: Optional[list[str]] = None  # noqa: UP045  # Multiple aliases for Pydantic v2 AliasChoices
     data_type: DataType
     constraints: Any = None
     strip_default_none: bool = False
@@ -154,6 +178,7 @@ class DataModelFieldBase(_BaseModel):
     use_serialize_as_any: bool = False
     has_default: bool = False
     use_field_description: bool = False
+    use_field_description_example: bool = False
     use_inline_field_description: bool = False
     const: bool = False
     original_name: Optional[str] = None  # noqa: UP045
@@ -166,9 +191,11 @@ class DataModelFieldBase(_BaseModel):
     read_only: bool = False
     write_only: bool = False
     use_frozen_field: bool = False
+    use_serialization_alias: bool = False
+    use_default_factory_for_optional_nested_models: bool = False
 
-    if not TYPE_CHECKING:
-        if not PYDANTIC_V2:
+    if not TYPE_CHECKING:  # pragma: no branch
+        if not is_pydantic_v2():
 
             @classmethod
             def model_rebuild(
@@ -208,10 +235,19 @@ class DataModelFieldBase(_BaseModel):
             self.default = const
 
     def self_reference(self) -> bool:
-        """Check if field references its parent model."""
+        """Check if field references its parent model.
+
+        Result is cached after first call since parent is stable at render time.
+        Uses __dict__ for caching to avoid Pydantic v1 field assignment restrictions.
+        """
+        if "_self_reference_cache" in self.__dict__:
+            return self.__dict__["_self_reference_cache"]
         if self.parent is None or not self.parent.reference:  # pragma: no cover
+            self.__dict__["_self_reference_cache"] = False
             return False
-        return self.parent.reference.path in {d.reference.path for d in self.data_type.all_data_types if d.reference}
+        result = self.parent.reference.path in {d.reference.path for d in self.data_type.all_data_types if d.reference}
+        self.__dict__["_self_reference_cache"] = result
+        return result
 
     @property
     def _use_union_operator(self) -> bool:
@@ -229,6 +265,15 @@ class DataModelFieldBase(_BaseModel):
             return f"Union[{', '.join(parts)}]"
         return None  # pragma: no cover
 
+    def _build_base_union_type_hint(self) -> str | None:  # pragma: no cover
+        """Build Union[] base type hint from data_type.data_types if forward reference requires it."""
+        if not (self._use_union_operator != self.data_type.use_union_operator and self.data_type.is_union):
+            return None
+        parts = [dt.base_type_hint for dt in self.data_type.data_types if dt.base_type_hint]
+        if len(parts) > 1:
+            return f"Union[{', '.join(parts)}]"
+        return None
+
     @property
     def type_hint(self) -> str:  # noqa: PLR0911
         """Get the type hint string for this field, including nullability."""
@@ -250,12 +295,45 @@ class DataModelFieldBase(_BaseModel):
             return get_optional_type(type_hint, self._use_union_operator)
         return type_hint
 
+    @property
+    def base_type_hint(self) -> str:
+        """Get the base type hint without constrained type kwargs.
+
+        This returns the type without kwargs (e.g., 'str' instead of 'constr(pattern=...)').
+        Used in RootModel generics when regex_engine config is needed for lookaround patterns.
+        """
+        base_hint = self._build_base_union_type_hint() or self.data_type.base_type_hint
+
+        if not base_hint:  # pragma: no cover
+            return NONE
+
+        needs_optional = (
+            (self.nullable is True)
+            or (self.required and self.type_has_null)
+            or (self.nullable is None and not self.required and self.fall_back_to_nullable)
+        )
+        skip_optional = (
+            self.has_default_factory
+            or (self.data_type.is_optional and self.data_type.type != ANY)
+            or (self.nullable is False)
+        )
+
+        if needs_optional and not skip_optional:  # pragma: no cover
+            return get_optional_type(base_hint, self._use_union_operator)
+        return base_hint
+
     @property
     def imports(self) -> tuple[Import, ...]:
         """Get all imports required for this field's type hint."""
         type_hint = self.type_hint
         has_union = not self._use_union_operator and UNION_PREFIX in type_hint
         has_optional = OPTIONAL_PREFIX in type_hint
+        needs_annotated = self.use_annotated and self.needs_annotated_import
+
+        # Fast path: no special typing imports needed
+        if not has_union and not has_optional and not needs_annotated:
+            return tuple(self.data_type.all_imports)
+
         imports: list[tuple[Import] | Iterator[Import]] = [
             iter(
                 i
@@ -268,22 +346,44 @@ class DataModelFieldBase(_BaseModel):
             imports.append((IMPORT_UNION,))
         if has_optional:
             imports.append((IMPORT_OPTIONAL,))
-        if self.use_annotated and self.needs_annotated_import:
+        if needs_annotated:
             imports.append((IMPORT_ANNOTATED,))
         return chain_as_tuple(*imports)
 
     @property
     def docstring(self) -> str | None:
-        """Get the docstring for this field from its description."""
+        """Get the docstring for this field from its description and/or example."""
+        parts = []
+
         if self.use_field_description:
-            description = self.extras.get("description", None)
+            description = self.extras.get("description")
             if description is not None:
-                return f"{description}"
-        elif self.use_inline_field_description:
-            # For inline mode, only use multi-line docstring format for multi-line descriptions
-            description = self.extras.get("description", None)
+                parts.append(description)
+        elif self.use_inline_field_description and self.use_field_description_example:
+            description = self.extras.get("description")
             if description is not None and "\n" in description:
-                return f"{description}"
+                parts.append(description)
+
+        if self.use_field_description_example:
+            example = self.extras.get("example")
+            examples = self.extras.get("examples")
+
+            if examples and isinstance(examples, list) and len(examples) > 1:
+                examples_str = "\n".join(f"- {e!r}" for e in examples)
+                parts.append(f"Examples:\n{examples_str}")
+            elif example is not None:
+                parts.append(f"Example: {example!r}")
+            elif examples and isinstance(examples, list) and len(examples) == 1:
+                parts.append(f"Example: {examples[0]!r}")
+
+        if parts:
+            return "\n\n".join(parts)
+
+        if self.use_inline_field_description:
+            description = self.extras.get("description")
+            if description is not None and "\n" in description:
+                return description
+
         return None
 
     @property
@@ -292,7 +392,8 @@ class DataModelFieldBase(_BaseModel):
         if self.use_inline_field_description:
             description = self.extras.get("description", None)
             if description is not None and "\n" not in description:
-                return f'"""{description}"""'
+                escaped = escape_docstring(description)
+                return f'"""{escaped}"""'
         return None
 
     @property
@@ -344,14 +445,14 @@ class DataModelFieldBase(_BaseModel):
 
     def copy_deep(self) -> Self:
         """Create a deep copy of this field to avoid mutating the original."""
-        copied = self.copy()
+        copied = model_copy(self)
         copied.parent = None
         copied.extras = deepcopy(self.extras)
-        copied.data_type = self.data_type.copy()
+        copied.data_type = model_copy(self.data_type)
         if self.data_type.data_types:
-            copied.data_type.data_types = [dt.copy() for dt in self.data_type.data_types]
+            copied.data_type.data_types = [model_copy(dt) for dt in self.data_type.data_types]
         if self.data_type.dict_key:
-            copied.data_type.dict_key = self.data_type.dict_key.copy()
+            copied.data_type.dict_key = model_copy(self.data_type.dict_key)
         return copied
 
     def replace_data_type(self, new_data_type: DataType, *, clear_old_parent: bool = True) -> None:
@@ -369,16 +470,87 @@ class DataModelFieldBase(_BaseModel):
             new_data_type.parent = self
 
 
+@lru_cache(maxsize=16)
+def _get_environment(template_subdir: Path, custom_template_dir: Path | None) -> Environment:
+    """Get or create a cached Jinja2 Environment for the given directories."""
+    from jinja2 import ChoiceLoader, Environment, FileSystemLoader, select_autoescape  # noqa: PLC0415
+
+    loaders: list[FileSystemLoader] = []
+
+    if custom_template_dir is not None:
+        custom_dir = custom_template_dir / template_subdir
+        if cached_path_exists(custom_dir):
+            loaders.append(FileSystemLoader(str(custom_dir)))
+
+    loaders.append(FileSystemLoader(str(TEMPLATE_DIR / template_subdir)))
+
+    loader: ChoiceLoader | FileSystemLoader = ChoiceLoader(loaders) if len(loaders) > 1 else loaders[0]
+    env = Environment(
+        loader=loader,
+        autoescape=select_autoescape(["html", "xml"]),
+    )
+    env.filters["escape_docstring"] = escape_docstring
+    return env
+
+
 @lru_cache
-def get_template(template_file_path: Path) -> Template:
-    """Load and cache a Jinja2 template from the template directory."""
-    loader = FileSystemLoader(str(TEMPLATE_DIR / template_file_path.parent))
-    environment: Environment = Environment(loader=loader)  # noqa: S701
+def _get_template_with_custom_dir(template_file_path: Path, custom_template_dir: Path | None) -> Template:
+    """Load and cache a Jinja2 template with optional custom directory support.
+
+    When custom_template_dir is provided, templates are searched in this order:
+    1. custom_template_dir/<template_subdir>/
+    2. TEMPLATE_DIR/<template_subdir>/ (fallback)
+
+    This allows users to override individual templates (including included ones)
+    while keeping other templates from the default directory.
+    """
+    template_subdir = template_file_path.parent
+    environment = _get_environment(template_subdir, custom_template_dir)
     return environment.get_template(template_file_path.name)
 
 
-def sanitize_module_name(name: str, *, treat_dot_as_module: bool) -> str:
-    """Sanitize a module name by replacing invalid characters."""
+@lru_cache(maxsize=16)
+def _get_environment_with_absolute_path(absolute_template_dir: Path, builtin_subdir: Path) -> Environment:
+    """Get or create a cached Jinja2 Environment for absolute path templates."""
+    from jinja2 import ChoiceLoader, Environment, FileSystemLoader, select_autoescape  # noqa: PLC0415
+
+    loaders: list[FileSystemLoader] = [
+        FileSystemLoader(str(absolute_template_dir)),
+        FileSystemLoader(str(TEMPLATE_DIR / builtin_subdir)),
+    ]
+    env = Environment(
+        loader=ChoiceLoader(loaders),
+        autoescape=select_autoescape(["html", "xml"]),
+    )
+    env.filters["escape_docstring"] = escape_docstring
+    return env
+
+
+@lru_cache
+def _get_template_with_absolute_path(absolute_template_path: Path, builtin_subdir: Path) -> Template:
+    """Load a Jinja2 template from an absolute path with fallback to built-in directory.
+
+    This handles backward compatibility for custom templates found at absolute paths.
+    Includes are searched in this order:
+    1. The directory containing the absolute template path
+    2. TEMPLATE_DIR/<builtin_subdir>/ (fallback for includes not in custom dir)
+    """
+    environment = _get_environment_with_absolute_path(absolute_template_path.parent, builtin_subdir)
+    return environment.get_template(absolute_template_path.name)
+
+
+@lru_cache
+def get_template(template_file_path: Path) -> Template:
+    """Load and cache a Jinja2 template from the template directory."""
+    return _get_template_with_custom_dir(template_file_path, None)
+
+
+def sanitize_module_name(name: str, *, treat_dot_as_module: bool | None) -> str:
+    """Sanitize a module name by replacing invalid characters.
+
+    If treat_dot_as_module is True, dots are preserved in the name.
+    If treat_dot_as_module is False or None (default), dots are replaced with underscores.
+    """
     pattern = r"[^0-9a-zA-Z_.]" if treat_dot_as_module else r"[^0-9a-zA-Z_]"
     sanitized = re.sub(pattern, "_", name)
     if sanitized and sanitized[0].isdigit():
@@ -386,19 +558,28 @@ def sanitize_module_name(name: str, *, treat_dot_as_module: bool) -> str:
     return sanitized
 
 
-def get_module_path(name: str, file_path: Path | None, *, treat_dot_as_module: bool) -> list[str]:
-    """Get the module path components from a name and file path."""
+def get_module_path(name: str, file_path: Path | None, *, treat_dot_as_module: bool | None) -> list[str]:
+    """Get the module path components from a name and file path.
+
+    The treat_dot_as_module flag controls behavior:
+    - None (default): Split names on dots (backward compat), but sanitize file names (replace dots)
+    - True: Split names on dots AND keep dots in file names (for modular output)
+    - False: Don't split names on dots AND sanitize file names (new feature for flat output)
+    """
+    should_split_names = treat_dot_as_module is not False
+    should_keep_dots_in_files = treat_dot_as_module is True
     if file_path:
-        sanitized_stem = sanitize_module_name(file_path.stem, treat_dot_as_module=treat_dot_as_module)
+        sanitized_stem = sanitize_module_name(file_path.stem, treat_dot_as_module=should_keep_dots_in_files)
+        module_parts = name.split(".")[:-1] if should_split_names else []
         return [
             *file_path.parts[:-1],
             sanitized_stem,
-            *name.split(".")[:-1],
+            *module_parts,
         ]
-    return name.split(".")[:-1]
+    return name.split(".")[:-1] if should_split_names else []
 
 
-def get_module_name(name: str, file_path: Path | None, *, treat_dot_as_module: bool) -> str:
+def get_module_name(name: str, file_path: Path | None, *, treat_dot_as_module: bool | None) -> str:
     """Get the full module name from a name and file path."""
     return ".".join(get_module_path(name, file_path, treat_dot_as_module=treat_dot_as_module))
 
@@ -447,7 +628,12 @@ class DataModel(TemplateBase, Nullable, ABC):  # noqa: PLR0904
     TEMPLATE_FILE_PATH: ClassVar[str] = ""
     BASE_CLASS: ClassVar[str] = ""
     DEFAULT_IMPORTS: ClassVar[tuple[Import, ...]] = ()
-    IS_ALIAS: bool = False
+    IS_ALIAS: ClassVar[bool] = False
+    SUPPORTS_GENERIC_BASE_CLASS: ClassVar[bool] = True
+    SUPPORTS_DISCRIMINATOR: ClassVar[bool] = False
+    SUPPORTS_FIELD_RENAMING: ClassVar[bool] = False
+    SUPPORTS_WRAPPED_DEFAULT: ClassVar[bool] = False
+    SUPPORTS_KW_ONLY: ClassVar[bool] = False
     has_forward_reference: bool = False
 
     def __init__(  # noqa: PLR0913
@@ -467,7 +653,7 @@ class DataModel(TemplateBase, Nullable, ABC):  # noqa: PLR0904
         nullable: bool = False,
         keyword_only: bool = False,
         frozen: bool = False,
-        treat_dot_as_module: bool = False,
+        treat_dot_as_module: bool | None = None,
         dataclass_arguments: DataclassArguments | None = None,
     ) -> None:
         """Initialize a data model with fields, base classes, and configuration."""
@@ -514,9 +700,7 @@ class DataModel(TemplateBase, Nullable, ABC):  # noqa: PLR0904
         if extra_template_data is not None:
             all_model_extra_template_data = extra_template_data.get(ALL_MODEL)
             if all_model_extra_template_data:
-                # The deepcopy is needed here to ensure that different models don't
-                # end up inadvertently sharing state (such as "base_class_kwargs")
-                self.extra_template_data.update(deepcopy(all_model_extra_template_data))
+                _copy_all_model_data(all_model_extra_template_data, self.extra_template_data)
 
         self.methods: list[str] = methods or []
 
@@ -527,7 +711,8 @@ class DataModel(TemplateBase, Nullable, ABC):  # noqa: PLR0904
         self._additional_imports.extend(self.DEFAULT_IMPORTS)
         self.default: Any = default
         self._nullable: bool = nullable
-        self._treat_dot_as_module: bool = treat_dot_as_module
+        self._treat_dot_as_module: bool | None = treat_dot_as_module
+        self._dedup_key_cache: dict[tuple[str | None, bool], tuple[Any, ...]] = {}
 
     def _validate_fields(self, fields: list[DataModelFieldBase]) -> list[DataModelFieldBase]:
         names: set[str] = set()
@@ -554,11 +739,22 @@ class DataModel(TemplateBase, Nullable, ABC):  # noqa: PLR0904
         yield from self.fields
 
     def get_dedup_key(self, class_name: str | None = None, *, use_default: bool = True) -> tuple[Any, ...]:
-        """Generate hashable key for model deduplication."""
+        """Generate hashable key for model deduplication.
+
+        Results are cached per (class_name, use_default) combination since
+        the key computation involves expensive render() and imports calls.
+        """
+        cache_key = (class_name, use_default)
+        cached = self._dedup_key_cache.get(cache_key)
+        if cached is not None:
+            return cached
+
         from datamodel_code_generator.parser.base import to_hashable  # noqa: PLC0415
 
         render_class_name = class_name if class_name is not None or not use_default else "M"
-        return tuple(to_hashable(v) for v in (self.render(class_name=render_class_name), self.imports))
+        result = tuple(to_hashable(v) for v in (self.render(class_name=render_class_name), self.imports))
+        self._dedup_key_cache[cache_key] = result
+        return result
 
     def create_reuse_model(self, base_ref: Reference) -> Self:
         """Create inherited model with empty fields pointing to base reference."""
@@ -600,10 +796,18 @@ class DataModel(TemplateBase, Nullable, ABC):  # noqa: PLR0904
         template_file_path = Path(self.TEMPLATE_FILE_PATH)
         if self._custom_template_dir is not None:
             custom_template_file_path = self._custom_template_dir / template_file_path
-            if custom_template_file_path.exists():
+            if cached_path_exists(custom_template_file_path):
                 return custom_template_file_path
         return template_file_path
 
+    @cached_property
+    def template(self) -> Template:
+        """Get the Jinja2 template with custom directory support for includes."""
+        resolved_path = self.template_file_path
+        if resolved_path.is_absolute():
+            return _get_template_with_absolute_path(resolved_path, Path(self.TEMPLATE_FILE_PATH).parent)
+        return _get_template_with_custom_dir(Path(self.TEMPLATE_FILE_PATH), self._custom_template_dir)
+
     @property
     def imports(self) -> tuple[Import, ...]:
         """Get all imports required by this model and its fields."""
@@ -680,6 +884,22 @@ class DataModel(TemplateBase, Nullable, ABC):  # noqa: PLR0904
         """Whether is a type alias (i.e. not an instance of BaseModel/RootModel)."""
         return self.IS_ALIAS
 
+    @classmethod
+    def create_base_class_model(
+        cls,
+        config: dict[str, Any],  # noqa: ARG003
+        reference: Reference,  # noqa: ARG003
+        custom_template_dir: Path | None = None,  # noqa: ARG003
+        keyword_only: bool = False,  # noqa: ARG003, FBT001, FBT002
+        treat_dot_as_module: bool | None = None,  # noqa: ARG003, FBT001
+    ) -> DataModel | None:
+        """Create a shared base class model for DRY configuration.
+
+        Returns the base model or None if not supported. Updates reference in place.
+        Each model type should override this to provide appropriate implementation.
+        """
+        return None
+
     @property
     def nullable(self) -> bool:
         """Check if this model is nullable."""
@@ -706,11 +926,12 @@ class DataModel(TemplateBase, Nullable, ABC):  # noqa: PLR0904
             methods=self.methods,
             description=self.description,
             dataclass_arguments=self.dataclass_arguments,
+            path=self.path,
             **self.extra_template_data,
         )
 
 
-if PYDANTIC_V2:
+if is_pydantic_v2():
     _rebuild_namespace = {"Union": Union, "DataModelFieldBase": DataModelFieldBase, "DataType": DataType}
     DataType.model_rebuild(_types_namespace=_rebuild_namespace)
     BaseClassDataType.model_rebuild(_types_namespace=_rebuild_namespace)
