@@ -10,7 +10,7 @@ from typing import TYPE_CHECKING, Any, ClassVar, Optional, TypeVar
 
 from pydantic import Field
 
-from datamodel_code_generator import DatetimeClassType, PythonVersion, PythonVersionMin
+from datamodel_code_generator import DateClassType, DatetimeClassType, PythonVersion, PythonVersionMin
 from datamodel_code_generator.imports import (
     IMPORT_DATE,
     IMPORT_DATETIME,
@@ -20,12 +20,12 @@ from datamodel_code_generator.imports import (
     Import,
 )
 from datamodel_code_generator.model import DataModel, DataModelFieldBase
-from datamodel_code_generator.model.base import UNDEFINED
+from datamodel_code_generator.model.base import UNDEFINED, BaseClassDataType
 from datamodel_code_generator.model.imports import (
-    IMPORT_CLASSVAR,
     IMPORT_MSGSPEC_CONVERT,
     IMPORT_MSGSPEC_FIELD,
     IMPORT_MSGSPEC_META,
+    IMPORT_MSGSPEC_STRUCT,
     IMPORT_MSGSPEC_UNSET,
     IMPORT_MSGSPEC_UNSETTYPE,
 )
@@ -34,7 +34,7 @@ from datamodel_code_generator.model.pydantic.base_model import (
 )
 from datamodel_code_generator.model.type_alias import TypeAliasBase
 from datamodel_code_generator.model.types import DataTypeManager as _DataTypeManager
-from datamodel_code_generator.model.types import type_map_factory
+from datamodel_code_generator.model.types import standard_primitive_type_map_factory, type_map_factory
 from datamodel_code_generator.types import (
     NONE,
     OPTIONAL_PREFIX,
@@ -47,6 +47,7 @@ from datamodel_code_generator.types import (
     _remove_none_from_union,
     chain_as_tuple,
 )
+from datamodel_code_generator.util import model_dump
 
 UNSET_TYPE = "UnsetType"
 
@@ -82,6 +83,8 @@ def import_extender(cls: type[DataModelFieldBaseT]) -> type[DataModelFieldBaseT]
 
     @wraps(original_imports.fget)  # pyright: ignore[reportArgumentType]
     def new_imports(self: DataModelFieldBaseT) -> tuple[Import, ...]:
+        if self.extras.get("is_classvar"):
+            return ()
         extra_imports = []
         field = self.field
         # TODO: Improve field detection
@@ -89,10 +92,8 @@ def import_extender(cls: type[DataModelFieldBaseT]) -> type[DataModelFieldBaseT]
             extra_imports.append(IMPORT_MSGSPEC_FIELD)
         if self.field and "lambda: convert" in self.field:
             extra_imports.append(IMPORT_MSGSPEC_CONVERT)
-        if self.annotated:
+        if isinstance(self, DataModelField) and self.needs_meta_import:
             extra_imports.append(IMPORT_MSGSPEC_META)
-        if self.extras.get("is_classvar"):
-            extra_imports.append(IMPORT_CLASSVAR)
         if not self.required and not self.nullable:
             extra_imports.append(IMPORT_MSGSPEC_UNSETTYPE)
             if not self.data_type.use_union_operator:
@@ -110,7 +111,19 @@ class Struct(DataModel):
 
     TEMPLATE_FILE_PATH: ClassVar[str] = "msgspec.jinja2"
     BASE_CLASS: ClassVar[str] = "msgspec.Struct"
+    BASE_CLASS_NAME: ClassVar[str] = "Struct"
+    BASE_CLASS_ALIAS: ClassVar[str] = "_Struct"
     DEFAULT_IMPORTS: ClassVar[tuple[Import, ...]] = ()
+    SUPPORTS_DISCRIMINATOR: ClassVar[bool] = True
+    CONFIG_MAPPING: ClassVar[dict[tuple[str, Any], tuple[str, Any] | None]] = {
+        ("allow_mutation", False): ("frozen", True),
+        ("extra_fields", "forbid"): ("forbid_unknown_fields", True),
+        ("extra_fields", "allow"): None,
+        ("extra_fields", "ignore"): None,
+        ("allow_extra_fields", True): None,
+        ("allow_population_by_field_name", True): None,
+        ("use_attribute_docstrings", True): None,
+    }
 
     def __init__(  # noqa: PLR0913
         self,
@@ -128,7 +141,7 @@ class Struct(DataModel):
         default: Any = UNDEFINED,
         nullable: bool = False,
         keyword_only: bool = False,
-        treat_dot_as_module: bool = False,
+        treat_dot_as_module: bool | None = None,
     ) -> None:
         """Initialize msgspec Struct with fields sorted by field assignment requirement."""
         super().__init__(
@@ -155,6 +168,46 @@ class Struct(DataModel):
         """Add keyword argument to base class constructor."""
         self.extra_template_data["base_class_kwargs"][name] = value
 
+    @classmethod
+    def create_base_class_model(
+        cls,
+        config: dict[str, Any],
+        reference: Reference,
+        custom_template_dir: Path | None = None,
+        keyword_only: bool = False,  # noqa: FBT001, FBT002
+        treat_dot_as_module: bool | None = None,  # noqa: FBT001
+    ) -> Struct | None:
+        """Create a shared base class model for DRY configuration.
+
+        Creates a Struct that inherits from msgspec.Struct (aliased as _Struct)
+        with the specified configuration. Updates the reference path and name in place.
+        """
+        reference.path = f"#/{cls.BASE_CLASS_NAME}"
+        reference.name = cls.BASE_CLASS_NAME
+
+        base_model = cls(
+            reference=reference,
+            fields=[],
+            custom_template_dir=custom_template_dir,
+            keyword_only=keyword_only,
+            treat_dot_as_module=treat_dot_as_module,
+        )
+
+        base_model.base_classes = [BaseClassDataType(type=cls.BASE_CLASS_ALIAS)]
+
+        for key, value in config.items():
+            mapping_result = cls.CONFIG_MAPPING.get((key, value))
+            if mapping_result is None:
+                continue
+            mapped_key, mapped_value = mapping_result
+            base_model.add_base_class_kwarg(mapped_key, str(mapped_value))
+
+        base_model._additional_imports.append(
+            Import(from_=IMPORT_MSGSPEC_STRUCT.from_, import_=IMPORT_MSGSPEC_STRUCT.import_, alias=cls.BASE_CLASS_ALIAS)
+        )
+
+        return base_model
+
 
 class Constraints(_Constraints):
     """Constraint model for msgspec fields."""
@@ -180,6 +233,19 @@ def get_neither_required_nor_nullable_type(type_: str, use_union_operator: bool)
     return f"{UNION_PREFIX}{type_}{UNION_DELIMITER}{UNSET_TYPE}]"
 
 
+@lru_cache
+def _add_unset_type(type_: str, use_union_operator: bool) -> str:  # noqa: FBT001
+    """Add UnsetType to a type hint without removing None."""
+    if use_union_operator:
+        return f"{type_}{UNION_OPERATOR_DELIMITER}{UNSET_TYPE}"
+    if type_.startswith(UNION_PREFIX):
+        return f"{type_[:-1]}{UNION_DELIMITER}{UNSET_TYPE}]"
+    if type_.startswith(OPTIONAL_PREFIX):  # pragma: no cover
+        inner_type = type_[len(OPTIONAL_PREFIX) : -1]
+        return f"{UNION_PREFIX}{inner_type}{UNION_DELIMITER}{NONE}{UNION_DELIMITER}{UNSET_TYPE}]"
+    return f"{UNION_PREFIX}{type_}{UNION_DELIMITER}{UNSET_TYPE}]"
+
+
 @import_extender
 class DataModelField(DataModelFieldBase):
     """Field implementation for msgspec Struct models."""
@@ -208,12 +274,6 @@ class DataModelField(DataModelFieldBase):
     _COMPARE_EXPRESSIONS: ClassVar[set[str]] = {"gt", "ge", "lt", "le", "multiple_of"}
     constraints: Optional[Constraints] = None  # noqa: UP045
 
-    def self_reference(self) -> bool:  # pragma: no cover
-        """Check if field references its parent Struct."""
-        return isinstance(self.parent, Struct) and self.parent.reference.path in {
-            d.reference.path for d in self.data_type.all_data_types if d.reference
-        }
-
     def process_const(self) -> None:
         """Process const field constraint."""
         if "const" not in self.extras:
@@ -222,7 +282,7 @@ class DataModelField(DataModelFieldBase):
         self.nullable = False
         const = self.extras["const"]
         if self.data_type.type == "str" and isinstance(const, str):  # pragma: no cover # Literal supports only str
-            self.data_type = self.data_type.__class__(literals=[const])
+            self.replace_data_type(self.data_type.__class__(literals=[const]), clear_old_parent=False)
 
     def _get_strict_field_constraint_value(self, constraint: str, value: Any) -> Any:
         """Get constraint value with appropriate numeric type."""
@@ -241,7 +301,7 @@ class DataModelField(DataModelFieldBase):
             return None
         return result
 
-    def __str__(self) -> str:
+    def __str__(self) -> str:  # noqa: PLR0912
         """Generate field() call or default value representation."""
         data: dict[str, Any] = {k: v for k, v in self.extras.items() if k in self._FIELD_KEYS}
         if self.alias:
@@ -268,6 +328,27 @@ class DataModelField(DataModelFieldBase):
                 data.pop("default")
                 data["default_factory"] = default_factory
 
+        if "default" in data and isinstance(data["default"], (list, dict, set)) and "default_factory" not in data:
+            default_value = data.pop("default")
+            if default_value:
+                from datamodel_code_generator.model.base import repr_set_sorted  # noqa: PLC0415
+
+                default_repr = repr_set_sorted(default_value) if isinstance(default_value, set) else repr(default_value)
+                data["default_factory"] = f"lambda: {default_repr}"
+            else:
+                data["default_factory"] = type(default_value).__name__
+
+        if (
+            self.use_default_factory_for_optional_nested_models
+            and not self.required
+            and (self.default is None or self.default is UNDEFINED)
+            and "default_factory" not in data
+        ):
+            nested_model_name = self._get_default_factory_for_optional_nested_model()
+            if nested_model_name:
+                data["default_factory"] = nested_model_name
+                data.pop("default", None)
+
         if not data:
             return ""
 
@@ -282,6 +363,8 @@ class DataModelField(DataModelFieldBase):
         """Return the type hint, using UnsetType for non-required non-nullable fields."""
         type_hint = super().type_hint
         if self._not_required and not self.nullable:
+            if self.data_type.is_optional:
+                return _add_unset_type(type_hint, self.data_type.use_union_operator)
             return get_neither_required_nor_nullable_type(type_hint, self.data_type.use_union_operator)
         return type_hint
 
@@ -294,39 +377,75 @@ class DataModelField(DataModelFieldBase):
         """Return whether to fall back to nullable type instead of UnsetType."""
         return not self._not_required
 
-    @property
-    def annotated(self) -> str | None:
-        """Get Annotated type hint with Meta constraints."""
-        if not self.use_annotated:  # pragma: no cover
-            return None
-
+    def _get_meta_string(self) -> str | None:
+        """Compute Meta(...) string if there are any meta constraints."""
         data: dict[str, Any] = {k: v for k, v in self.extras.items() if k in self._META_FIELD_KEYS}
-        if self.constraints is not None and not self.self_reference() and not self.data_type.strict:
+        has_type_constraints = self.data_type.kwargs is not None and len(self.data_type.kwargs) > 0
+        if (
+            self.constraints is not None
+            and not self.self_reference()
+            and not (self.data_type.strict and has_type_constraints)
+        ):
             data = {
                 **data,
                 **{
                     k: self._get_strict_field_constraint_value(k, v)
-                    for k, v in self.constraints.dict().items()
+                    for k, v in model_dump(self.constraints).items()
                     if k in self._META_FIELD_KEYS
                 },
             }
 
         meta_arguments = sorted(f"{k}={v!r}" for k, v in data.items() if v is not None)
-        if not meta_arguments:
+        return f"Meta({', '.join(meta_arguments)})" if meta_arguments else None
+
+    @property
+    def annotated(self) -> str | None:  # noqa: PLR0911
+        """Get Annotated type hint with Meta constraints.
+
+        For ClassVar fields (discriminator tag_field), ClassVar is required
+        regardless of use_annotated setting.
+        """
+        if self.extras.get("is_classvar"):
+            meta = self._get_meta_string()
+            if self.use_annotated and meta:
+                return f"ClassVar[Annotated[{self.type_hint}, {meta}]]"
+            return f"ClassVar[{self.type_hint}]"
+
+        if not self.use_annotated:  # pragma: no cover
             return None
 
-        meta = f"Meta({', '.join(meta_arguments)})"
+        meta = self._get_meta_string()
+        if not meta:
+            return None
 
-        if not self.required and not self.extras.get("is_classvar"):
-            type_hint = self.data_type.type_hint
-            annotated_type = f"Annotated[{type_hint}, {meta}]"
-            return get_neither_required_nor_nullable_type(annotated_type, self.data_type.use_union_operator)
+        if self.required:
+            return f"Annotated[{self.type_hint}, {meta}]"
 
-        annotated_type = f"Annotated[{self.type_hint}, {meta}]"
+        type_hint = self.data_type.type_hint
+        annotated_type = f"Annotated[{type_hint}, {meta}]"
+        if self.nullable:  # pragma: no cover
+            return annotated_type
+        if self.data_type.is_optional:  # pragma: no cover
+            return _add_unset_type(annotated_type, self.data_type.use_union_operator)
+        return get_neither_required_nor_nullable_type(annotated_type, self.data_type.use_union_operator)
+
+    @property
+    def needs_annotated_import(self) -> bool:
+        """Check if this field requires the Annotated import.
+
+        ClassVar fields with Meta need Annotated only when use_annotated is True.
+        ClassVar fields without Meta don't need Annotated.
+        """
+        if not self.annotated:
+            return False
         if self.extras.get("is_classvar"):
-            annotated_type = f"ClassVar[{annotated_type}]"
+            return self.use_annotated and self._get_meta_string() is not None
+        return True
 
-        return annotated_type
+    @property
+    def needs_meta_import(self) -> bool:
+        """Check if this field requires the Meta import."""
+        return self._get_meta_string() is not None
 
     def _get_default_as_struct_model(self) -> str | None:
         """Convert default value to Struct model using msgspec convert."""
@@ -358,6 +477,19 @@ class DataModelField(DataModelFieldBase):
                 )
         return None
 
+    def _get_default_factory_for_optional_nested_model(self) -> str | None:
+        """Get default_factory for optional nested Struct model fields.
+
+        Returns the class name if the field type references a Struct,
+        otherwise returns None.
+        """
+        for data_type in self.data_type.data_types or (self.data_type,):
+            if data_type.is_dict:
+                continue
+            if data_type.reference and isinstance(data_type.reference.source, Struct):
+                return data_type.alias or data_type.reference.source.class_name
+        return None
+
 
 class DataTypeManager(_DataTypeManager):
     """Type manager for msgspec Struct models."""
@@ -369,22 +501,29 @@ class DataTypeManager(_DataTypeManager):
         use_generic_container_types: bool = False,  # noqa: FBT001, FBT002
         strict_types: Sequence[StrictTypes] | None = None,
         use_non_positive_negative_number_constrained_types: bool = False,  # noqa: FBT001, FBT002
+        use_decimal_for_multiple_of: bool = False,  # noqa: FBT001, FBT002
         use_union_operator: bool = False,  # noqa: FBT001, FBT002
         use_pendulum: bool = False,  # noqa: FBT001, FBT002
+        use_standard_primitive_types: bool = False,  # noqa: FBT001, FBT002
         target_datetime_class: DatetimeClassType | None = None,
-        treat_dot_as_module: bool = False,  # noqa: FBT001, FBT002
+        target_date_class: DateClassType | None = None,  # noqa: ARG002
+        treat_dot_as_module: bool | None = None,  # noqa: FBT001
+        use_serialize_as_any: bool = False,  # noqa: FBT001, FBT002
     ) -> None:
         """Initialize type manager with optional datetime type mapping."""
         super().__init__(
-            python_version,
-            use_standard_collections,
-            use_generic_container_types,
-            strict_types,
-            use_non_positive_negative_number_constrained_types,
-            use_union_operator,
-            use_pendulum,
-            target_datetime_class,
-            treat_dot_as_module,
+            python_version=python_version,
+            use_standard_collections=use_standard_collections,
+            use_generic_container_types=use_generic_container_types,
+            strict_types=strict_types,
+            use_non_positive_negative_number_constrained_types=use_non_positive_negative_number_constrained_types,
+            use_decimal_for_multiple_of=use_decimal_for_multiple_of,
+            use_union_operator=use_union_operator,
+            use_pendulum=use_pendulum,
+            use_standard_primitive_types=use_standard_primitive_types,
+            target_datetime_class=target_datetime_class,
+            treat_dot_as_module=treat_dot_as_module,
+            use_serialize_as_any=use_serialize_as_any,
         )
 
         datetime_map = (
@@ -398,7 +537,12 @@ class DataTypeManager(_DataTypeManager):
             else {}
         )
 
+        standard_primitive_map = (
+            standard_primitive_type_map_factory(self.data_type) if use_standard_primitive_types else {}
+        )
+
         self.type_map: dict[Types, DataType] = {
             **type_map_factory(self.data_type),
             **datetime_map,
+            **standard_primitive_map,
         }
