@@ -6,40 +6,28 @@ objects, interfaces, enums, scalars, inputs, and union types.
 
 from __future__ import annotations
 
-from pathlib import Path
 from typing import (
     TYPE_CHECKING,
     Any,
 )
-from urllib.parse import ParseResult
+
+from typing_extensions import Unpack
 
 from datamodel_code_generator import (
-    DEFAULT_SHARED_MODULE_NAME,
-    AllOfMergeMode,
-    DataclassArguments,
-    DefaultPutDict,
     LiteralType,
-    PythonVersion,
-    PythonVersionMin,
-    ReadOnlyWriteOnlyModelType,
-    ReuseScope,
     snooper_to_methods,
 )
-from datamodel_code_generator.format import DEFAULT_FORMATTERS, DatetimeClassType, Formatter
-from datamodel_code_generator.model import DataModel, DataModelFieldBase
-from datamodel_code_generator.model import pydantic as pydantic_model
+from datamodel_code_generator.format import DatetimeClassType
 from datamodel_code_generator.model.dataclass import DataClass
 from datamodel_code_generator.model.enum import SPECIALIZED_ENUM_TYPE_MATCH, Enum
-from datamodel_code_generator.model.scalar import DataTypeScalar
-from datamodel_code_generator.model.union import DataTypeUnion
+from datamodel_code_generator.model.pydantic_v2.dataclass import DataClass as PydanticV2DataClass
 from datamodel_code_generator.parser.base import (
     DataType,
     Parser,
-    Source,
     escape_characters,
 )
 from datamodel_code_generator.reference import ModelType, Reference
-from datamodel_code_generator.types import DataTypeManager, StrictTypes, Types
+from datamodel_code_generator.types import Types
 
 try:
     import graphql
@@ -49,8 +37,12 @@ except ImportError as exc:  # pragma: no cover
 
 
 if TYPE_CHECKING:
-    from collections import defaultdict
-    from collections.abc import Callable, Iterable, Iterator, Mapping, Sequence
+    from pathlib import Path
+    from urllib.parse import ParseResult
+
+    from datamodel_code_generator._types import GraphQLParserConfigDict
+    from datamodel_code_generator.config import GraphQLParserConfig
+    from datamodel_code_generator.model import DataModel, DataModelFieldBase
 
 # graphql-core >=3.2.7 removed TypeResolvers in favor of TypeFields.kind.
 # Normalize to a single callable for resolving type kinds.
@@ -67,7 +59,7 @@ def build_graphql_schema(schema_str: str) -> graphql.GraphQLSchema:
 
 
 @snooper_to_methods()
-class GraphQLParser(Parser):
+class GraphQLParser(Parser["GraphQLParserConfig"]):
     """Parser for GraphQL schema files."""
 
     # raw graphql schema as `graphql-core` object
@@ -94,228 +86,55 @@ class GraphQLParser(Parser):
         graphql.type.introspection.TypeKind.UNION,
     ]
 
-    def __init__(  # noqa: PLR0913
+    @classmethod
+    def _create_default_config(cls, options: GraphQLParserConfigDict) -> GraphQLParserConfig:  # type: ignore[override]
+        """Create a GraphQLParserConfig from options."""
+        from datamodel_code_generator import types as types_module  # noqa: PLC0415
+        from datamodel_code_generator.config import GraphQLParserConfig  # noqa: PLC0415
+        from datamodel_code_generator.model import base as model_base  # noqa: PLC0415
+        from datamodel_code_generator.util import is_pydantic_v2  # noqa: PLC0415
+
+        if is_pydantic_v2():
+            GraphQLParserConfig.model_rebuild(
+                _types_namespace={
+                    "StrictTypes": types_module.StrictTypes,
+                    "DataModel": model_base.DataModel,
+                    "DataModelFieldBase": model_base.DataModelFieldBase,
+                    "DataTypeManager": types_module.DataTypeManager,
+                }
+            )
+            return GraphQLParserConfig.model_validate(options)
+        GraphQLParserConfig.update_forward_refs(
+            StrictTypes=types_module.StrictTypes,
+            DataModel=model_base.DataModel,
+            DataModelFieldBase=model_base.DataModelFieldBase,
+            DataTypeManager=types_module.DataTypeManager,
+        )
+        defaults = {name: field.default for name, field in GraphQLParserConfig.__fields__.items()}
+        defaults.update(options)
+        return GraphQLParserConfig.construct(**defaults)  # type: ignore[return-value]  # pragma: no cover
+
+    def __init__(
         self,
         source: str | Path | ParseResult,
         *,
-        data_model_type: type[DataModel] = pydantic_model.BaseModel,
-        data_model_root_type: type[DataModel] = pydantic_model.CustomRootType,
-        data_model_scalar_type: type[DataModel] = DataTypeScalar,
-        data_model_union_type: type[DataModel] = DataTypeUnion,
-        data_type_manager_type: type[DataTypeManager] = pydantic_model.DataTypeManager,
-        data_model_field_type: type[DataModelFieldBase] = pydantic_model.DataModelField,
-        base_class: str | None = None,
-        additional_imports: list[str] | None = None,
-        custom_template_dir: Path | None = None,
-        extra_template_data: defaultdict[str, dict[str, Any]] | None = None,
-        target_python_version: PythonVersion = PythonVersionMin,
-        dump_resolve_reference_action: Callable[[Iterable[str]], str] | None = None,
-        validation: bool = False,
-        field_constraints: bool = False,
-        snake_case_field: bool = False,
-        strip_default_none: bool = False,
-        aliases: Mapping[str, str] | None = None,
-        allow_population_by_field_name: bool = False,
-        apply_default_values_for_required_fields: bool = False,
-        allow_extra_fields: bool = False,
-        extra_fields: str | None = None,
-        force_optional_for_required_fields: bool = False,
-        class_name: str | None = None,
-        use_standard_collections: bool = False,
-        base_path: Path | None = None,
-        use_schema_description: bool = False,
-        use_field_description: bool = False,
-        use_attribute_docstrings: bool = False,
-        use_inline_field_description: bool = False,
-        use_default_kwarg: bool = False,
-        reuse_model: bool = False,
-        reuse_scope: ReuseScope | None = None,
-        shared_module_name: str = DEFAULT_SHARED_MODULE_NAME,
-        encoding: str = "utf-8",
-        enum_field_as_literal: LiteralType | None = None,
-        ignore_enum_constraints: bool = False,
-        set_default_enum_member: bool = False,
-        use_subclass_enum: bool = False,
-        use_specialized_enum: bool = True,
-        strict_nullable: bool = False,
-        use_generic_container_types: bool = False,
-        enable_faux_immutability: bool = False,
-        remote_text_cache: DefaultPutDict[str, str] | None = None,
-        disable_appending_item_suffix: bool = False,
-        strict_types: Sequence[StrictTypes] | None = None,
-        empty_enum_field_name: str | None = None,
-        custom_class_name_generator: Callable[[str], str] | None = None,
-        field_extra_keys: set[str] | None = None,
-        field_include_all_keys: bool = False,
-        field_extra_keys_without_x_prefix: set[str] | None = None,
-        wrap_string_literal: bool | None = None,
-        use_title_as_name: bool = False,
-        use_operation_id_as_name: bool = False,
-        use_unique_items_as_set: bool = False,
-        allof_merge_mode: AllOfMergeMode = AllOfMergeMode.Constraints,
-        http_headers: Sequence[tuple[str, str]] | None = None,
-        http_ignore_tls: bool = False,
-        use_annotated: bool = False,
-        use_non_positive_negative_number_constrained_types: bool = False,
-        use_decimal_for_multiple_of: bool = False,
-        original_field_name_delimiter: str | None = None,
-        use_double_quotes: bool = False,
-        use_union_operator: bool = False,
-        allow_responses_without_content: bool = False,
-        collapse_root_models: bool = False,
-        skip_root_model: bool = False,
-        use_type_alias: bool = False,
-        special_field_name_prefix: str | None = None,
-        remove_special_field_name_prefix: bool = False,
-        capitalise_enum_members: bool = False,
-        keep_model_order: bool = False,
-        use_one_literal_as_default: bool = False,
-        use_enum_values_in_discriminator: bool = False,
-        known_third_party: list[str] | None = None,
-        custom_formatters: list[str] | None = None,
-        custom_formatters_kwargs: dict[str, Any] | None = None,
-        use_pendulum: bool = False,
-        http_query_parameters: Sequence[tuple[str, str]] | None = None,
-        treat_dot_as_module: bool = False,
-        use_exact_imports: bool = False,
-        default_field_extras: dict[str, Any] | None = None,
-        target_datetime_class: DatetimeClassType = DatetimeClassType.Datetime,
-        keyword_only: bool = False,
-        frozen_dataclasses: bool = False,
-        no_alias: bool = False,
-        formatters: list[Formatter] = DEFAULT_FORMATTERS,
-        parent_scoped_naming: bool = False,
-        dataclass_arguments: DataclassArguments | None = None,
-        type_mappings: list[str] | None = None,
-        read_only_write_only_model_type: ReadOnlyWriteOnlyModelType | None = None,
-        use_serialize_as_any: bool = False,
-        use_frozen_field: bool = False,
+        config: GraphQLParserConfig | None = None,
+        **options: Unpack[GraphQLParserConfigDict],
     ) -> None:
         """Initialize the GraphQL parser with configuration options."""
-        super().__init__(
-            source=source,
-            data_model_type=data_model_type,
-            data_model_root_type=data_model_root_type,
-            data_type_manager_type=data_type_manager_type,
-            data_model_field_type=data_model_field_type,
-            base_class=base_class,
-            additional_imports=additional_imports,
-            custom_template_dir=custom_template_dir,
-            extra_template_data=extra_template_data,
-            target_python_version=target_python_version,
-            dump_resolve_reference_action=dump_resolve_reference_action,
-            validation=validation,
-            field_constraints=field_constraints,
-            snake_case_field=snake_case_field,
-            strip_default_none=strip_default_none,
-            aliases=aliases,
-            allow_population_by_field_name=allow_population_by_field_name,
-            allow_extra_fields=allow_extra_fields,
-            extra_fields=extra_fields,
-            apply_default_values_for_required_fields=apply_default_values_for_required_fields,
-            force_optional_for_required_fields=force_optional_for_required_fields,
-            class_name=class_name,
-            use_standard_collections=use_standard_collections,
-            base_path=base_path,
-            use_schema_description=use_schema_description,
-            use_field_description=use_field_description,
-            use_attribute_docstrings=use_attribute_docstrings,
-            use_inline_field_description=use_inline_field_description,
-            use_default_kwarg=use_default_kwarg,
-            reuse_model=reuse_model,
-            reuse_scope=reuse_scope,
-            shared_module_name=shared_module_name,
-            encoding=encoding,
-            enum_field_as_literal=enum_field_as_literal,
-            ignore_enum_constraints=ignore_enum_constraints,
-            use_one_literal_as_default=use_one_literal_as_default,
-            use_enum_values_in_discriminator=use_enum_values_in_discriminator,
-            set_default_enum_member=set_default_enum_member,
-            use_subclass_enum=use_subclass_enum,
-            use_specialized_enum=use_specialized_enum,
-            strict_nullable=strict_nullable,
-            use_generic_container_types=use_generic_container_types,
-            enable_faux_immutability=enable_faux_immutability,
-            remote_text_cache=remote_text_cache,
-            disable_appending_item_suffix=disable_appending_item_suffix,
-            strict_types=strict_types,
-            empty_enum_field_name=empty_enum_field_name,
-            custom_class_name_generator=custom_class_name_generator,
-            field_extra_keys=field_extra_keys,
-            field_include_all_keys=field_include_all_keys,
-            field_extra_keys_without_x_prefix=field_extra_keys_without_x_prefix,
-            wrap_string_literal=wrap_string_literal,
-            use_title_as_name=use_title_as_name,
-            use_operation_id_as_name=use_operation_id_as_name,
-            use_unique_items_as_set=use_unique_items_as_set,
-            allof_merge_mode=allof_merge_mode,
-            http_headers=http_headers,
-            http_ignore_tls=http_ignore_tls,
-            use_annotated=use_annotated,
-            use_non_positive_negative_number_constrained_types=use_non_positive_negative_number_constrained_types,
-            use_decimal_for_multiple_of=use_decimal_for_multiple_of,
-            original_field_name_delimiter=original_field_name_delimiter,
-            use_double_quotes=use_double_quotes,
-            use_union_operator=use_union_operator,
-            allow_responses_without_content=allow_responses_without_content,
-            collapse_root_models=collapse_root_models,
-            skip_root_model=skip_root_model,
-            use_type_alias=use_type_alias,
-            special_field_name_prefix=special_field_name_prefix,
-            remove_special_field_name_prefix=remove_special_field_name_prefix,
-            capitalise_enum_members=capitalise_enum_members,
-            keep_model_order=keep_model_order,
-            known_third_party=known_third_party,
-            custom_formatters=custom_formatters,
-            custom_formatters_kwargs=custom_formatters_kwargs,
-            use_pendulum=use_pendulum,
-            http_query_parameters=http_query_parameters,
-            treat_dot_as_module=treat_dot_as_module,
-            use_exact_imports=use_exact_imports,
-            default_field_extras=default_field_extras,
-            target_datetime_class=target_datetime_class,
-            keyword_only=keyword_only,
-            frozen_dataclasses=frozen_dataclasses,
-            no_alias=no_alias,
-            formatters=formatters,
-            parent_scoped_naming=parent_scoped_naming,
-            dataclass_arguments=dataclass_arguments,
-            type_mappings=type_mappings,
-            read_only_write_only_model_type=read_only_write_only_model_type,
-            use_serialize_as_any=use_serialize_as_any,
-            use_frozen_field=use_frozen_field,
+        if config is None and options.get("target_datetime_class") is None:
+            options["target_datetime_class"] = DatetimeClassType.Datetime
+        use_standard_collections = (
+            config.use_standard_collections if config else options.get("use_standard_collections", False)
         )
+        use_union_operator = config.use_union_operator if config else options.get("use_union_operator", False)
+        super().__init__(source=source, config=config, **options)
 
-        self.data_model_scalar_type = data_model_scalar_type
-        self.data_model_union_type = data_model_union_type
+        self.data_model_scalar_type = self.config.data_model_scalar_type
+        self.data_model_union_type = self.config.data_model_union_type
         self.use_standard_collections = use_standard_collections
         self.use_union_operator = use_union_operator
 
-    def _get_context_source_path_parts(self) -> Iterator[tuple[Source, list[str]]]:
-        # TODO (denisart): Temporarily this method duplicates
-        # the method `datamodel_code_generator.parser.jsonschema.JsonSchemaParser._get_context_source_path_parts`.
-
-        if isinstance(self.source, list) or (  # pragma: no cover
-            isinstance(self.source, Path) and self.source.is_dir()
-        ):  # pragma: no cover
-            self.current_source_path = Path()
-            self.model_resolver.after_load_files = {
-                self.base_path.joinpath(s.path).resolve().as_posix() for s in self.iter_source
-            }
-
-        for source in self.iter_source:
-            if isinstance(self.source, ParseResult):  # pragma: no cover
-                path_parts = self.get_url_path_parts(self.source)
-            else:
-                path_parts = list(source.path.parts)
-            if self.current_source_path is not None:  # pragma: no cover
-                self.current_source_path = source.path
-            with (
-                self.model_resolver.current_base_path_context(source.path.parent),
-                self.model_resolver.current_root_context(path_parts),
-            ):
-                yield source, path_parts
-
     def _resolve_types(self, paths: list[str], schema: graphql.GraphQLSchema) -> None:
         for type_name, type_ in schema.type_map.items():
             if type_name.startswith("__"):
@@ -328,10 +147,11 @@ class GraphQLParser(Parser):
 
             if resolved_type in self.support_graphql_types:  # pragma: no cover
                 self.all_graphql_objects[type_.name] = type_
-                # TODO: need a special method for each graph type
+                graphql_model_type = "enum" if resolved_type == graphql.TypeKind.ENUM else "model"
+                affixed_name = self.model_resolver.get_affixed_name(type_.name, model_type=graphql_model_type)
                 self.references[type_.name] = Reference(
                     path=f"{paths!s}/{resolved_type.value}/{type_.name}",
-                    name=type_.name,
+                    name=affixed_name,
                     original_name=type_.name,
                 )
 
@@ -339,8 +159,11 @@ class GraphQLParser(Parser):
 
     def _create_data_model(self, model_type: type[DataModel] | None = None, **kwargs: Any) -> DataModel:
         """Create data model instance with dataclass_arguments support for DataClass."""
+        # Add class decorators if not already provided
+        if "decorators" not in kwargs and self.class_decorators:
+            kwargs["decorators"] = list(self.class_decorators)
         data_model_class = model_type or self.data_model_type
-        if issubclass(data_model_class, DataClass):
+        if issubclass(data_model_class, (DataClass, PydanticV2DataClass)):
             # Use dataclass_arguments from kwargs, or fall back to self.dataclass_arguments
             # If both are None, construct from legacy frozen_dataclasses/keyword_only flags
             dataclass_arguments = kwargs.pop("dataclass_arguments", None)
@@ -375,6 +198,7 @@ class GraphQLParser(Parser):
             use_one_literal_as_default=True,
             use_default_kwarg=self.use_default_kwarg,
             has_default=True,
+            use_serialization_alias=self.use_serialization_alias,
         )
 
     def _get_default(  # noqa: PLR6301
@@ -433,7 +257,7 @@ class GraphQLParser(Parser):
                     data_type=data_type,
                 )
             ],
-            custom_base_class=self.base_class,
+            custom_base_class=self._resolve_base_class(enum_object.name),
             custom_template_dir=self.custom_template_dir,
             extra_template_data=self.extra_template_data,
             path=self.current_source_path,
@@ -453,7 +277,7 @@ class GraphQLParser(Parser):
                     data_type=data_type,
                 )
             ],
-            custom_base_class=self.base_class,
+            custom_base_class=self._resolve_base_class(enum_object.name),
             custom_template_dir=self.custom_template_dir,
             extra_template_data=self.extra_template_data,
             path=self.current_source_path,
@@ -511,8 +335,10 @@ class GraphQLParser(Parser):
     def parse_field(
         self,
         field_name: str,
-        alias: str | None,
+        alias: str | list[str] | None,
         field: graphql.GraphQLField | graphql.GraphQLInputField,
+        original_field_name: str,
+        class_name: str | None = None,
     ) -> DataModelFieldBase:
         """Parse a GraphQL field and return a data model field."""
         final_data_type = DataType(
@@ -551,26 +377,48 @@ class GraphQLParser(Parser):
         required = (not self.force_optional_for_required_fields) and (not final_data_type.is_optional)
 
         default = self._get_default(field, final_data_type, required=required)
+        has_default = default is not None
+
+        effective_default, effective_has_default = self.model_resolver.resolve_default_value(
+            original_field_name,
+            default,
+            has_default,
+            class_name=class_name,
+        )
+
+        if self.apply_default_values_for_required_fields and effective_has_default:
+            required = False
+
         extras = {} if self.default_field_extras is None else self.default_field_extras.copy()
 
         if field.description is not None:  # pragma: no cover
             extras["description"] = field.description
 
+        # Handle multiple aliases (Pydantic v2 AliasChoices)
+        single_alias: str | None = None
+        validation_aliases: list[str] | None = None
+        if isinstance(alias, list):
+            validation_aliases = alias
+        else:
+            single_alias = alias
         return self.data_model_field_type(
             name=field_name,
-            default=default,
+            default=effective_default,
             data_type=final_data_type,
             required=required,
             extras=extras,
-            alias=alias,
+            alias=single_alias,
+            validation_aliases=validation_aliases,
             strip_default_none=self.strip_default_none,
             use_annotated=self.use_annotated,
             use_serialize_as_any=self.use_serialize_as_any,
             use_field_description=self.use_field_description,
+            use_field_description_example=self.use_field_description_example,
             use_inline_field_description=self.use_inline_field_description,
             use_default_kwarg=self.use_default_kwarg,
             original_name=field_name,
-            has_default=default is not None,
+            has_default=effective_has_default,
+            use_serialization_alias=self.use_serialization_alias,
         )
 
     def parse_object_like(
@@ -581,19 +429,22 @@ class GraphQLParser(Parser):
         fields = []
         exclude_field_names: set[str] = set()
 
-        for field_name, field in obj.fields.items():
+        for original_field_name, field in obj.fields.items():
             field_name_, alias = self.model_resolver.get_valid_field_name_and_alias(
-                field_name,
+                original_field_name,
                 excludes=exclude_field_names,
                 model_type=self.field_name_model_type,
                 class_name=obj.name,
             )
             exclude_field_names.add(field_name_)
 
-            data_model_field_type = self.parse_field(field_name_, alias, field)
+            data_model_field_type = self.parse_field(
+                field_name_, alias, field, original_field_name, class_name=obj.name
+            )
             fields.append(data_model_field_type)
 
-        fields.append(self._typename_field(obj.name))
+        if not self.config.graphql_no_typename:
+            fields.append(self._typename_field(obj.name))
 
         base_classes = []
         if hasattr(obj, "interfaces"):  # pragma: no cover
@@ -603,7 +454,7 @@ class GraphQLParser(Parser):
             reference=self.references[obj.name],
             fields=fields,
             base_classes=base_classes,
-            custom_base_class=self.base_class,
+            custom_base_class=self._resolve_base_class(obj.name),
             custom_template_dir=self.custom_template_dir,
             extra_template_data=self.extra_template_data,
             path=self.current_source_path,
@@ -633,7 +484,7 @@ class GraphQLParser(Parser):
         data_model_type = self.data_model_union_type(
             reference=self.references[union_object.name],
             fields=fields,
-            custom_base_class=self.base_class,
+            custom_base_class=self._resolve_base_class(union_object.name),
             custom_template_dir=self.custom_template_dir,
             extra_template_data=self.extra_template_data,
             path=self.current_source_path,
@@ -665,13 +516,13 @@ class GraphQLParser(Parser):
             graphql.type.introspection.TypeKind.UNION: self.parse_union,
         }
 
-        for source, path_parts in self._get_context_source_path_parts():
-            schema: graphql.GraphQLSchema = build_graphql_schema(source.text)
-            self.raw_obj = schema
+        combined_schema = "\n".join(source.text for source in self.iter_source)
+        schema: graphql.GraphQLSchema = build_graphql_schema(combined_schema)
+        self.raw_obj = schema
 
-            self._resolve_types(path_parts, schema)
+        self._resolve_types([], schema)
 
-            for next_type in self.parse_order:
-                for obj in self.support_graphql_types[next_type]:
-                    parser_ = mapper_from_graphql_type_to_parser_method[next_type]
-                    parser_(obj)
+        for next_type in self.parse_order:
+            for obj in self.support_graphql_types[next_type]:
+                parser_ = mapper_from_graphql_type_to_parser_method[next_type]
+                parser_(obj)
