@@ -6,6 +6,7 @@ specifications, including paths, operations, parameters, and request/response bo
 
 from __future__ import annotations
 
+import fnmatch
 import re
 from collections import defaultdict
 from contextlib import nullcontext
@@ -16,25 +17,15 @@ from typing import TYPE_CHECKING, Any, ClassVar, Optional, TypeVar, Union
 from warnings import warn
 
 from pydantic import Field
+from typing_extensions import Unpack
 
 from datamodel_code_generator import (
-    DEFAULT_SHARED_MODULE_NAME,
-    AllOfMergeMode,
-    DataclassArguments,
     Error,
-    LiteralType,
     OpenAPIScope,
-    PythonVersion,
-    PythonVersionMin,
-    ReadOnlyWriteOnlyModelType,
-    ReuseScope,
     YamlValue,
-    load_yaml_dict,
+    load_data,
     snooper_to_methods,
 )
-from datamodel_code_generator.format import DEFAULT_FORMATTERS, DatetimeClassType, Formatter
-from datamodel_code_generator.model import DataModel, DataModelFieldBase
-from datamodel_code_generator.model import pydantic as pydantic_model
 from datamodel_code_generator.parser.base import get_special_path
 from datamodel_code_generator.parser.jsonschema import (
     JsonSchemaObject,
@@ -44,17 +35,16 @@ from datamodel_code_generator.parser.jsonschema import (
 from datamodel_code_generator.reference import FieldNameResolver, is_url, snake_to_upper_camel
 from datamodel_code_generator.types import (
     DataType,
-    DataTypeManager,
     EmptyDataType,
-    StrictTypes,
 )
-from datamodel_code_generator.util import BaseModel
+from datamodel_code_generator.util import BaseModel, model_dump, model_validate
 
 if TYPE_CHECKING:
-    from collections.abc import Callable, Iterable, Mapping, Sequence
     from urllib.parse import ParseResult
 
-    from datamodel_code_generator.parser import DefaultPutDict
+    from datamodel_code_generator._types import OpenAPIParserConfigDict
+    from datamodel_code_generator.config import OpenAPIParserConfig
+    from datamodel_code_generator.model import DataModelFieldBase
 
 
 RE_APPLICATION_JSON_PATTERN: Pattern[str] = re.compile(r"^application/.*json$")
@@ -117,7 +107,7 @@ class ParameterObject(BaseModel):
     schema_: Optional[JsonSchemaObject] = Field(None, alias="schema")  # noqa: UP045
     example: YamlValue = None
     examples: Optional[Union[str, ReferenceObject, ExampleObject]] = None  # noqa: UP007, UP045
-    content: dict[str, MediaObject] = {}  # noqa: RUF012
+    content: dict[str, MediaObject] = Field(default_factory=dict)
 
 
 class HeaderObject(BaseModel):
@@ -129,14 +119,14 @@ class HeaderObject(BaseModel):
     schema_: Optional[JsonSchemaObject] = Field(None, alias="schema")  # noqa: UP045
     example: YamlValue = None
     examples: Optional[Union[str, ReferenceObject, ExampleObject]] = None  # noqa: UP007, UP045
-    content: dict[str, MediaObject] = {}  # noqa: RUF012
+    content: dict[str, MediaObject] = Field(default_factory=dict)
 
 
 class RequestBodyObject(BaseModel):
     """Represent an OpenAPI request body object."""
 
     description: Optional[str] = None  # noqa: UP045
-    content: dict[str, MediaObject] = {}  # noqa: RUF012
+    content: dict[str, MediaObject] = Field(default_factory=dict)
     required: bool = False
 
 
@@ -144,31 +134,31 @@ class ResponseObject(BaseModel):
     """Represent an OpenAPI response object."""
 
     description: Optional[str] = None  # noqa: UP045
-    headers: dict[str, ParameterObject] = {}  # noqa: RUF012
-    content: dict[Union[str, int], MediaObject] = {}  # noqa: RUF012, UP007
+    headers: dict[str, ParameterObject] = Field(default_factory=dict)
+    content: dict[Union[str, int], MediaObject] = Field(default_factory=dict)  # noqa: UP007
 
 
 class Operation(BaseModel):
     """Represent an OpenAPI operation object."""
 
-    tags: list[str] = []  # noqa: RUF012
+    tags: list[str] = Field(default_factory=list)
     summary: Optional[str] = None  # noqa: UP045
     description: Optional[str] = None  # noqa: UP045
     operationId: Optional[str] = None  # noqa: N815, UP045
-    parameters: list[Union[ReferenceObject, ParameterObject]] = []  # noqa: RUF012, UP007
+    parameters: list[Union[ReferenceObject, ParameterObject]] = Field(default_factory=list)  # noqa: UP007
     requestBody: Optional[Union[ReferenceObject, RequestBodyObject]] = None  # noqa: N815, UP007, UP045
-    responses: dict[Union[str, int], Union[ReferenceObject, ResponseObject]] = {}  # noqa: RUF012, UP007
+    responses: dict[Union[str, int], Union[ReferenceObject, ResponseObject]] = Field(default_factory=dict)  # noqa: UP007
     deprecated: bool = False
 
 
 class ComponentsObject(BaseModel):
     """Represent an OpenAPI components object."""
 
-    schemas: dict[str, Union[ReferenceObject, JsonSchemaObject]] = {}  # noqa: RUF012, UP007
-    responses: dict[str, Union[ReferenceObject, ResponseObject]] = {}  # noqa: RUF012, UP007
-    examples: dict[str, Union[ReferenceObject, ExampleObject]] = {}  # noqa: RUF012, UP007
-    requestBodies: dict[str, Union[ReferenceObject, RequestBodyObject]] = {}  # noqa: N815, RUF012, UP007
-    headers: dict[str, Union[ReferenceObject, HeaderObject]] = {}  # noqa: RUF012, UP007
+    schemas: dict[str, Union[ReferenceObject, JsonSchemaObject]] = Field(default_factory=dict)  # noqa: UP007
+    responses: dict[str, Union[ReferenceObject, ResponseObject]] = Field(default_factory=dict)  # noqa: UP007
+    examples: dict[str, Union[ReferenceObject, ExampleObject]] = Field(default_factory=dict)  # noqa: UP007
+    requestBodies: dict[str, Union[ReferenceObject, RequestBodyObject]] = Field(default_factory=dict)  # noqa: N815, UP007
+    headers: dict[str, Union[ReferenceObject, HeaderObject]] = Field(default_factory=dict)  # noqa: UP007
 
 
 @snooper_to_methods()
@@ -177,202 +167,54 @@ class OpenAPIParser(JsonSchemaParser):
 
     SCHEMA_PATHS: ClassVar[list[str]] = ["#/components/schemas"]
 
-    def __init__(  # noqa: PLR0913
+    @classmethod
+    def _create_default_config(cls, options: OpenAPIParserConfigDict) -> OpenAPIParserConfig:
+        """Create an OpenAPIParserConfig from options."""
+        from datamodel_code_generator import types as types_module  # noqa: PLC0415
+        from datamodel_code_generator.config import OpenAPIParserConfig  # noqa: PLC0415
+        from datamodel_code_generator.model import base as model_base  # noqa: PLC0415
+        from datamodel_code_generator.util import is_pydantic_v2  # noqa: PLC0415
+
+        if is_pydantic_v2():
+            OpenAPIParserConfig.model_rebuild(
+                _types_namespace={
+                    "StrictTypes": types_module.StrictTypes,
+                    "DataModel": model_base.DataModel,
+                    "DataModelFieldBase": model_base.DataModelFieldBase,
+                    "DataTypeManager": types_module.DataTypeManager,
+                }
+            )
+            return OpenAPIParserConfig.model_validate(options)
+        OpenAPIParserConfig.update_forward_refs(
+            StrictTypes=types_module.StrictTypes,
+            DataModel=model_base.DataModel,
+            DataModelFieldBase=model_base.DataModelFieldBase,
+            DataTypeManager=types_module.DataTypeManager,
+        )
+        defaults = {name: field.default for name, field in OpenAPIParserConfig.__fields__.items()}
+        defaults.update(options)
+        return OpenAPIParserConfig.construct(**defaults)  # type: ignore[return-value]  # pragma: no cover
+
+    def __init__(
         self,
         source: str | Path | list[Path] | ParseResult,
         *,
-        data_model_type: type[DataModel] = pydantic_model.BaseModel,
-        data_model_root_type: type[DataModel] = pydantic_model.CustomRootType,
-        data_type_manager_type: type[DataTypeManager] = pydantic_model.DataTypeManager,
-        data_model_field_type: type[DataModelFieldBase] = pydantic_model.DataModelField,
-        base_class: str | None = None,
-        additional_imports: list[str] | None = None,
-        custom_template_dir: Path | None = None,
-        extra_template_data: defaultdict[str, dict[str, Any]] | None = None,
-        target_python_version: PythonVersion = PythonVersionMin,
-        dump_resolve_reference_action: Callable[[Iterable[str]], str] | None = None,
-        validation: bool = False,
-        field_constraints: bool = False,
-        snake_case_field: bool = False,
-        strip_default_none: bool = False,
-        aliases: Mapping[str, str] | None = None,
-        allow_population_by_field_name: bool = False,
-        allow_extra_fields: bool = False,
-        extra_fields: str | None = None,
-        apply_default_values_for_required_fields: bool = False,
-        force_optional_for_required_fields: bool = False,
-        class_name: str | None = None,
-        use_standard_collections: bool = False,
-        base_path: Path | None = None,
-        use_schema_description: bool = False,
-        use_field_description: bool = False,
-        use_attribute_docstrings: bool = False,
-        use_inline_field_description: bool = False,
-        use_default_kwarg: bool = False,
-        reuse_model: bool = False,
-        reuse_scope: ReuseScope | None = None,
-        shared_module_name: str = DEFAULT_SHARED_MODULE_NAME,
-        encoding: str = "utf-8",
-        enum_field_as_literal: LiteralType | None = None,
-        ignore_enum_constraints: bool = False,
-        use_one_literal_as_default: bool = False,
-        use_enum_values_in_discriminator: bool = False,
-        set_default_enum_member: bool = False,
-        use_subclass_enum: bool = False,
-        use_specialized_enum: bool = True,
-        strict_nullable: bool = False,
-        use_generic_container_types: bool = False,
-        enable_faux_immutability: bool = False,
-        remote_text_cache: DefaultPutDict[str, str] | None = None,
-        disable_appending_item_suffix: bool = False,
-        strict_types: Sequence[StrictTypes] | None = None,
-        empty_enum_field_name: str | None = None,
-        custom_class_name_generator: Callable[[str], str] | None = None,
-        field_extra_keys: set[str] | None = None,
-        field_include_all_keys: bool = False,
-        field_extra_keys_without_x_prefix: set[str] | None = None,
-        openapi_scopes: list[OpenAPIScope] | None = None,
-        include_path_parameters: bool = False,
-        wrap_string_literal: bool | None = False,
-        use_title_as_name: bool = False,
-        use_operation_id_as_name: bool = False,
-        use_unique_items_as_set: bool = False,
-        allof_merge_mode: AllOfMergeMode = AllOfMergeMode.Constraints,
-        http_headers: Sequence[tuple[str, str]] | None = None,
-        http_ignore_tls: bool = False,
-        use_annotated: bool = False,
-        use_serialize_as_any: bool = False,
-        use_non_positive_negative_number_constrained_types: bool = False,
-        use_decimal_for_multiple_of: bool = False,
-        original_field_name_delimiter: str | None = None,
-        use_double_quotes: bool = False,
-        use_union_operator: bool = False,
-        allow_responses_without_content: bool = False,
-        collapse_root_models: bool = False,
-        skip_root_model: bool = False,
-        use_type_alias: bool = False,
-        special_field_name_prefix: str | None = None,
-        remove_special_field_name_prefix: bool = False,
-        capitalise_enum_members: bool = False,
-        keep_model_order: bool = False,
-        known_third_party: list[str] | None = None,
-        custom_formatters: list[str] | None = None,
-        custom_formatters_kwargs: dict[str, Any] | None = None,
-        use_pendulum: bool = False,
-        http_query_parameters: Sequence[tuple[str, str]] | None = None,
-        treat_dot_as_module: bool = False,
-        use_exact_imports: bool = False,
-        default_field_extras: dict[str, Any] | None = None,
-        target_datetime_class: DatetimeClassType | None = None,
-        keyword_only: bool = False,
-        frozen_dataclasses: bool = False,
-        no_alias: bool = False,
-        formatters: list[Formatter] = DEFAULT_FORMATTERS,
-        parent_scoped_naming: bool = False,
-        dataclass_arguments: DataclassArguments | None = None,
-        type_mappings: list[str] | None = None,
-        read_only_write_only_model_type: ReadOnlyWriteOnlyModelType | None = None,
-        use_frozen_field: bool = False,
-        use_status_code_in_response_name: bool = False,
+        config: OpenAPIParserConfig | None = None,
+        **options: Unpack[OpenAPIParserConfigDict],
     ) -> None:
         """Initialize the OpenAPI parser with extensive configuration options."""
-        target_datetime_class = target_datetime_class or DatetimeClassType.Awaredatetime
-        super().__init__(
-            source=source,
-            data_model_type=data_model_type,
-            data_model_root_type=data_model_root_type,
-            data_type_manager_type=data_type_manager_type,
-            data_model_field_type=data_model_field_type,
-            base_class=base_class,
-            additional_imports=additional_imports,
-            custom_template_dir=custom_template_dir,
-            extra_template_data=extra_template_data,
-            target_python_version=target_python_version,
-            dump_resolve_reference_action=dump_resolve_reference_action,
-            validation=validation,
-            field_constraints=field_constraints,
-            snake_case_field=snake_case_field,
-            strip_default_none=strip_default_none,
-            aliases=aliases,
-            allow_population_by_field_name=allow_population_by_field_name,
-            allow_extra_fields=allow_extra_fields,
-            extra_fields=extra_fields,
-            apply_default_values_for_required_fields=apply_default_values_for_required_fields,
-            force_optional_for_required_fields=force_optional_for_required_fields,
-            class_name=class_name,
-            use_standard_collections=use_standard_collections,
-            base_path=base_path,
-            use_schema_description=use_schema_description,
-            use_field_description=use_field_description,
-            use_attribute_docstrings=use_attribute_docstrings,
-            use_inline_field_description=use_inline_field_description,
-            use_default_kwarg=use_default_kwarg,
-            reuse_model=reuse_model,
-            reuse_scope=reuse_scope,
-            shared_module_name=shared_module_name,
-            encoding=encoding,
-            enum_field_as_literal=enum_field_as_literal,
-            ignore_enum_constraints=ignore_enum_constraints,
-            use_one_literal_as_default=use_one_literal_as_default,
-            use_enum_values_in_discriminator=use_enum_values_in_discriminator,
-            set_default_enum_member=set_default_enum_member,
-            use_subclass_enum=use_subclass_enum,
-            use_specialized_enum=use_specialized_enum,
-            strict_nullable=strict_nullable,
-            use_generic_container_types=use_generic_container_types,
-            enable_faux_immutability=enable_faux_immutability,
-            remote_text_cache=remote_text_cache,
-            disable_appending_item_suffix=disable_appending_item_suffix,
-            strict_types=strict_types,
-            empty_enum_field_name=empty_enum_field_name,
-            custom_class_name_generator=custom_class_name_generator,
-            field_extra_keys=field_extra_keys,
-            field_include_all_keys=field_include_all_keys,
-            field_extra_keys_without_x_prefix=field_extra_keys_without_x_prefix,
-            wrap_string_literal=wrap_string_literal,
-            use_title_as_name=use_title_as_name,
-            use_operation_id_as_name=use_operation_id_as_name,
-            use_unique_items_as_set=use_unique_items_as_set,
-            allof_merge_mode=allof_merge_mode,
-            http_headers=http_headers,
-            http_ignore_tls=http_ignore_tls,
-            use_annotated=use_annotated,
-            use_serialize_as_any=use_serialize_as_any,
-            use_non_positive_negative_number_constrained_types=use_non_positive_negative_number_constrained_types,
-            use_decimal_for_multiple_of=use_decimal_for_multiple_of,
-            original_field_name_delimiter=original_field_name_delimiter,
-            use_double_quotes=use_double_quotes,
-            use_union_operator=use_union_operator,
-            allow_responses_without_content=allow_responses_without_content,
-            collapse_root_models=collapse_root_models,
-            skip_root_model=skip_root_model,
-            use_type_alias=use_type_alias,
-            special_field_name_prefix=special_field_name_prefix,
-            remove_special_field_name_prefix=remove_special_field_name_prefix,
-            capitalise_enum_members=capitalise_enum_members,
-            keep_model_order=keep_model_order,
-            known_third_party=known_third_party,
-            custom_formatters=custom_formatters,
-            custom_formatters_kwargs=custom_formatters_kwargs,
-            use_pendulum=use_pendulum,
-            http_query_parameters=http_query_parameters,
-            treat_dot_as_module=treat_dot_as_module,
-            use_exact_imports=use_exact_imports,
-            default_field_extras=default_field_extras,
-            target_datetime_class=target_datetime_class,
-            keyword_only=keyword_only,
-            frozen_dataclasses=frozen_dataclasses,
-            no_alias=no_alias,
-            formatters=formatters,
-            parent_scoped_naming=parent_scoped_naming,
-            dataclass_arguments=dataclass_arguments,
-            type_mappings=type_mappings,
-            read_only_write_only_model_type=read_only_write_only_model_type,
-            use_frozen_field=use_frozen_field,
-        )
-        self.open_api_scopes: list[OpenAPIScope] = openapi_scopes or [OpenAPIScope.Schemas]
-        self.include_path_parameters: bool = include_path_parameters
-        self.use_status_code_in_response_name: bool = use_status_code_in_response_name
+        if config is None and options.get("wrap_string_literal") is None:
+            options["wrap_string_literal"] = False
+        super().__init__(source=source, config=config, **options)  # type: ignore[arg-type]
+        self.open_api_scopes: list[OpenAPIScope] = self.config.openapi_scopes or [OpenAPIScope.Schemas]
+        self.include_path_parameters: bool = self.config.include_path_parameters
+        self.use_status_code_in_response_name: bool = self.config.use_status_code_in_response_name
+        self.openapi_include_paths: list[str] | None = self.config.openapi_include_paths
+        if self.openapi_include_paths and OpenAPIScope.Paths not in self.open_api_scopes:
+            warn(
+                "--openapi-include-paths has no effect without --openapi-scopes paths",
+                stacklevel=2,
+            )
         self._discriminator_schemas: dict[str, dict[str, Any]] = {}
         self._discriminator_subtypes: dict[str, list[str]] = defaultdict(list)
 
@@ -393,9 +235,53 @@ class OpenAPIParser(JsonSchemaParser):
 
         return super().get_data_type(obj)
 
+    def _normalize_discriminator_mapping_ref(self, mapping_value: str) -> str:  # noqa: PLR6301
+        """Normalize a discriminator mapping value to a full $ref path.
+
+        Per OpenAPI spec, mapping values can be either:
+        - Full refs: "#/components/schemas/Pet" or "./other.yaml#/components/schemas/Pet"
+        - Short names: "Pet" or "Pet.V1" (relative to #/components/schemas/)
+        - Relative paths: "schemas/Pet" or "./other.yaml"
+
+        Values containing "/" or "#" are treated as paths/refs and passed through.
+        All other values (including those with dots like "Pet.V1") are treated as
+        short schema names and normalized to full refs.
+
+        Note: Bare file references without path separators (e.g., "other.yaml") will be
+        treated as schema names. Use "./other.yaml" format for file references.
+
+        Note: This could be a staticmethod, but @snooper_to_methods() decorator
+        converts staticmethods to regular functions when pysnooper is installed.
+        """
+        if "/" in mapping_value or "#" in mapping_value:
+            return mapping_value
+        return f"#/components/schemas/{mapping_value}"
+
+    def _normalize_discriminator(self, discriminator: dict[str, Any]) -> dict[str, Any]:
+        """Return a copy of the discriminator dict with normalized mapping refs."""
+        result = discriminator.copy()
+        mapping = discriminator.get("mapping")
+        if mapping:
+            result["mapping"] = {
+                k: self._normalize_discriminator_mapping_ref(v) for k, v in mapping.items() if isinstance(v, str)
+            }
+        return result
+
     def _get_discriminator_union_type(self, ref: str) -> DataType | None:
-        """Create a union type for discriminator subtypes if available."""
+        """Create a union type for discriminator subtypes if available.
+
+        First tries to use allOf subtypes. If none found, falls back to using
+        the discriminator mapping to create the union type. This handles cases
+        where schemas don't use allOf inheritance but have explicit discriminator mappings.
+        """
         subtypes = self._discriminator_subtypes.get(ref, [])
+        if not subtypes:
+            discriminator = self._discriminator_schemas[ref]
+            mapping = discriminator.get("mapping", {})
+            if mapping:
+                subtypes = [
+                    self._normalize_discriminator_mapping_ref(v) for v in mapping.values() if isinstance(v, str)
+                ]
         if not subtypes:
             return None
         refs = map(self.model_resolver.add_ref, subtypes)
@@ -428,10 +314,11 @@ class OpenAPIParser(JsonSchemaParser):
                 and (discriminator := self._discriminator_schemas.get(field.ref))
             ):
                 new_field_type = self._get_discriminator_union_type(field.ref) or field_obj.data_type
+                normalized_discriminator = self._normalize_discriminator(discriminator)
                 field_obj = self.data_model_field_type(**{  # noqa: PLW2901
                     **field_obj.__dict__,
                     "data_type": new_field_type,
-                    "extras": {**field_obj.extras, "discriminator": discriminator},
+                    "extras": {**field_obj.extras, "discriminator": normalized_discriminator},
                 })
             result_fields.append(field_obj)
 
@@ -441,7 +328,7 @@ class OpenAPIParser(JsonSchemaParser):
         """Resolve a reference object to its actual type or return the object as-is."""
         if isinstance(obj, ReferenceObject):
             ref_obj = self.get_ref_model(obj.ref)
-            return object_type.parse_obj(ref_obj)
+            return model_validate(object_type, ref_obj)
         return obj
 
     def _parse_schema_or_ref(
@@ -458,6 +345,25 @@ class OpenAPIParser(JsonSchemaParser):
         self.resolve_ref(schema.ref)
         return self.get_ref_data_type(schema.ref)
 
+    def _normalize_path(self, path: str) -> str:  # noqa: PLR6301
+        """Normalize path for consistent matching.
+
+        Note: This is an instance method (not static) due to the snooper_to_methods
+        class decorator which does not preserve staticmethod descriptors.
+        """
+        if not path.startswith("/"):
+            path = f"/{path}"
+        return path
+
+    def _matches_path_pattern(self, path: str) -> bool:
+        """Check if path matches any of the include patterns."""
+        if not self.openapi_include_paths:
+            return True
+        normalized_path = self._normalize_path(path)
+        return any(
+            fnmatch.fnmatch(normalized_path, self._normalize_path(pattern)) for pattern in self.openapi_include_paths
+        )
+
     def _process_path_items(  # noqa: PLR0913
         self,
         items: dict[str, dict[str, Any]],
@@ -467,10 +373,13 @@ class OpenAPIParser(JsonSchemaParser):
         security: list[dict[str, list[str]]] | None,
         *,
         strip_leading_slash: bool = True,
+        apply_path_filter: bool = True,
     ) -> None:
         """Process path or webhook items with operations."""
         scope_path = [*base_path, f"#/{scope_name}"]
         for item_name, methods_ in items.items():
+            if apply_path_filter and not self._matches_path_pattern(item_name):
+                continue
             item_ref = methods_.get("$ref")
             if item_ref:
                 methods = self.get_ref_model(item_ref)
@@ -560,7 +469,7 @@ class OpenAPIParser(JsonSchemaParser):
                 if not detail.ref:  # pragma: no cover
                     continue
                 ref_model = self.get_ref_model(detail.ref)
-                content = {k: MediaObject.parse_obj(v) for k, v in ref_model.get("content", {}).items()}
+                content = {k: model_validate(MediaObject, v) for k, v in ref_model.get("content", {}).items()}
             else:
                 content = detail.content
 
@@ -593,7 +502,7 @@ class OpenAPIParser(JsonSchemaParser):
         camel_path_name = snake_to_upper_camel(normalized)
         return f"{camel_path_name}{method.capitalize()}{suffix}"
 
-    def parse_all_parameters(
+    def parse_all_parameters(  # noqa: PLR0912, PLR0914
         self,
         name: str,
         parameters: list[ReferenceObject | ParameterObject],
@@ -602,6 +511,7 @@ class OpenAPIParser(JsonSchemaParser):
         """Parse all operation parameters into a data model."""
         fields: list[DataModelFieldBase] = []
         exclude_field_names: set[str] = set()
+        seen_parameter_names: set[str] = set()
         reference = self.model_resolver.add(path, name, class_name=True, unique=True)
         for parameter_ in parameters:
             parameter = self.resolve_object(parameter_, ParameterObject)
@@ -613,9 +523,10 @@ class OpenAPIParser(JsonSchemaParser):
             ):
                 continue
 
-            if any(field.original_name == parameter_name for field in fields):
+            if parameter_name in seen_parameter_names:
                 msg = f"Parameter name '{parameter_name}' is used more than once."
                 raise Exception(msg)  # noqa: TRY002
+            seen_parameter_names.add(parameter_name)
 
             field_name, alias = self.model_resolver.get_valid_field_name_and_alias(
                 field_name=parameter_name,
@@ -624,14 +535,25 @@ class OpenAPIParser(JsonSchemaParser):
                 class_name=name,
             )
             if parameter.schema_:
+                effective_default, effective_has_default = self.model_resolver.resolve_default_value(
+                    parameter_name,
+                    parameter.schema_.default,
+                    parameter.schema_.has_default,
+                    class_name=reference.name,
+                )
+                effective_required = parameter.required
+                if self.apply_default_values_for_required_fields and effective_has_default:
+                    effective_required = False
                 fields.append(
                     self.get_object_field(
                         field_name=field_name,
                         field=parameter.schema_,
                         field_type=self.parse_item(field_name, parameter.schema_, [*path, name, parameter_name]),
                         original_field_name=parameter_name,
-                        required=parameter.required,
+                        required=effective_required,
                         alias=alias,
+                        effective_default=effective_default,
+                        effective_has_default=effective_has_default,
                     )
                 )
             else:
@@ -660,29 +582,54 @@ class OpenAPIParser(JsonSchemaParser):
                     data_type = self.data_type(data_types=data_types)
                     # multiple data_type parse as non-constraints field
                     object_schema = None
+                original_default = object_schema.default if object_schema else None
+                original_has_default = object_schema.has_default if object_schema else False
+                effective_default, effective_has_default = self.model_resolver.resolve_default_value(
+                    parameter_name,
+                    original_default,
+                    original_has_default,
+                    class_name=reference.name,
+                )
+                effective_required = parameter.required
+                if self.apply_default_values_for_required_fields and effective_has_default:
+                    effective_required = False
+                # Handle multiple aliases (Pydantic v2 AliasChoices)
+                single_alias: str | None = None
+                validation_aliases: list[str] | None = None
+                if isinstance(alias, list):
+                    validation_aliases = alias
+                else:
+                    single_alias = alias
                 fields.append(
                     self.data_model_field_type(
                         name=field_name,
-                        default=object_schema.default if object_schema else None,
+                        default=effective_default,
                         data_type=data_type,
-                        required=parameter.required,
-                        alias=alias,
-                        constraints=object_schema.dict()
+                        required=effective_required,
+                        alias=single_alias,
+                        validation_aliases=validation_aliases,
+                        constraints=model_dump(object_schema, exclude_none=True)
                         if object_schema and self.is_constraints_field(object_schema)
                         else None,
                         nullable=object_schema.nullable
-                        if object_schema and self.strict_nullable and (object_schema.has_default or parameter.required)
-                        else None,
+                        if object_schema and self.strict_nullable and object_schema.nullable is not None
+                        else (
+                            False
+                            if object_schema and self.strict_nullable and (effective_has_default or effective_required)
+                            else None
+                        ),
                         strip_default_none=self.strip_default_none,
                         extras=self.get_field_extras(object_schema) if object_schema else {},
                         use_annotated=self.use_annotated,
                         use_serialize_as_any=self.use_serialize_as_any,
                         use_field_description=self.use_field_description,
+                        use_field_description_example=self.use_field_description_example,
                         use_inline_field_description=self.use_inline_field_description,
                         use_default_kwarg=self.use_default_kwarg,
                         original_name=parameter_name,
-                        has_default=object_schema.has_default if object_schema else False,
+                        has_default=effective_has_default,
                         type_has_null=object_schema.type_has_null if object_schema else None,
+                        use_serialization_alias=self.use_serialization_alias,
                     )
                 )
 
@@ -693,8 +640,9 @@ class OpenAPIParser(JsonSchemaParser):
                 self._create_data_model(
                     fields=fields,
                     reference=reference,
-                    custom_base_class=self.base_class,
+                    custom_base_class=self._resolve_base_class(name),
                     custom_template_dir=self.custom_template_dir,
+                    extra_template_data=self.extra_template_data,
                     keyword_only=self.keyword_only,
                     treat_dot_as_module=self.treat_dot_as_module,
                     dataclass_arguments=self.dataclass_arguments,
@@ -710,7 +658,7 @@ class OpenAPIParser(JsonSchemaParser):
         path: list[str],
     ) -> None:
         """Parse an OpenAPI operation including parameters, request body, and responses."""
-        operation = Operation.parse_obj(raw_operation)
+        operation = model_validate(Operation, raw_operation)
         path_name, method = path[-2:]
         if self.use_operation_id_as_name:
             if not operation.operationId:
@@ -731,7 +679,7 @@ class OpenAPIParser(JsonSchemaParser):
         if operation.requestBody:
             if isinstance(operation.requestBody, ReferenceObject):
                 ref_model = self.get_ref_model(operation.requestBody.ref)
-                request_body = RequestBodyObject.parse_obj(ref_model)
+                request_body = model_validate(RequestBodyObject, ref_model)
             else:
                 request_body = operation.requestBody
             self.parse_request_body(
@@ -751,7 +699,7 @@ class OpenAPIParser(JsonSchemaParser):
                 path=[*path, "tags"],
             )
 
-    def parse_raw(self) -> None:
+    def parse_raw(self) -> None:  # noqa: PLR0912
         """Parse OpenAPI specification including schemas, paths, and operations."""
         for source, path_parts in self._get_context_source_path_parts():
             if self.validation:
@@ -761,24 +709,33 @@ class OpenAPIParser(JsonSchemaParser):
                     stacklevel=2,
                 )
 
-                try:
-                    from prance import BaseParser  # noqa: PLC0415
-
-                    BaseParser(
-                        spec_string=source.text,
-                        backend="openapi-spec-validator",
-                        encoding=self.encoding,
-                    )
-                except ImportError:  # pragma: no cover
+                if source.raw_data is not None:
                     warn(
-                        "Warning: Validation was skipped for OpenAPI. `prance` or `openapi-spec-validator` are not "
-                        "installed.\n"
-                        "To use --validation option after datamodel-code-generator 0.24.0, Please run `$pip install "
-                        "'datamodel-code-generator[validation]'`.\n",
+                        "Warning: Validation was skipped for dict input. "
+                        "The --validation option only works with file or text input.\n",
                         stacklevel=2,
                     )
+                else:
+                    try:
+                        from prance import BaseParser  # noqa: PLC0415
 
-            specification: dict[str, Any] = load_yaml_dict(source.text)
+                        BaseParser(
+                            spec_string=source.text,
+                            backend="openapi-spec-validator",
+                            encoding=self.encoding,
+                        )
+                    except ImportError:  # pragma: no cover
+                        warn(
+                            "Warning: Validation was skipped for OpenAPI. "
+                            "`prance` or `openapi-spec-validator` are not installed.\n"
+                            "To use --validation option after datamodel-code-generator 0.24.0, "
+                            "Please run `$pip install 'datamodel-code-generator[validation]'`.\n",
+                            stacklevel=2,
+                        )
+
+            specification: dict[str, Any] = (
+                dict(source.raw_data) if source.raw_data is not None else load_data(source.text)
+            )
             self.raw_obj = specification
             self._collect_discriminator_schemas()
             schemas: dict[str, Any] = specification.get("components", {}).get("schemas", {})
@@ -809,28 +766,54 @@ class OpenAPIParser(JsonSchemaParser):
 
             if OpenAPIScope.Webhooks in self.open_api_scopes:
                 webhooks: dict[str, dict[str, Any]] = specification.get("webhooks", {})
-                self._process_path_items(webhooks, path_parts, "webhooks", [], security, strip_leading_slash=False)
+                self._process_path_items(
+                    webhooks, path_parts, "webhooks", [], security, strip_leading_slash=False, apply_path_filter=False
+                )
+
+            if OpenAPIScope.RequestBodies in self.open_api_scopes:
+                request_bodies: dict[str, Any] = specification.get("components", {}).get("requestBodies", {})
+                for body_name, raw_body in request_bodies.items():
+                    resolved_body = self.get_ref_model(raw_body["$ref"]) if "$ref" in raw_body else raw_body
+                    content = resolved_body.get("content", {})
+                    for media_type, media_obj in content.items():
+                        schema = media_obj.get("schema")
+                        if not schema:
+                            continue
+                        self.parse_raw_obj(
+                            body_name,
+                            schema,
+                            [
+                                *path_parts,
+                                "#/components",
+                                "requestBodies",
+                                body_name,
+                                "content",
+                                media_type,
+                                "schema",
+                            ],
+                        )
 
         self._resolve_unparsed_json_pointer()
 
     def _collect_discriminator_schemas(self) -> None:
         """Collect schemas with discriminators but no oneOf/anyOf, and find their subtypes."""
         schemas: dict[str, Any] = self.raw_obj.get("components", {}).get("schemas", {})
+        potential_subtypes: dict[str, list[str]] = {}
 
         for schema_name, schema in schemas.items():
             discriminator = schema.get("discriminator")
-            if not discriminator:
-                continue
+            if discriminator and not schema.get("oneOf") and not schema.get("anyOf"):
+                ref = f"#/components/schemas/{schema_name}"
+                self._discriminator_schemas[ref] = discriminator
 
-            if schema.get("oneOf") or schema.get("anyOf"):
-                continue
+            all_of = schema.get("allOf")
+            if all_of:
+                refs = [item.get("$ref") for item in all_of if item.get("$ref")]
+                if refs:
+                    potential_subtypes[schema_name] = refs
 
-            ref = f"#/components/schemas/{schema_name}"
-            self._discriminator_schemas[ref] = discriminator
-
-        for schema_name, schema in schemas.items():
-            for all_of_item in schema.get("allOf", []):
-                ref_in_allof = all_of_item.get("$ref")
-                if ref_in_allof and ref_in_allof in self._discriminator_schemas:
+        for schema_name, refs in potential_subtypes.items():
+            for ref_in_allof in refs:
+                if ref_in_allof in self._discriminator_schemas:
                     subtype_ref = f"#/components/schemas/{schema_name}"
                     self._discriminator_subtypes[ref_in_allof].append(subtype_ref)
