@@ -7,8 +7,10 @@ utilities for handling unions, optionals, and type hints.
 
 from __future__ import annotations
 
+import ast
 import re
 from abc import ABC, abstractmethod
+from copy import deepcopy
 from enum import Enum, auto
 from functools import lru_cache
 from itertools import chain
@@ -26,10 +28,11 @@ from typing import (
 
 import pydantic
 from packaging import version
-from pydantic import StrictBool, StrictInt, StrictStr, create_model
+from pydantic import Field, StrictBool, StrictInt, StrictStr, create_model
 from typing_extensions import TypeIs
 
 from datamodel_code_generator.format import (
+    DateClassType,
     DatetimeClassType,
     PythonVersion,
     PythonVersionMin,
@@ -37,6 +40,7 @@ from datamodel_code_generator.format import (
 from datamodel_code_generator.imports import (
     IMPORT_ABC_MAPPING,
     IMPORT_ABC_SEQUENCE,
+    IMPORT_ANNOTATED,
     IMPORT_ANY,
     IMPORT_DICT,
     IMPORT_FROZEN_SET,
@@ -51,7 +55,7 @@ from datamodel_code_generator.imports import (
     Import,
 )
 from datamodel_code_generator.reference import Reference, _BaseModel
-from datamodel_code_generator.util import PYDANTIC_V2, ConfigDict
+from datamodel_code_generator.util import ConfigDict, is_pydantic_v2
 
 T = TypeVar("T")
 SourceT = TypeVar("SourceT")
@@ -85,29 +89,34 @@ STR = "str"
 NOT_REQUIRED = "NotRequired"
 NOT_REQUIRED_PREFIX = f"{NOT_REQUIRED}["
 
+READ_ONLY = "ReadOnly"
+READ_ONLY_PREFIX = f"{READ_ONLY}["
+
+
+def __getattr__(name: str) -> Any:
+    """Provide lazy access to StrictTypes for backwards compatibility."""
+    if name == "StrictTypes":
+        from datamodel_code_generator.enums import StrictTypes  # noqa: PLC0415
+
+        return StrictTypes
+    msg = f"module {__name__!r} has no attribute {name!r}"
+    raise AttributeError(msg)
+
+
 if TYPE_CHECKING:
     import builtins
     from collections.abc import Callable, Iterable, Iterator, Sequence
 
     from pydantic_core import core_schema
 
+    from datamodel_code_generator.enums import StrictTypes
     from datamodel_code_generator.model.base import DataModelFieldBase
 
-if PYDANTIC_V2:
+if is_pydantic_v2():
     from pydantic import GetCoreSchemaHandler
     from pydantic_core import core_schema
 
 
-class StrictTypes(Enum):
-    """Strict type options for generated models."""
-
-    str = "str"
-    bytes = "bytes"
-    int = "int"
-    float = "float"
-    bool = "bool"
-
-
 class UnionIntFloat:
     """Pydantic-compatible type that accepts both int and float values."""
 
@@ -175,10 +184,117 @@ class UnionIntFloat:
 
 
 def chain_as_tuple(*iterables: Iterable[T]) -> tuple[T, ...]:
-    """Chain multiple iterables and return as a tuple."""
+    """Chain multiple iterables and return as a tuple.
+
+    Optimized for the common case of 2 iterables to avoid chain() overhead.
+    """
+    if len(iterables) == 2:  # noqa: PLR2004
+        return (*iterables[0], *iterables[1])
     return tuple(chain(*iterables))
 
 
+def get_type_base_name(type_str: str) -> str:
+    """Extract base type name from a type annotation string using AST.
+
+    Examples:
+        "List[str]" -> "List"
+        "foo.bar.Baz" -> "Baz"
+        "Optional[int]" -> "Optional"
+    """
+    try:
+        tree = ast.parse(type_str, mode="eval")
+    except SyntaxError:
+        return type_str.split("[", maxsplit=1)[0].rsplit(".", 1)[-1].strip()
+
+    body = tree.body
+    if isinstance(body, ast.Subscript):
+        body = body.value
+
+    if isinstance(body, ast.Attribute):
+        return body.attr
+    if isinstance(body, ast.Name):
+        return body.id
+    return type_str.split("[", maxsplit=1)[0].rsplit(".", 1)[-1].strip()
+
+
+def get_subscript_args(type_str: str) -> list[str]:
+    """Extract type arguments from a subscripted type using AST.
+
+    Examples:
+        "List[str]" -> ["str"]
+        "Dict[str, int]" -> ["str", "int"]
+        "Union[str, int, None]" -> ["str", "int", "None"]
+        "str | int | None" -> ["str", "int", "None"]
+        "str" -> []
+    """
+    try:
+        tree = ast.parse(type_str, mode="eval")
+    except SyntaxError:
+        return []
+
+    body = tree.body
+
+    if isinstance(body, ast.BinOp) and isinstance(body.op, ast.BitOr):
+        args: list[str] = []
+
+        def collect_union_args(node: ast.expr) -> None:
+            if isinstance(node, ast.BinOp) and isinstance(node.op, ast.BitOr):
+                collect_union_args(node.left)
+                collect_union_args(node.right)
+            else:
+                args.append(ast.unparse(node))
+
+        collect_union_args(body)
+        return args
+
+    if isinstance(body, ast.Subscript):
+        slice_node = body.slice
+        if isinstance(slice_node, ast.Tuple):
+            return [ast.unparse(elt) for elt in slice_node.elts]
+        return [ast.unparse(slice_node)]
+
+    return []
+
+
+def extract_qualified_names(type_str: str) -> list[str]:
+    """Extract all fully qualified names from a type annotation string using AST.
+
+    Finds patterns like 'module.path.ClassName' where the name contains dots.
+
+    Examples:
+        "type[foo.bar.Baz]" -> ["foo.bar.Baz"]
+        "Dict[a.B, c.D]" -> ["a.B", "c.D"]
+        "str" -> []
+    """
+    try:
+        tree = ast.parse(type_str, mode="eval")
+    except SyntaxError:
+        return []
+
+    qualified_names: list[str] = []
+    visited: set[int] = set()
+
+    def get_full_name(node: ast.expr) -> str | None:
+        parts: list[str] = []
+        current: ast.expr = node
+        while isinstance(current, ast.Attribute):
+            visited.add(id(current))
+            parts.append(current.attr)
+            current = current.value
+        if isinstance(current, ast.Name):
+            parts.append(current.id)
+            return ".".join(reversed(parts))
+        return None
+
+    for node in ast.walk(tree):
+        if isinstance(node, ast.Attribute) and id(node) not in visited:
+            name = get_full_name(node)
+            if name and "." in name:
+                qualified_names.append(name)
+
+    return qualified_names
+
+
 def _remove_none_from_union(type_: str, *, use_union_operator: bool) -> str:  # noqa: PLR0912
     """Remove None from a Union type string, handling nested unions."""
     if use_union_operator:
@@ -285,7 +401,7 @@ class Nullable(Protocol):
 class DataType(_BaseModel):
     """Represents a type in generated code with imports and references."""
 
-    if PYDANTIC_V2:
+    if is_pydantic_v2():
         # TODO[pydantic]: The following keys were removed: `copy_on_model_validation`.
         # Check https://docs.pydantic.dev/dev-v2/migration/#changes-to-config for more information.
         model_config = ConfigDict(  # pyright: ignore[reportAssignmentType]
@@ -293,7 +409,7 @@ class DataType(_BaseModel):
             revalidate_instances="never",
         )
     else:
-        if not TYPE_CHECKING:
+        if not TYPE_CHECKING:  # pragma: no branch
 
             @classmethod
             def model_rebuild(
@@ -313,7 +429,7 @@ class DataType(_BaseModel):
 
     type: Optional[str] = None  # noqa: UP045
     reference: Optional[Reference] = None  # noqa: UP045
-    data_types: list[DataType] = []  # noqa: RUF012
+    data_types: list[DataType] = Field(default_factory=list)
     is_func: bool = False
     kwargs: Optional[dict[str, Any]] = None  # noqa: UP045
     import_: Optional[Import] = None  # noqa: UP045
@@ -322,24 +438,60 @@ class DataType(_BaseModel):
     is_dict: bool = False
     is_list: bool = False
     is_set: bool = False
+    is_frozen_set: bool = False
+    is_mapping: bool = False
+    is_sequence: bool = False
     is_tuple: bool = False
     is_custom_type: bool = False
-    literals: list[Union[StrictBool, StrictInt, StrictStr]] = []  # noqa: RUF012, UP007
-    enum_member_literals: list[tuple[str, str]] = []  # noqa: RUF012  # [(EnumClassName, member_name), ...]
+    literals: list[Union[StrictBool, StrictInt, StrictStr]] = Field(default_factory=list)  # noqa: UP007
+    enum_member_literals: list[tuple[str, str]] = Field(default_factory=list)  # [(EnumClassName, member_name), ...]
     use_standard_collections: bool = False
     use_generic_container: bool = False
     use_union_operator: bool = False
     alias: Optional[str] = None  # noqa: UP045
     parent: Union[DataModelFieldBase, DataType, None] = None  # noqa: UP007
-    children: list[DataType] = []  # noqa: RUF012
+    children: list[DataType] = Field(default_factory=list)
     strict: bool = False
     dict_key: Optional[DataType] = None  # noqa: UP045
     treat_dot_as_module: bool = False
     use_serialize_as_any: bool = False
+    discriminator: Optional[str] = None  # noqa: UP045
 
     _exclude_fields: ClassVar[set[str]] = {"parent", "children"}
     _pass_fields: ClassVar[set[str]] = {"parent", "children", "data_types", "reference"}
 
+    def __deepcopy__(self, memo: dict[int, Any] | None = None) -> DataType:
+        """Create a deep copy handling circular references in parent/children fields."""
+        if memo is None:
+            memo = {}
+
+        obj_id = id(self)
+        if obj_id in memo:
+            return memo[obj_id]
+
+        cls = self.__class__
+        model_fields = getattr(cls, "model_fields" if is_pydantic_v2() else "__fields__")
+
+        shallow_kwargs: dict[str, Any] = {}
+        for field_name in model_fields:
+            value = getattr(self, field_name)
+            if field_name in self._exclude_fields:
+                shallow_kwargs[field_name] = None
+            else:
+                shallow_kwargs[field_name] = value
+
+        constructor = getattr(cls, "model_construct" if is_pydantic_v2() else "construct")
+        new_obj: DataType = constructor(**shallow_kwargs)
+        memo[obj_id] = new_obj
+
+        for field_name in model_fields:
+            if field_name not in self._exclude_fields:
+                value = getattr(self, field_name)
+                copied_value = deepcopy(value, memo)
+                object.__setattr__(new_obj, field_name, copied_value)
+
+        return new_obj
+
     @classmethod
     def from_import(  # noqa: PLR0913
         cls: builtins.type[DataTypeT],
@@ -422,11 +574,31 @@ class DataType(_BaseModel):
 
     @property
     def all_data_types(self) -> Iterator[DataType]:
-        """Recursively yield all nested DataTypes including self."""
+        """Recursively yield all nested DataTypes including self and dict_key."""
         for data_type in self.data_types:
             yield from data_type.all_data_types
+        if self.dict_key:
+            yield from self.dict_key.all_data_types
         yield self
 
+    def walk(
+        self,
+        visitor: Callable[[DataType], None],
+        visited: set[int] | None = None,
+    ) -> None:
+        """Recursively walk this DataType tree, calling visitor on each node."""
+        if visited is None:
+            visited = set()
+        node_id = id(self)
+        if node_id in visited:
+            return
+        visited.add(node_id)
+        visitor(self)
+        for child in self.data_types:
+            child.walk(visitor, visited)
+        if self.dict_key:
+            self.dict_key.walk(visitor, visited)
+
     def find_source(self, source_type: type[SourceT]) -> SourceT | None:
         """Find the first reference source matching the given type from all nested data types."""
         for data_type in self.all_data_types:  # pragma: no branch
@@ -451,11 +623,20 @@ class DataType(_BaseModel):
         if self.import_:
             yield self.import_
 
-        # Define required imports based on type features and conditions
         imports: tuple[tuple[bool, Import], ...] = (
             (self.is_optional and not self.use_union_operator, IMPORT_OPTIONAL),
             (len(self.data_types) > 1 and not self.use_union_operator, IMPORT_UNION),
             (bool(self.literals) or bool(self.enum_member_literals), IMPORT_LITERAL),
+            (bool(self.discriminator), IMPORT_ANNOTATED),
+        )
+
+        imports = (
+            *imports,
+            (self.is_frozen_set and not self.use_standard_collections, IMPORT_FROZEN_SET),
+            (self.is_mapping and self.use_standard_collections, IMPORT_ABC_MAPPING),
+            (self.is_mapping and not self.use_standard_collections, IMPORT_MAPPING),
+            (self.is_sequence and self.use_standard_collections, IMPORT_ABC_SEQUENCE),
+            (self.is_sequence and not self.use_standard_collections, IMPORT_SEQUENCE),
         )
 
         if self.use_generic_container:
@@ -485,7 +666,7 @@ class DataType(_BaseModel):
 
         # Yield imports based on conditions
         for field, import_ in imports:
-            if field and import_ != self.import_:
+            if field and import_ is not None and import_ != self.import_:
                 yield import_
 
         # Propagate imports from any dict_key type
@@ -494,15 +675,25 @@ class DataType(_BaseModel):
 
     def __init__(self, **values: Any) -> None:
         """Initialize DataType with validation and reference setup."""
-        if not TYPE_CHECKING:
+        if not TYPE_CHECKING:  # pragma: no cover
             super().__init__(**values)
 
+        # Single-pass optimization: detect ANY+optional and non-ANY types together
+        # This is a rare edge case optimization - pragma: no cover
+        any_optional_found = False
+        has_non_any = False
         for type_ in self.data_types:
             if type_.type == ANY and type_.is_optional:
-                if any(t for t in self.data_types if t.type != ANY):  # pragma: no cover
-                    self.is_optional = True
-                    self.data_types = [t for t in self.data_types if not (t.type == ANY and t.is_optional)]
-                break  # pragma: no cover
+                any_optional_found = True  # pragma: no cover
+            elif type_.type != ANY:
+                has_non_any = True
+            # Early exit if both conditions met
+            if any_optional_found and has_non_any:  # pragma: no cover
+                break
+
+        if any_optional_found and has_non_any:  # pragma: no cover
+            self.is_optional = True
+            self.data_types = [t for t in self.data_types if not (t.type == ANY and t.is_optional)]
 
         for data_type in self.data_types:
             if data_type.reference or data_type.data_types:
@@ -559,6 +750,8 @@ class DataType(_BaseModel):
                     type_ = UNION_OPERATOR_DELIMITER.join(data_types)
                 else:
                     type_ = f"{UNION_PREFIX}{UNION_DELIMITER.join(data_types)}]"
+                if self.discriminator:
+                    type_ = f"Annotated[{type_}, Field(discriminator={self.discriminator!r})]"
             elif len(self.data_types) == 1:
                 type_ = self.data_types[0].type_hint
             elif self.enum_member_literals:
@@ -574,16 +767,12 @@ class DataType(_BaseModel):
                 type_ = ""
         if self.reference:
             source = self.reference.source
-            if isinstance(source, Nullable) and source.nullable:
+            is_alias = getattr(source, "is_alias", False)
+            if isinstance(source, Nullable) and source.nullable and not is_alias:
                 self.is_optional = True
-        if self.is_list:
-            if self.use_generic_container:
-                list_ = SEQUENCE
-            elif self.use_standard_collections:
-                list_ = STANDARD_LIST
-            else:
-                list_ = LIST
-            type_ = f"{list_}[{type_}]" if type_ else list_
+        if self.is_frozen_set:
+            set_ = STANDARD_FROZEN_SET if self.use_standard_collections else FROZEN_SET
+            type_ = f"{set_}[{type_}]" if type_ else set_
         elif self.is_set:
             if self.use_generic_container:
                 set_ = STANDARD_FROZEN_SET if self.use_standard_collections else FROZEN_SET
@@ -592,6 +781,24 @@ class DataType(_BaseModel):
             else:
                 set_ = SET
             type_ = f"{set_}[{type_}]" if type_ else set_
+        elif self.is_sequence:
+            list_ = SEQUENCE
+            type_ = f"{list_}[{type_}]" if type_ else list_
+        elif self.is_list:
+            if self.use_generic_container:
+                list_ = SEQUENCE
+            elif self.use_standard_collections:
+                list_ = STANDARD_LIST
+            else:
+                list_ = LIST
+            type_ = f"{list_}[{type_}]" if type_ else list_
+        elif self.is_mapping:
+            dict_ = MAPPING
+            if self.dict_key or type_:
+                key = self.dict_key.type_hint if self.dict_key else STR
+                type_ = f"{dict_}[{key}, {type_ or ANY}]"
+            else:  # pragma: no cover
+                type_ = dict_
         elif self.is_dict:
             if self.use_generic_container:
                 dict_ = MAPPING
@@ -618,6 +825,125 @@ class DataType(_BaseModel):
         """Return whether this DataType represents a union of multiple types."""
         return len(self.data_types) > 1
 
+    # Mapping from constrained type functions to their base Python types.
+    # Only constr is included because it's the only type with a 'pattern' parameter
+    # that can trigger lookaround regex detection. Other constrained types (conint,
+    # confloat, condecimal, conbytes) don't have pattern constraints, so they will
+    # never need base_type_hint conversion in the regex_engine context.
+    _CONSTRAINED_TYPE_TO_BASE: ClassVar[dict[str, str]] = {
+        "constr": "str",
+    }
+
+    @property
+    def base_type_hint(self) -> str:  # noqa: PLR0912, PLR0915
+        """Return the base type hint without constrained type kwargs.
+
+        For types like constr(pattern=..., min_length=...), this returns just 'str'.
+        This works recursively for nested types like list[constr(pattern=...)] -> list[str].
+
+        This is useful when the pattern contains lookaround assertions that require
+        regex_engine="python-re", which must be set in model_config. In such cases,
+        the RootModel generic cannot use the constrained type because it would be
+        evaluated at class definition time before model_config is processed.
+        """
+        if self.is_func and self.kwargs:
+            type_: str | None = self.alias or self.type
+            if type_:  # pragma: no branch
+                base_type = self._CONSTRAINED_TYPE_TO_BASE.get(type_)
+                if base_type is None:
+                    # Not a constrained type we convert (e.g., conint, confloat)
+                    # Return the full type_hint with kwargs to avoid returning bare function name
+                    return self.type_hint
+                if self.is_optional and base_type != ANY:  # pragma: no cover
+                    return get_optional_type(base_type, self.use_union_operator)
+                return base_type
+
+        type_: str | None = self.alias or self.type
+        if not type_:
+            if self.is_tuple:  # pragma: no cover
+                tuple_type = STANDARD_TUPLE if self.use_standard_collections else TUPLE
+                inner_types = [item.base_type_hint or ANY for item in self.data_types]
+                type_ = f"{tuple_type}[{', '.join(inner_types)}]" if inner_types else f"{tuple_type}[()]"
+            elif self.is_union:
+                data_types: list[str] = []
+                for data_type in self.data_types:
+                    data_type_type = data_type.base_type_hint
+                    if not data_type_type or data_type_type in data_types:  # pragma: no cover
+                        continue
+
+                    if data_type_type == NONE:
+                        self.is_optional = True
+                        continue
+
+                    non_optional_data_type_type = _remove_none_from_union(
+                        data_type_type, use_union_operator=self.use_union_operator
+                    )
+
+                    if non_optional_data_type_type != data_type_type:  # pragma: no cover
+                        self.is_optional = True
+
+                    data_types.append(non_optional_data_type_type)
+                if not data_types:  # pragma: no cover
+                    type_ = ANY
+                    self.import_ = self.import_ or IMPORT_ANY
+                elif len(data_types) == 1:
+                    type_ = data_types[0]
+                elif self.use_union_operator:
+                    type_ = UNION_OPERATOR_DELIMITER.join(data_types)
+                else:  # pragma: no cover
+                    type_ = f"{UNION_PREFIX}{UNION_DELIMITER.join(data_types)}]"
+            elif len(self.data_types) == 1:
+                type_ = self.data_types[0].base_type_hint
+            elif self.enum_member_literals:  # pragma: no cover
+                parts = [f"{enum_class}.{member}" for enum_class, member in self.enum_member_literals]
+                type_ = f"{LITERAL}[{', '.join(parts)}]"
+            elif self.literals:  # pragma: no cover
+                type_ = f"{LITERAL}[{', '.join(repr(literal) for literal in self.literals)}]"
+            elif self.reference:  # pragma: no cover
+                type_ = self.reference.short_name
+                type_ = self._get_wrapped_reference_type_hint(type_)
+            else:  # pragma: no cover
+                type_ = ""
+        if self.reference:  # pragma: no cover
+            source = self.reference.source
+            is_alias = getattr(source, "is_alias", False)
+            if isinstance(source, Nullable) and source.nullable and not is_alias:
+                self.is_optional = True
+        if self.is_list:
+            if self.use_generic_container:
+                list_ = SEQUENCE
+            elif self.use_standard_collections:
+                list_ = STANDARD_LIST
+            else:  # pragma: no cover
+                list_ = LIST
+            type_ = f"{list_}[{type_}]" if type_ else list_
+        elif self.is_set:  # pragma: no cover
+            if self.use_generic_container:
+                set_ = STANDARD_FROZEN_SET if self.use_standard_collections else FROZEN_SET
+            elif self.use_standard_collections:
+                set_ = STANDARD_SET
+            else:
+                set_ = SET
+            type_ = f"{set_}[{type_}]" if type_ else set_
+        elif self.is_dict:
+            if self.use_generic_container:
+                dict_ = MAPPING
+            elif self.use_standard_collections:
+                dict_ = STANDARD_DICT
+            else:  # pragma: no cover
+                dict_ = DICT
+            if self.dict_key or type_:
+                key = self.dict_key.base_type_hint if self.dict_key else STR
+                type_ = f"{dict_}[{key}, {type_ or ANY}]"
+            else:  # pragma: no cover
+                type_ = dict_
+
+        if self.is_optional and type_ != ANY:
+            return get_optional_type(type_, self.use_union_operator)
+        if self.is_func:  # pragma: no cover
+            return f"{type_}()"
+        return type_
+
 
 DataTypeT = TypeVar("DataTypeT", bound=DataType)
 
@@ -642,6 +968,8 @@ class Types(Enum):
     binary = auto()
     date = auto()
     date_time = auto()
+    date_time_local = auto()
+    time_local = auto()
     timedelta = auto()
     password = auto()
     path = auto()
@@ -652,6 +980,7 @@ class Types(Enum):
     uuid3 = auto()
     uuid4 = auto()
     uuid5 = auto()
+    ulid = auto()
     uri = auto()
     hostname = auto()
     ipv4 = auto()
@@ -671,6 +1000,11 @@ class DataTypeManager(ABC):
     Subclasses implement get_data_type() to map schema types to DataType objects.
     """
 
+    HOSTNAME_REGEX: ClassVar[str] = (
+        r"^(([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]{0,61}[a-zA-Z0-9])\.)*"
+        r"([A-Za-z0-9]|[A-Za-z0-9][A-Za-z0-9\-]{0,61}[A-Za-z0-9])$"
+    )
+
     def __init__(  # noqa: PLR0913, PLR0917
         self,
         python_version: PythonVersion = PythonVersionMin,
@@ -681,8 +1015,10 @@ class DataTypeManager(ABC):
         use_decimal_for_multiple_of: bool = False,  # noqa: FBT001, FBT002
         use_union_operator: bool = False,  # noqa: FBT001, FBT002
         use_pendulum: bool = False,  # noqa: FBT001, FBT002
+        use_standard_primitive_types: bool = False,  # noqa: FBT001, FBT002, ARG002
         target_datetime_class: DatetimeClassType | None = None,
-        treat_dot_as_module: bool = False,  # noqa: FBT001, FBT002
+        target_date_class: DateClassType | None = None,
+        treat_dot_as_module: bool | None = None,  # noqa: FBT001
         use_serialize_as_any: bool = False,  # noqa: FBT001, FBT002
     ) -> None:
         """Initialize DataTypeManager with code generation options."""
@@ -697,7 +1033,8 @@ class DataTypeManager(ABC):
         self.use_union_operator: bool = use_union_operator
         self.use_pendulum: bool = use_pendulum
         self.target_datetime_class: DatetimeClassType | None = target_datetime_class
-        self.treat_dot_as_module: bool = treat_dot_as_module
+        self.target_date_class: DateClassType | None = target_date_class
+        self.treat_dot_as_module: bool = treat_dot_as_module or False
         self.use_serialize_as_any: bool = use_serialize_as_any
 
         self.data_type: type[DataType] = create_model(
