@@ -4,25 +4,24 @@ Custom module docstring header.
 This is a multi-line docstring used for testing.
 """
 
-
 from __future__ import annotations
 
-from typing import Any, Dict, List, Optional
+from typing import Any
 
 from pydantic import BaseModel
 
 
 class Thing(BaseModel):
-    attributes: Optional[Dict[str, Any]] = None
+    attributes: dict[str, Any] | None = None
 
 
 class Thang(BaseModel):
-    attributes: Optional[List[Dict[str, Any]]] = None
+    attributes: list[dict[str, Any]] | None = None
 
 
 class Others(BaseModel):
-    name: Optional[str] = None
+    name: str | None = None
 
 
 class Clone(Thing):
-    others: Optional[Others] = None
+    others: Others | None = None
