@@ -7,7 +7,7 @@ from typing import TYPE_CHECKING
 import black
 import pytest
 
-from tests.main.conftest import GRAPHQL_DATA_PATH, LEGACY_BLACK_SKIP, run_main_and_assert
+from tests.main.conftest import DEFAULT_VALUES_DATA_PATH, GRAPHQL_DATA_PATH, LEGACY_BLACK_SKIP, run_main_and_assert
 from tests.main.graphql.conftest import assert_file_content
 
 if TYPE_CHECKING:
@@ -29,6 +29,10 @@ if TYPE_CHECKING:
 )
 @pytest.mark.cli_doc(
     options=["--output-model-type"],
+    option_description="""Generate models from GraphQL with different output model types.
+
+This example demonstrates using `--output-model-type` with GraphQL schemas
+to generate either Pydantic models or dataclasses.""",
     input_schema="graphql/simple-star-wars.graphql",
     cli_args=["--output-model-type", "pydantic.BaseModel"],
     model_outputs={
@@ -74,6 +78,11 @@ def test_main_graphql_different_types_of_fields(output_file: Path) -> None:
 
 @pytest.mark.cli_doc(
     options=["--use-default-kwarg"],
+    option_description="""Use default= keyword argument instead of positional argument for fields with defaults.
+
+The `--use-default-kwarg` flag generates Field() declarations using `default=`
+as a keyword argument instead of a positional argument for fields that have
+default values.""",
     input_schema="graphql/annotated.graphql",
     cli_args=["--use-default-kwarg"],
     golden_output="graphql/annotated_use_default_kwarg.py",
@@ -117,12 +126,20 @@ def test_main_graphql_custom_scalar_types(output_file: Path) -> None:
 )
 @pytest.mark.cli_doc(
     options=["--aliases"],
+    option_description="""Apply custom field and class name aliases from JSON file.
+
+The `--aliases` option allows you to rename fields using a JSON mapping file.
+Supports hierarchical formats for scoped or global aliasing.""",
     input_schema="graphql/field-aliases.graphql",
     cli_args=["--aliases", "graphql/field-aliases.json"],
     golden_output="graphql/field_aliases.py",
 )
 def test_main_graphql_field_aliases(output_file: Path) -> None:
-    """Test GraphQL code generation with field aliases."""
+    """Apply custom field and class name aliases from JSON file.
+
+    The `--aliases` option allows you to rename fields using a JSON mapping file.
+    Supports hierarchical formats for scoped or global aliasing.
+    """
     run_main_and_assert(
         input_path=GRAPHQL_DATA_PATH / "field-aliases.graphql",
         output_path=output_file,
@@ -133,6 +150,27 @@ def test_main_graphql_field_aliases(output_file: Path) -> None:
     )
 
 
+@pytest.mark.skipif(
+    black.__version__.split(".")[0] == "19",
+    reason="Installed black doesn't support the old style",
+)
+def test_main_graphql_multiple_aliases_pydantic_v2(output_file: Path) -> None:
+    """Test GraphQL with multiple aliases using Pydantic v2 AliasChoices."""
+    run_main_and_assert(
+        input_path=GRAPHQL_DATA_PATH / "multiple-aliases.graphql",
+        output_path=output_file,
+        input_file_type="graphql",
+        assert_func=assert_file_content,
+        expected_file="graphql_multiple_aliases_pydantic_v2.py",
+        extra_args=[
+            "--aliases",
+            str(GRAPHQL_DATA_PATH / "multiple-aliases.json"),
+            "--output-model-type",
+            "pydantic_v2.BaseModel",
+        ],
+    )
+
+
 @pytest.mark.skipif(
     black.__version__.split(".")[0] == "19",
     reason="Installed black doesn't support the old style",
@@ -181,6 +219,11 @@ def test_main_graphql_specialized_enums(output_file: Path) -> None:
 
 @pytest.mark.cli_doc(
     options=["--enum-field-as-literal"],
+    option_description="""Convert all enum fields to Literal types instead of Enum classes.
+
+The `--enum-field-as-literal all` flag converts all enum types to Literal
+type annotations. This is useful when you want string literal types instead
+of Enum classes for all enumerations.""",
     input_schema="graphql/enums.graphql",
     cli_args=["--enum-field-as-literal", "all"],
     golden_output="graphql/enum_literals_all.py",
@@ -205,6 +248,10 @@ def test_main_graphql_enums_as_literals_all(output_file: Path) -> None:
 
 @pytest.mark.cli_doc(
     options=["--enum-field-as-literal"],
+    option_description="""Convert single-member enums to Literal types.
+
+The `--enum-field-as-literal one` flag only converts enums with a single
+member to Literal types, keeping multi-member enums as Enum classes.""",
     input_schema="graphql/enums.graphql",
     cli_args=["--enum-field-as-literal", "one"],
     golden_output="graphql/enum_literals_one.py",
@@ -239,6 +286,12 @@ def test_main_graphql_enums_to_typed_dict(output_file: Path) -> None:
 
 @pytest.mark.cli_doc(
     options=["--ignore-enum-constraints"],
+    option_description="""Ignore enum constraints and use base string type instead of Enum classes.
+
+The `--ignore-enum-constraints` flag ignores enum constraints and uses
+the base type (str) instead of generating Enum classes. This is useful
+when you need flexibility in the values a field can accept beyond the
+defined enum members.""",
     input_schema="graphql/enums.graphql",
     cli_args=["--ignore-enum-constraints"],
     golden_output="graphql/enums_ignore_enum_constraints.py",
@@ -268,6 +321,11 @@ def test_main_graphql_enums_ignore_enum_constraints(output_file: Path) -> None:
 )
 @pytest.mark.cli_doc(
     options=["--no-use-specialized-enum"],
+    option_description="""Disable specialized Enum classes for Python 3.11+ code generation.
+
+The `--no-use-specialized-enum` flag prevents the generator from using
+specialized Enum classes (StrEnum, IntEnum) when generating code for
+Python 3.11+, falling back to standard Enum classes instead.""",
     input_schema="graphql/enums.graphql",
     cli_args=["--target-python-version", "3.11", "--no-use-specialized-enum"],
     golden_output="graphql/enums_no_specialized.py",
@@ -296,6 +354,11 @@ def test_main_graphql_specialized_enums_disabled(output_file: Path) -> None:
 )
 @pytest.mark.cli_doc(
     options=["--use-subclass-enum"],
+    option_description="""Generate typed Enum subclasses for enums with specific field types.
+
+The `--use-subclass-enum` flag generates Enum classes as subclasses of the
+appropriate field type (int, float, bytes, str) when an enum has a specific
+type, providing better type safety and IDE support.""",
     input_schema="graphql/enums.graphql",
     cli_args=["--use-subclass-enum"],
     golden_output="graphql/enums_using_subclass.py",
@@ -338,6 +401,12 @@ def test_main_graphql_union(output_file: Path) -> None:
 )
 @pytest.mark.cli_doc(
     options=["--additional-imports"],
+    option_description="""Add custom imports to generated output files.
+
+The `--additional-imports` flag allows you to specify custom imports as a
+comma-delimited list that will be added to the generated output file. This
+is useful when using custom types defined in external modules (e.g.,
+"datetime.datetime,datetime.date,mymodule.myclass.MyCustomPythonClass").""",
     input_schema="graphql/additional-imports.graphql",
     cli_args=["--additional-imports", "datetime.datetime,datetime.date,mymodule.myclass.MyCustomPythonClass"],
     golden_output="graphql/additional_imports.py",
@@ -365,12 +434,78 @@ def test_main_graphql_additional_imports(output_file: Path) -> None:
     )
 
 
+@pytest.mark.skipif(
+    black.__version__.split(".")[0] == "19",
+    reason="Installed black doesn't support the old style",
+)
+def test_main_graphql_additional_imports_in_extra_template_data(output_file: Path) -> None:
+    """Test additional_imports specified in extra-template-data JSON file (string format)."""
+    run_main_and_assert(
+        input_path=GRAPHQL_DATA_PATH / "additional-imports.graphql",
+        output_path=output_file,
+        input_file_type="graphql",
+        assert_func=assert_file_content,
+        expected_file="additional_imports.py",
+        extra_args=[
+            "--extra-template-data",
+            str(GRAPHQL_DATA_PATH / "additional-imports-in-extra-template-data.json"),
+        ],
+    )
+
+
+@pytest.mark.skipif(
+    black.__version__.split(".")[0] == "19",
+    reason="Installed black doesn't support the old style",
+)
+def test_main_graphql_additional_imports_in_extra_template_data_list_format(output_file: Path) -> None:
+    """Test additional_imports specified in extra-template-data JSON file (list format)."""
+    run_main_and_assert(
+        input_path=GRAPHQL_DATA_PATH / "additional-imports.graphql",
+        output_path=output_file,
+        input_file_type="graphql",
+        assert_func=assert_file_content,
+        expected_file="additional_imports.py",
+        extra_args=[
+            "--extra-template-data",
+            str(GRAPHQL_DATA_PATH / "additional-imports-list-format.json"),
+        ],
+    )
+
+
+@pytest.mark.skipif(
+    black.__version__.split(".")[0] == "19",
+    reason="Installed black doesn't support the old style",
+)
+def test_main_graphql_additional_imports_merged(output_file: Path) -> None:
+    """Test merging additional_imports from CLI and extra-template-data JSON."""
+    run_main_and_assert(
+        input_path=GRAPHQL_DATA_PATH / "additional-imports.graphql",
+        output_path=output_file,
+        input_file_type="graphql",
+        assert_func=assert_file_content,
+        expected_file="additional_imports.py",
+        extra_args=[
+            "--extra-template-data",
+            str(GRAPHQL_DATA_PATH / "additional-imports-partial.json"),
+            "--additional-imports",
+            "datetime.date,mymodule.myclass.MyCustomPythonClass",
+        ],
+    )
+
+
 @pytest.mark.skipif(
     black.__version__.split(".")[0] == "19",
     reason="Installed black doesn't support the old style",
 )
 @pytest.mark.cli_doc(
     options=["--custom-formatters"],
+    option_description="""Apply custom Python code formatters to generated output.
+
+The `--custom-formatters` flag allows you to specify custom Python functions
+that will be applied to format the generated code. The formatter is specified
+as a module path (e.g., "mymodule.formatter_function"). This is useful for
+adding custom comments, modifying code structure, or applying project-specific
+formatting rules beyond what black/isort provide.""",
     input_schema="graphql/custom-scalar-types.graphql",
     cli_args=["--custom-formatters", "tests.data.python.custom_formatters.add_comment"],
     golden_output="graphql/custom_formatters.py",
@@ -428,6 +563,11 @@ def test_main_graphql_use_union_operator(output_file: Path) -> None:
 
 @pytest.mark.cli_doc(
     options=["--extra-fields"],
+    option_description="""Configure how generated models handle extra fields not defined in schema.
+
+The `--extra-fields` flag sets the generated models to allow, forbid, or
+ignore extra fields. With `--extra-fields allow`, models will accept and
+store fields not defined in the schema. Options: allow, ignore, forbid.""",
     input_schema="graphql/simple-star-wars.graphql",
     cli_args=["--extra-fields", "allow"],
     golden_output="graphql/simple_star_wars_extra_fields_allow.py",
@@ -451,6 +591,12 @@ def test_main_graphql_extra_fields_allow(output_file: Path) -> None:
 
 @pytest.mark.cli_doc(
     options=["--use-type-alias"],
+    option_description="""Use TypeAlias instead of root models for type definitions (experimental).
+
+The `--use-type-alias` flag generates TypeAlias declarations instead of
+root model classes for certain type definitions. For Python 3.10-3.11, it
+generates TypeAliasType, and for Python 3.12+, it uses the 'type' statement
+syntax. This feature is experimental.""",
     input_schema="graphql/type_alias.graphql",
     cli_args=["--use-type-alias"],
     golden_output="graphql/type_alias.py",
@@ -502,6 +648,12 @@ def test_main_graphql_type_alias_py312(output_file: Path) -> None:
 )
 @pytest.mark.cli_doc(
     options=["--dataclass-arguments"],
+    option_description="""Customize dataclass decorator arguments via JSON dictionary.
+
+The `--dataclass-arguments` flag accepts custom dataclass arguments as a JSON
+dictionary (e.g., '{"frozen": true, "kw_only": true, "slots": true, "order": true}').
+This overrides individual flags like --frozen-dataclasses and provides fine-grained
+control over dataclass generation.""",
     input_schema="graphql/simple-star-wars.graphql",
     cli_args=[
         "--output-model-type",
@@ -565,6 +717,13 @@ def test_main_graphql_dataclass_arguments_with_pydantic(output_file: Path) -> No
 )
 @pytest.mark.cli_doc(
     options=["--keyword-only"],
+    option_description="""Generate dataclasses with keyword-only fields (Python 3.10+).
+
+The `--keyword-only` flag generates dataclasses where all fields must be
+specified as keyword arguments (kw_only=True). This is only available for
+Python 3.10+. When combined with `--frozen-dataclasses`, it creates immutable
+dataclasses with keyword-only arguments, improving code clarity and preventing
+positional argument errors.""",
     input_schema="graphql/simple-star-wars.graphql",
     cli_args=[
         "--output-model-type",
@@ -582,9 +741,9 @@ def test_main_graphql_dataclass_frozen_keyword_only(output_file: Path) -> None:
 
     The `--keyword-only` flag generates dataclasses where all fields must be
     specified as keyword arguments (kw_only=True). This is only available for
-    Python 3.10+. When combined with `--frozen`, it creates immutable dataclasses
-    with keyword-only arguments, improving code clarity and preventing positional
-    argument errors.
+    Python 3.10+. When combined with `--frozen-dataclasses`, it creates immutable
+    dataclasses with keyword-only arguments, improving code clarity and preventing
+    positional argument errors.
     """
     run_main_and_assert(
         input_path=GRAPHQL_DATA_PATH / "simple-star-wars.graphql",
@@ -595,9 +754,72 @@ def test_main_graphql_dataclass_frozen_keyword_only(output_file: Path) -> None:
         extra_args=[
             "--output-model-type",
             "dataclasses.dataclass",
-            "--frozen",
+            "--frozen-dataclasses",
             "--keyword-only",
             "--target-python-version",
             "3.10",
         ],
     )
+
+
+def test_main_graphql_union_snake_case_field(output_file: Path) -> None:
+    """Test that union type references are not converted to snake_case."""
+    run_main_and_assert(
+        input_path=GRAPHQL_DATA_PATH / "union.graphql",
+        output_path=output_file,
+        input_file_type="graphql",
+        assert_func=assert_file_content,
+        expected_file="union_snake_case_field.py",
+        extra_args=["--snake-case-field", "--output-model-type", "pydantic_v2.BaseModel"],
+    )
+
+
+def test_main_graphql_split_graphql_schemas(output_file: Path) -> None:
+    """Test GraphQL code generation with multiple schema files in a directory."""
+    run_main_and_assert(
+        input_path=GRAPHQL_DATA_PATH / "split",
+        output_path=output_file,
+        input_file_type="graphql",
+        assert_func=assert_file_content,
+        expected_file="split_graphql_schemas.py",
+    )
+
+
+def test_main_graphql_use_default_with_default_values(output_file: Path) -> None:
+    """Test --use-default combined with --default-values on required GraphQL fields."""
+    run_main_and_assert(
+        input_path=GRAPHQL_DATA_PATH / "default_values_required.graphql",
+        output_path=output_file,
+        input_file_type="graphql",
+        assert_func=assert_file_content,
+        expected_file="default_values_required_use_default.py",
+        extra_args=[
+            "--use-default",
+            "--default-values",
+            str(DEFAULT_VALUES_DATA_PATH / "graphql_user_defaults.json"),
+        ],
+    )
+
+
+@pytest.mark.cli_doc(
+    options=["--graphql-no-typename"],
+    option_description="""Exclude __typename field from generated GraphQL models.
+
+The `--graphql-no-typename` flag prevents the generator from adding the
+`typename__` field (aliased to `__typename`) to generated models. This is
+useful when using generated models for GraphQL mutations, as servers typically
+don't expect this field in input data.""",
+    input_schema="graphql/no-typename.graphql",
+    cli_args=["--graphql-no-typename"],
+    golden_output="graphql/no_typename.py",
+)
+def test_main_graphql_no_typename(output_file: Path) -> None:
+    """Test that --graphql-no-typename excludes typename__ field from all types."""
+    run_main_and_assert(
+        input_path=GRAPHQL_DATA_PATH / "no-typename.graphql",
+        output_path=output_file,
+        input_file_type="graphql",
+        assert_func=assert_file_content,
+        expected_file="no_typename.py",
+        extra_args=["--graphql-no-typename"],
+    )
