@@ -24,6 +24,7 @@ from datamodel_code_generator.model.pydantic.imports import (
 )
 from datamodel_code_generator.model.pydantic.types import DataTypeManager
 from datamodel_code_generator.types import DataType, Types, UnionIntFloat
+from datamodel_code_generator.util import model_dump
 
 
 @pytest.mark.parametrize(
@@ -143,8 +144,8 @@ def test_get_data_int_type(
     data_type_manager = DataTypeManager(
         use_non_positive_negative_number_constrained_types=use_non_positive_negative_number_constrained_types
     )
-    assert (
-        data_type_manager.get_data_int_type(types, **params).dict() == data_type_manager.data_type(**data_type).dict()
+    assert model_dump(data_type_manager.get_data_int_type(types, **params)) == model_dump(
+        data_type_manager.data_type(**data_type)
     )
 
 
@@ -344,6 +345,49 @@ def test_get_data_decimal_type(types: Types, params: dict[str, Any], data_type:
     assert data_type_manager.get_data_decimal_type(types, **params) == data_type_manager.data_type(**data_type)
 
 
+@pytest.mark.parametrize(
+    ("types", "params", "data_type"),
+    [
+        (
+            Types.float,
+            {"multipleOf": 0.1},
+            {
+                "type": "condecimal",
+                "is_func": True,
+                "kwargs": {"multiple_of": Decimal("0.1")},
+                "import_": IMPORT_CONDECIMAL,
+            },
+        ),
+        (
+            Types.float,
+            {"multipleOf": 0.1, "minimum": 0, "maximum": 100},
+            {
+                "type": "condecimal",
+                "is_func": True,
+                "kwargs": {"multiple_of": Decimal("0.1"), "ge": Decimal(0), "le": Decimal(100)},
+                "import_": IMPORT_CONDECIMAL,
+            },
+        ),
+        (
+            Types.number,
+            {"multipleOf": 0.01, "exclusiveMinimum": 0},
+            {
+                "type": "condecimal",
+                "is_func": True,
+                "kwargs": {"multiple_of": Decimal("0.01"), "gt": Decimal(0)},
+                "import_": IMPORT_CONDECIMAL,
+            },
+        ),
+    ],
+)
+def test_get_data_float_type_with_use_decimal_for_multiple_of(
+    types: Types, params: dict[str, Any], data_type: dict[str, Any]
+) -> None:
+    """Test float type uses condecimal when use_decimal_for_multiple_of is True."""
+    data_type_manager = DataTypeManager(use_decimal_for_multiple_of=True)
+    assert data_type_manager.get_data_float_type(types, **params) == data_type_manager.data_type(**data_type)
+
+
 @pytest.mark.parametrize(
     ("types", "params", "data_type"),
     [
