@@ -25,6 +25,7 @@ from datamodel_code_generator.parser.jsonschema import (
 )
 from datamodel_code_generator.reference import SPECIAL_PATH_MARKER, Reference
 from datamodel_code_generator.types import DataType
+from datamodel_code_generator.util import model_dump, model_validate
 from tests.conftest import assert_output
 
 if TYPE_CHECKING:
@@ -53,7 +54,7 @@ def test_get_model_by_path(schema: dict, path: str, model: dict) -> None:
 def test_json_schema_object_ref_url_json(mocker: MockerFixture) -> None:
     """Test JSON schema object reference with JSON URL."""
     parser = JsonSchemaParser("")
-    obj = JsonSchemaObject.parse_obj({"$ref": "https://example.com/person.schema.json#/definitions/User"})
+    obj = model_validate(JsonSchemaObject, {"$ref": "https://example.com/person.schema.json#/definitions/User"})
     mock_get = mocker.patch("httpx.get")
     mock_get.return_value.text = json.dumps(
         {
@@ -86,6 +87,7 @@ def test_json_schema_object_ref_url_json(mocker: MockerFixture) -> None:
             verify=True,
             follow_redirects=True,
             params=None,
+            timeout=30.0,
         ),
     ])
 
@@ -93,7 +95,7 @@ def test_json_schema_object_ref_url_json(mocker: MockerFixture) -> None:
 def test_json_schema_object_ref_url_yaml(mocker: MockerFixture) -> None:
     """Test JSON schema object reference with YAML URL."""
     parser = JsonSchemaParser("")
-    obj = JsonSchemaObject.parse_obj({"$ref": "https://example.org/schema.yaml#/definitions/User"})
+    obj = model_validate(JsonSchemaObject, {"$ref": "https://example.org/schema.yaml#/definitions/User"})
     mock_get = mocker.patch("httpx.get")
     mock_get.return_value.text = yaml.safe_dump(json.load((DATA_PATH / "user.json").open()))
 
@@ -115,6 +117,7 @@ class Pet(BaseModel):
         verify=True,
         follow_redirects=True,
         params=None,
+        timeout=30.0,
     )
 
 
@@ -122,13 +125,16 @@ def test_json_schema_object_cached_ref_url_yaml(mocker: MockerFixture) -> None:
     """Test JSON schema object cached reference with YAML URL."""
     parser = JsonSchemaParser("")
 
-    obj = JsonSchemaObject.parse_obj({
-        "type": "object",
-        "properties": {
-            "pet": {"$ref": "https://example.org/schema.yaml#/definitions/Pet"},
-            "user": {"$ref": "https://example.org/schema.yaml#/definitions/User"},
+    obj = model_validate(
+        JsonSchemaObject,
+        {
+            "type": "object",
+            "properties": {
+                "pet": {"$ref": "https://example.org/schema.yaml#/definitions/Pet"},
+                "user": {"$ref": "https://example.org/schema.yaml#/definitions/User"},
+            },
         },
-    })
+    )
     mock_get = mocker.patch("httpx.get")
     mock_get.return_value.text = yaml.safe_dump(json.load((DATA_PATH / "user.json").open()))
 
@@ -149,6 +155,7 @@ class User(BaseModel):
         verify=True,
         follow_redirects=True,
         params=None,
+        timeout=30.0,
     )
 
 
@@ -183,6 +190,7 @@ class Pet(BaseModel):
         verify=True,
         follow_redirects=True,
         params=None,
+        timeout=30.0,
     )
 
 
@@ -256,7 +264,7 @@ def test_parse_object(source_obj: dict[str, Any], generated_classes: str) -> Non
         data_model_field_type=DataModelFieldBase,
         source="",
     )
-    parser.parse_object("Person", JsonSchemaObject.parse_obj(source_obj), [])
+    parser.parse_object("Person", model_validate(JsonSchemaObject, source_obj), [])
     assert dump_templates(list(parser.results)) == generated_classes
 
 
@@ -279,7 +287,7 @@ def test_parse_object(source_obj: dict[str, Any], generated_classes: str) -> Non
 def test_parse_any_root_object(source_obj: dict[str, Any], generated_classes: str) -> None:
     """Test parsing any root object."""
     parser = JsonSchemaParser("")
-    parser.parse_root_type("AnyObject", JsonSchemaObject.parse_obj(source_obj), [])
+    parser.parse_root_type("AnyObject", model_validate(JsonSchemaObject, source_obj), [])
     assert dump_templates(list(parser.results)) == generated_classes
 
 
@@ -406,6 +414,7 @@ def test_parse_nested_array(tmp_path: Path, monkeypatch: pytest.MonkeyPatch) ->
         ("string", "uuid3", "UUID3", "pydantic", "UUID3", False),
         ("string", "uuid4", "UUID4", "pydantic", "UUID4", False),
         ("string", "uuid5", "UUID5", "pydantic", "UUID5", False),
+        ("string", "ulid", "ULID", "ulid", "ULID", False),
         ("string", "ipv4", "IPv4Address", "ipaddress", "IPv4Address", False),
         ("string", "ipv6", "IPv6Address", "ipaddress", "IPv6Address", False),
         ("string", "unknown-type", "str", None, None, False),
@@ -426,9 +435,8 @@ def test_get_data_type(
         import_ = None
 
     parser = JsonSchemaParser("", use_pendulum=use_pendulum)
-    assert (
-        parser.get_data_type(JsonSchemaObject(type=schema_type, format=schema_format)).dict()
-        == DataType(type=result_type, import_=import_).dict()
+    assert model_dump(parser.get_data_type(JsonSchemaObject(type=schema_type, format=schema_format))) == model_dump(
+        DataType(type=result_type, import_=import_)
     )
 
 
@@ -468,6 +476,24 @@ def test_no_additional_imports() -> None:
     assert len(new_parser.imports) == 0
 
 
+def test_class_decorators() -> None:
+    """Test that class decorators are stored in parser."""
+    new_parser = JsonSchemaParser(source="", class_decorators=["@dataclass_json"])
+    assert new_parser.class_decorators == ["@dataclass_json"]
+
+
+def test_class_decorators_multiple() -> None:
+    """Test that multiple class decorators are stored in parser."""
+    new_parser = JsonSchemaParser(source="", class_decorators=["@dataclass_json", "@my_decorator"])
+    assert new_parser.class_decorators == ["@dataclass_json", "@my_decorator"]
+
+
+def test_no_class_decorators() -> None:
+    """Test that no class decorators results in empty list."""
+    new_parser = JsonSchemaParser(source="")
+    assert new_parser.class_decorators == []
+
+
 @pytest.mark.parametrize(
     ("source_obj", "generated_classes"),
     [
@@ -528,7 +554,7 @@ def test_json_schema_parser_extension(source_obj: dict[str, Any], generated_clas
         data_model_field_type=DataModelFieldBase,
         source="",
     )
-    parser.parse_object("Person", AltJsonSchemaObject.parse_obj(source_obj), [])
+    parser.parse_object("Person", model_validate(AltJsonSchemaObject, source_obj), [])
     assert dump_templates(list(parser.results)) == generated_classes
 
 
@@ -816,7 +842,7 @@ def test_get_ref_body_from_url_file_unc_path(mocker: MockerFixture) -> None:
     """Test _get_ref_body_from_url handles UNC file:// URLs correctly."""
     parser = JsonSchemaParser("")
     mock_load = mocker.patch(
-        "datamodel_code_generator.parser.jsonschema.load_yaml_dict_from_path",
+        "datamodel_code_generator.parser.jsonschema.load_data_from_path",
         return_value={"type": "object"},
     )
 
@@ -837,7 +863,7 @@ def test_get_ref_body_from_url_file_local_path(mocker: MockerFixture) -> None:
     """Test _get_ref_body_from_url handles local file:// URLs (no netloc)."""
     parser = JsonSchemaParser("")
     mock_load = mocker.patch(
-        "datamodel_code_generator.parser.jsonschema.load_yaml_dict_from_path",
+        "datamodel_code_generator.parser.jsonschema.load_data_from_path",
         return_value={"type": "string"},
     )
 
@@ -852,7 +878,7 @@ def test_get_ref_body_from_url_file_local_path(mocker: MockerFixture) -> None:
 def test_merge_ref_with_schema_no_ref() -> None:
     """Test _merge_ref_with_schema returns object unchanged when no $ref is present."""
     parser = JsonSchemaParser("")
-    obj = JsonSchemaObject.parse_obj({"type": "string", "minLength": 5})
+    obj = model_validate(JsonSchemaObject, {"type": "string", "minLength": 5})
     result = parser._merge_ref_with_schema(obj)
     assert result is obj
 
@@ -860,10 +886,13 @@ def test_merge_ref_with_schema_no_ref() -> None:
 def test_has_ref_with_schema_keywords_extras_with_schema_affecting_keys() -> None:
     """Test has_ref_with_schema_keywords when extras contains schema-affecting keys."""
     # const is stored in extras and is schema-affecting
-    obj = JsonSchemaObject.parse_obj({
-        "$ref": "#/$defs/Base",
-        "const": "active",
-    })
+    obj = model_validate(
+        JsonSchemaObject,
+        {
+            "$ref": "#/$defs/Base",
+            "const": "active",
+        },
+    )
     # Verify extras contains schema-affecting key
     assert obj.extras
     assert "const" in obj.extras
@@ -873,23 +902,54 @@ def test_has_ref_with_schema_keywords_extras_with_schema_affecting_keys() -> Non
 def test_has_ref_with_schema_keywords_extras_with_metadata_only_keys() -> None:
     """Test has_ref_with_schema_keywords when extras contains only metadata keys."""
     # $comment is metadata-only, should not trigger merge
-    obj = JsonSchemaObject.parse_obj({
-        "$ref": "#/$defs/Base",
-        "$comment": "this is a comment",
-    })
+    obj = model_validate(
+        JsonSchemaObject,
+        {
+            "$ref": "#/$defs/Base",
+            "$comment": "this is a comment",
+        },
+    )
     # Verify extras contains only metadata key
     assert obj.extras
     assert "$comment" in obj.extras
     assert obj.has_ref_with_schema_keywords is False
 
 
+def test_has_ref_with_schema_keywords_extras_with_extension_keys() -> None:
+    """Test has_ref_with_schema_keywords when extras contains only x-* extension keys.
+
+    OpenAPI/JSON Schema extension fields (x-*) should be treated as metadata
+    and not trigger schema merging, which prevents infinite recursion with
+    self-referencing schemas.
+    """
+    # x-* extensions are vendor extensions, should not trigger merge
+    obj = model_validate(
+        JsonSchemaObject,
+        {
+            "$ref": "#/$defs/Base",
+            "deprecated": False,  # metadata-only field
+            "x-internalAPI": False,  # extension field
+            "x-custom-field": "value",  # another extension field
+        },
+    )
+    # Verify extras contains extension keys
+    assert obj.extras
+    assert "x-internalAPI" in obj.extras
+    assert "x-custom-field" in obj.extras
+    # Extension fields should NOT trigger schema merge
+    assert obj.has_ref_with_schema_keywords is False
+
+
 def test_has_ref_with_schema_keywords_no_extras() -> None:
     """Test has_ref_with_schema_keywords when extras is empty."""
     # Only $ref and a schema-affecting field, no extras
-    obj = JsonSchemaObject.parse_obj({
-        "$ref": "#/$defs/Base",
-        "minLength": 10,
-    })
+    obj = model_validate(
+        JsonSchemaObject,
+        {
+            "$ref": "#/$defs/Base",
+            "minLength": 10,
+        },
+    )
     # Verify extras is empty but minLength triggers merge
     assert not obj.extras
     assert obj.has_ref_with_schema_keywords is True
@@ -929,7 +989,7 @@ def test_parse_combined_schema_anyof_with_ref_and_schema_keywords() -> None:
 def test_parse_enum_empty_enum_not_nullable() -> None:
     """Test parse_enum returns null type when enum_fields is empty and not nullable."""
     parser = JsonSchemaParser("")
-    obj = JsonSchemaObject.parse_obj({"type": "integer", "enum": []})
+    obj = model_validate(JsonSchemaObject, {"type": "integer", "enum": []})
     result = parser.parse_enum("EmptyEnum", obj, ["EmptyEnum"])
     assert result.type == "None"
 
@@ -952,14 +1012,14 @@ def test_parse_enum_empty_enum_not_nullable() -> None:
 def test_is_root_model_schema(schema: dict[str, Any], expected: bool) -> None:
     """Test _is_root_model_schema returns correct value for various schema types."""
     parser = JsonSchemaParser("")
-    obj = JsonSchemaObject.parse_obj(schema)
+    obj = model_validate(JsonSchemaObject, schema)
     assert parser._is_root_model_schema(obj) is expected
 
 
 def test_merge_primitive_schemas_for_allof_single_item() -> None:
     """Test _merge_primitive_schemas_for_allof returns unchanged item when single."""
     parser = JsonSchemaParser("")
-    item = JsonSchemaObject.parse_obj({"type": "string", "minLength": 1})
+    item = model_validate(JsonSchemaObject, {"type": "string", "minLength": 1})
     result = parser._merge_primitive_schemas_for_allof([item])
     assert result == item
 
@@ -969,8 +1029,8 @@ def test_merge_primitive_schemas_for_allof_nomerge_mode() -> None:
     parser = JsonSchemaParser("")
     parser.allof_merge_mode = AllOfMergeMode.NoMerge
     items = [
-        JsonSchemaObject.parse_obj({"type": "string", "pattern": "^a.*"}),
-        JsonSchemaObject.parse_obj({"minLength": 5}),
+        model_validate(JsonSchemaObject, {"type": "string", "pattern": "^a.*"}),
+        model_validate(JsonSchemaObject, {"minLength": 5}),
     ]
     result = parser._merge_primitive_schemas_for_allof(items)
     assert result.pattern == "^a.*"
@@ -982,8 +1042,8 @@ def test_merge_primitive_schemas_for_allof_nomerge_mode_with_format() -> None:
     parser = JsonSchemaParser("")
     parser.allof_merge_mode = AllOfMergeMode.NoMerge
     items = [
-        JsonSchemaObject.parse_obj({"type": "string"}),
-        JsonSchemaObject.parse_obj({"format": "email"}),
+        model_validate(JsonSchemaObject, {"type": "string"}),
+        model_validate(JsonSchemaObject, {"format": "email"}),
     ]
     result = parser._merge_primitive_schemas_for_allof(items)
     assert result.format == "email"
@@ -994,8 +1054,8 @@ def test_merge_primitive_schemas_for_allof_constraints_mode_with_format() -> Non
     parser = JsonSchemaParser("")
     parser.allof_merge_mode = AllOfMergeMode.Constraints
     items = [
-        JsonSchemaObject.parse_obj({"type": "string", "pattern": "^a.*"}),
-        JsonSchemaObject.parse_obj({"format": "email"}),
+        model_validate(JsonSchemaObject, {"type": "string", "pattern": "^a.*"}),
+        model_validate(JsonSchemaObject, {"format": "email"}),
     ]
     result = parser._merge_primitive_schemas_for_allof(items)
     assert result.format == "email"
@@ -1004,12 +1064,15 @@ def test_merge_primitive_schemas_for_allof_constraints_mode_with_format() -> Non
 def test_handle_allof_root_model_special_path_marker() -> None:
     """Test _handle_allof_root_model_with_constraints returns None for special path."""
     parser = JsonSchemaParser("")
-    obj = JsonSchemaObject.parse_obj({
-        "allOf": [
-            {"$ref": "#/definitions/Base"},
-            {"minLength": 1},
-        ]
-    })
+    obj = model_validate(
+        JsonSchemaObject,
+        {
+            "allOf": [
+                {"$ref": "#/definitions/Base"},
+                {"minLength": 1},
+            ]
+        },
+    )
     path = [f"test{SPECIAL_PATH_MARKER}inline"]
     result = parser._handle_allof_root_model_with_constraints("Test", obj, path)
     assert result is None
@@ -1018,12 +1081,15 @@ def test_handle_allof_root_model_special_path_marker() -> None:
 def test_handle_allof_root_model_multiple_refs() -> None:
     """Test _handle_allof_root_model_with_constraints returns None for multiple refs."""
     parser = JsonSchemaParser("")
-    obj = JsonSchemaObject.parse_obj({
-        "allOf": [
-            {"$ref": "#/definitions/Base1"},
-            {"$ref": "#/definitions/Base2"},
-        ]
-    })
+    obj = model_validate(
+        JsonSchemaObject,
+        {
+            "allOf": [
+                {"$ref": "#/definitions/Base1"},
+                {"$ref": "#/definitions/Base2"},
+            ]
+        },
+    )
     result = parser._handle_allof_root_model_with_constraints("Test", obj, ["test"])
     assert result is None
 
@@ -1031,12 +1097,15 @@ def test_handle_allof_root_model_multiple_refs() -> None:
 def test_handle_allof_root_model_no_refs() -> None:
     """Test _handle_allof_root_model_with_constraints returns None when no refs."""
     parser = JsonSchemaParser("")
-    obj = JsonSchemaObject.parse_obj({
-        "allOf": [
-            {"type": "string"},
-            {"minLength": 1},
-        ]
-    })
+    obj = model_validate(
+        JsonSchemaObject,
+        {
+            "allOf": [
+                {"type": "string"},
+                {"minLength": 1},
+            ]
+        },
+    )
     result = parser._handle_allof_root_model_with_constraints("Test", obj, ["test"])
     assert result is None
 
@@ -1044,12 +1113,15 @@ def test_handle_allof_root_model_no_refs() -> None:
 def test_handle_allof_root_model_no_constraint_items() -> None:
     """Test _handle_allof_root_model_with_constraints returns None when no constraints."""
     parser = JsonSchemaParser("")
-    parser._load_ref_schema_object = lambda _ref: JsonSchemaObject.parse_obj({"type": "string"})
-    obj = JsonSchemaObject.parse_obj({
-        "allOf": [
-            {"$ref": "#/definitions/Base"},
-        ]
-    })
+    parser._load_ref_schema_object = lambda _ref: model_validate(JsonSchemaObject, {"type": "string"})
+    obj = model_validate(
+        JsonSchemaObject,
+        {
+            "allOf": [
+                {"$ref": "#/definitions/Base"},
+            ]
+        },
+    )
     result = parser._handle_allof_root_model_with_constraints("Test", obj, ["test"])
     assert result is None
 
@@ -1057,13 +1129,16 @@ def test_handle_allof_root_model_no_constraint_items() -> None:
 def test_handle_allof_root_model_constraint_with_properties() -> None:
     """Test _handle_allof_root_model_with_constraints returns None when constraint has properties."""
     parser = JsonSchemaParser("")
-    parser._load_ref_schema_object = lambda _ref: JsonSchemaObject.parse_obj({"type": "string"})
-    obj = JsonSchemaObject.parse_obj({
-        "allOf": [
-            {"$ref": "#/definitions/Base"},
-            {"properties": {"name": {"type": "string"}}},
-        ]
-    })
+    parser._load_ref_schema_object = lambda _ref: model_validate(JsonSchemaObject, {"type": "string"})
+    obj = model_validate(
+        JsonSchemaObject,
+        {
+            "allOf": [
+                {"$ref": "#/definitions/Base"},
+                {"properties": {"name": {"type": "string"}}},
+            ]
+        },
+    )
     result = parser._handle_allof_root_model_with_constraints("Test", obj, ["test"])
     assert result is None
 
@@ -1071,13 +1146,16 @@ def test_handle_allof_root_model_constraint_with_properties() -> None:
 def test_handle_allof_root_model_constraint_with_items() -> None:
     """Test _handle_allof_root_model_with_constraints returns None when constraint has items."""
     parser = JsonSchemaParser("")
-    parser._load_ref_schema_object = lambda _ref: JsonSchemaObject.parse_obj({"type": "string"})
-    obj = JsonSchemaObject.parse_obj({
-        "allOf": [
-            {"$ref": "#/definitions/Base"},
-            {"items": {"type": "string"}},
-        ]
-    })
+    parser._load_ref_schema_object = lambda _ref: model_validate(JsonSchemaObject, {"type": "string"})
+    obj = model_validate(
+        JsonSchemaObject,
+        {
+            "allOf": [
+                {"$ref": "#/definitions/Base"},
+                {"items": {"type": "string"}},
+            ]
+        },
+    )
     result = parser._handle_allof_root_model_with_constraints("Test", obj, ["test"])
     assert result is None
 
@@ -1085,13 +1163,16 @@ def test_handle_allof_root_model_constraint_with_items() -> None:
 def test_handle_allof_root_model_incompatible_types() -> None:
     """Test _handle_allof_root_model_with_constraints returns None for incompatible types."""
     parser = JsonSchemaParser("")
-    parser._load_ref_schema_object = lambda _ref: JsonSchemaObject.parse_obj({"type": "string"})
-    obj = JsonSchemaObject.parse_obj({
-        "allOf": [
-            {"$ref": "#/definitions/Base"},
-            {"type": "boolean"},
-        ]
-    })
+    parser._load_ref_schema_object = lambda _ref: model_validate(JsonSchemaObject, {"type": "string"})
+    obj = model_validate(
+        JsonSchemaObject,
+        {
+            "allOf": [
+                {"$ref": "#/definitions/Base"},
+                {"type": "boolean"},
+            ]
+        },
+    )
     result = parser._handle_allof_root_model_with_constraints("Test", obj, ["test"])
     assert result is None
 
@@ -1099,15 +1180,133 @@ def test_handle_allof_root_model_incompatible_types() -> None:
 def test_handle_allof_root_model_ref_to_non_root() -> None:
     """Test _handle_allof_root_model_with_constraints returns None when ref is not root model."""
     parser = JsonSchemaParser("")
-    parser._load_ref_schema_object = lambda _ref: JsonSchemaObject.parse_obj({
-        "type": "object",
-        "properties": {"id": {"type": "integer"}},
-    })
-    obj = JsonSchemaObject.parse_obj({
-        "allOf": [
-            {"$ref": "#/definitions/Base"},
-            {"minLength": 1},
-        ]
-    })
+    parser._load_ref_schema_object = lambda _ref: model_validate(
+        JsonSchemaObject,
+        {
+            "type": "object",
+            "properties": {"id": {"type": "integer"}},
+        },
+    )
+    obj = model_validate(
+        JsonSchemaObject,
+        {
+            "allOf": [
+                {"$ref": "#/definitions/Base"},
+                {"minLength": 1},
+            ]
+        },
+    )
     result = parser._handle_allof_root_model_with_constraints("Test", obj, ["test"])
     assert result is None
+
+
+def test_timestamp_with_time_zone_format() -> None:
+    """Test that PostgreSQL timestamp with time zone format maps to datetime."""
+    from datamodel_code_generator.parser.jsonschema import json_schema_data_formats
+
+    # Verify the format is mapped correctly
+    assert json_schema_data_formats["string"]["timestamp with time zone"] == Types.date_time
+
+
+@pytest.mark.parametrize(
+    ("x_python_type", "expected"),
+    [
+        # Direct matches for special container types
+        ("Set[str]", {"is_set": True}),
+        ("set[int]", {"is_set": True}),
+        ("FrozenSet[int]", {"is_frozen_set": True}),
+        ("frozenset[str]", {"is_frozen_set": True}),
+        ("Sequence[str]", {"is_sequence": True}),
+        ("MutableSequence[int]", {"is_sequence": True}),
+        ("Mapping[str, int]", {"is_mapping": True}),
+        ("MutableMapping[str, int]", {"is_mapping": True}),
+        ("AbstractSet[str]", {"is_frozen_set": True}),
+        ("MutableSet[int]", {"is_set": True}),
+        # Union with special container type
+        ("Union[Set[str], None]", {"is_set": True}),
+        ("Optional[FrozenSet[int]]", {"is_frozen_set": True}),
+        ("Set[int] | None", {"is_set": True}),
+        ("Sequence[str] | int", {"is_sequence": True}),
+        # Union without special container type (loop completes without match)
+        ("Union[str, int]", {}),
+        ("str | int", {}),
+        ("Optional[str]", {}),
+        ("Union[str, int, float]", {}),
+        ("Union[List[str], None]", {}),  # List is not a special container
+        ("Optional[Dict[str, int]]", {}),  # Dict is not a special container
+        # Non-special container types
+        ("List[str]", {}),
+        ("Dict[str, int]", {}),
+        ("str", {}),
+        ("int", {}),
+        ("CustomType", {}),
+    ],
+)
+def test_get_python_type_flags(x_python_type: str, expected: dict[str, bool]) -> None:
+    """Test _get_python_type_flags extracts collection flags correctly."""
+    parser = JsonSchemaParser("")
+    obj = model_validate(JsonSchemaObject, {"x-python-type": x_python_type})
+    result = parser._get_python_type_flags(obj)
+    assert result == expected
+
+
+def test_resolve_type_import_from_defs() -> None:
+    """Test _resolve_type_import_from_defs resolves imports from $defs with x-python-import."""
+    schema_dict: dict[str, Any] = {
+        "type": "object",
+        "properties": {"status": {"$ref": "#/$defs/Status"}},
+        "$defs": {
+            "Status": {
+                "type": "string",
+                "enum": ["active", "inactive"],
+                "x-python-import": {"module": "myapp.enums", "name": "Status"},
+            }
+        },
+    }
+    parser = JsonSchemaParser(json.dumps(schema_dict))
+    parser.raw_obj = schema_dict  # Set raw_obj for _load_ref_schema_object to work
+
+    # Call _resolve_type_import_from_defs directly
+    result = parser._resolve_type_import_from_defs("Status")
+    assert result is not None
+    assert result.from_ == "myapp.enums"
+    assert result.import_ == "Status"
+
+
+def test_resolve_type_import_from_defs_not_found() -> None:
+    """Test _resolve_type_import_from_defs returns None when type not in $defs."""
+    schema_dict: dict[str, Any] = {"type": "object", "properties": {"name": {"type": "string"}}}
+    parser = JsonSchemaParser(json.dumps(schema_dict))
+    parser.raw_obj = schema_dict
+
+    result = parser._resolve_type_import_from_defs("NonExistentType")
+    assert result is None
+
+
+def test_resolve_type_import_from_defs_no_x_python_import() -> None:
+    """Test _resolve_type_import_from_defs returns None when $defs entry has no x-python-import."""
+    schema_dict: dict[str, Any] = {
+        "type": "object",
+        "properties": {"status": {"$ref": "#/$defs/Status"}},
+        "$defs": {"Status": {"type": "string", "enum": ["active", "inactive"]}},
+    }
+    parser = JsonSchemaParser(json.dumps(schema_dict))
+    parser.raw_obj = schema_dict
+
+    result = parser._resolve_type_import_from_defs("Status")
+    assert result is None
+
+
+def test_resolve_type_import_from_defs_exception_handling() -> None:
+    """Test _resolve_type_import_from_defs handles exceptions gracefully.
+
+    When raw_obj is None or invalid, _load_ref_schema_object will raise an exception,
+    and _resolve_type_import_from_defs should catch it and return None.
+    """
+    schema_dict: dict[str, Any] = {"type": "object", "properties": {"name": {"type": "string"}}}
+    parser = JsonSchemaParser(json.dumps(schema_dict))
+    # Set raw_obj to None to trigger exception in _load_ref_schema_object
+    parser.raw_obj = None  # pyright: ignore[reportAttributeAccessIssue]
+
+    result = parser._resolve_type_import_from_defs("SomeType")
+    assert result is None
