@@ -24,6 +24,7 @@ from datamodel_code_generator.parser.openapi import (
     RequestBodyObject,
     ResponseObject,
 )
+from datamodel_code_generator.util import model_dump, model_validate
 from tests.conftest import assert_output, assert_parser_modules, assert_parser_results
 
 DATA_PATH: Path = Path(__file__).parents[1] / "data" / "openapi"
@@ -138,7 +139,7 @@ class Pets(BaseModel):
 def test_parse_object(source_obj: dict[str, Any], generated_classes: str) -> None:
     """Test parsing OpenAPI object schemas."""
     parser = OpenAPIParser("")
-    parser.parse_object("Pets", JsonSchemaObject.parse_obj(source_obj), [])
+    parser.parse_object("Pets", model_validate(JsonSchemaObject, source_obj), [])
     assert dump_templates(list(parser.results)) == generated_classes
 
 
@@ -182,7 +183,7 @@ class Pets(BaseModel):
 def test_parse_array(source_obj: dict[str, Any], generated_classes: str) -> None:
     """Test parsing OpenAPI array schemas."""
     parser = OpenAPIParser("")
-    parser.parse_array("Pets", JsonSchemaObject.parse_obj(source_obj), [])
+    parser.parse_array("Pets", model_validate(JsonSchemaObject, source_obj), [])
     assert dump_templates(list(parser.results)) == generated_classes
 
 
@@ -236,7 +237,7 @@ def test_openapi_parser_parse(with_import: bool, format_: bool, base_class: str
 def test_parse_root_type(source_obj: dict[str, Any], generated_classes: str) -> None:
     """Test parsing OpenAPI root type schemas."""
     parser = OpenAPIParser("")
-    parser.parse_root_type("Name", JsonSchemaObject.parse_obj(source_obj), [])
+    parser.parse_root_type("Name", model_validate(JsonSchemaObject, source_obj), [])
     assert dump_templates(list(parser.results)) == generated_classes
 
 
@@ -524,9 +525,42 @@ def test_openapi_parser_parse_array_enum(tmp_path: Path, monkeypatch: pytest.Mon
     assert_output(parser.parse(), expected_file)
 
 
-def test_openapi_parser_parse_remote_ref(tmp_path: Path, monkeypatch: pytest.MonkeyPatch) -> None:
+def test_openapi_parser_parse_remote_ref(tmp_path: Path, monkeypatch: pytest.MonkeyPatch, mocker: Any) -> None:
     """Test parsing OpenAPI with remote references."""
     monkeypatch.chdir(tmp_path)
+
+    remote_schema = """
+schemas:
+  Problem:
+    properties:
+      detail:
+        description: A human readable explanation specific to this occurrence of the problem.
+        type: string
+      instance:
+        description: An absolute URI that identifies the specific occurrence of the problem.
+        format: uri
+        type: string
+      status:
+        description: The HTTP status code generated by the origin server for this occurrence of the problem.
+        exclusiveMaximum: true
+        format: int32
+        maximum: 600
+        minimum: 100
+        type: integer
+      title:
+        description: A short, summary of the problem type.
+        type: string
+      type:
+        default: about:blank
+        description: An absolute URI that identifies the problem type.
+        format: uri
+        type: string
+    type: object
+"""
+    mock_response = mocker.Mock()
+    mock_response.text = remote_schema
+    mocker.patch("httpx.get", return_value=mock_response)
+
     parser = OpenAPIParser(
         data_model_field_type=DataModelFieldBase,
         source=(DATA_PATH / "refs.yaml").read_text(),
@@ -551,9 +585,7 @@ def test_openapi_model_resolver(tmp_path: Path, monkeypatch: pytest.MonkeyPatch)
     parser.parse()
 
     references = {
-        k: v.dict(
-            exclude={"source", "module_name", "actual_module_name"},
-        )
+        k: model_dump(v, exclude={"source", "module_name", "actual_module_name", "children"})
         for k, v in parser.model_resolver.references.items()
     }
     assert references == {
@@ -713,8 +745,8 @@ def test_parse_all_parameters_duplicate_names_exception() -> None:
     """Test parsing parameters with duplicate names raises exception."""
     parser = OpenAPIParser("", include_path_parameters=True)
     parameters = [
-        ParameterObject.parse_obj({"name": "duplicate_param", "in": "path", "schema": {"type": "string"}}),
-        ParameterObject.parse_obj({"name": "duplicate_param", "in": "query", "schema": {"type": "integer"}}),
+        model_validate(ParameterObject, {"name": "duplicate_param", "in": "path", "schema": {"type": "string"}}),
+        model_validate(ParameterObject, {"name": "duplicate_param", "in": "query", "schema": {"type": "integer"}}),
     ]
 
     with pytest.raises(Exception) as exc_info:  # noqa: PT011
@@ -799,7 +831,8 @@ def test_parse_request_body_return(request_body_data: dict[str, Any], expected_t
         "TestRequest",
         RequestBodyObject(
             content={
-                media_type: MediaObject.parse_obj(media_data) for media_type, media_data in request_body_data.items()
+                media_type: model_validate(MediaObject, media_data)
+                for media_type, media_data in request_body_data.items()
             }
         ),
         ["test", "path"],
@@ -837,7 +870,7 @@ def test_parse_all_parameters_return(parameters_data: list[dict[str, Any]], expe
     )
     result = parser.parse_all_parameters(
         "TestParametersQuery",
-        [ParameterObject.parse_obj(param_data) for param_data in parameters_data],
+        [model_validate(ParameterObject, param_data) for param_data in parameters_data],
         ["test", "path"],
     )
     if expected_type_hint is None:
@@ -901,7 +934,10 @@ def test_parse_responses_return(
 
     result = parser.parse_responses(
         "TestResponse",
-        {status_code: ResponseObject.parse_obj(response_data) for status_code, response_data in responses_data.items()},
+        {
+            status_code: model_validate(ResponseObject, response_data)
+            for status_code, response_data in responses_data.items()
+        },
         ["test", "path"],
     )
 
@@ -913,3 +949,91 @@ def test_parse_responses_return(
         for content_type, expected_type_hint in expected_content_types.items():
             assert content_type in result[status_code]
             assert result[status_code][content_type].type_hint == expected_type_hint
+
+
+def test_parse_all_parameters_strict_nullable() -> None:
+    """Test that strict_nullable exposes nullable for optional parameters without default."""
+    parser = OpenAPIParser(
+        data_model_field_type=DataModelField,
+        source="",
+        openapi_scopes=[OpenAPIScope.Parameters],
+        strict_nullable=True,
+    )
+    parameters_data = [
+        {"name": "nullable_param", "in": "query", "required": False, "schema": {"type": "string", "nullable": True}},
+        {
+            "name": "non_nullable_param",
+            "in": "query",
+            "required": False,
+            "schema": {"type": "string", "nullable": False},
+        },
+    ]
+    result = parser.parse_all_parameters(
+        "TestParametersQuery",
+        [model_validate(ParameterObject, param_data) for param_data in parameters_data],
+        ["test", "path"],
+    )
+    assert result is not None
+    fields = parser.results[0].fields
+    assert len(fields) == 2
+    assert fields[0].nullable is True
+    assert fields[1].nullable is False
+
+
+def test_openapi_parser_with_request_bodies_scope() -> None:
+    """Test parsing OpenAPI with requestBodies scope generates models from components/requestBodies."""
+    parser = OpenAPIParser(
+        data_model_field_type=DataModelFieldBase,
+        source=Path(DATA_PATH / "request_bodies_scope.yaml"),
+        openapi_scopes=[OpenAPIScope.RequestBodies],
+    )
+    result = parser.parse()
+    assert "CreatePet" in result
+    assert "name: Optional[str]" in result
+    assert "age: Optional[int]" in result
+
+
+def test_openapi_parser_with_request_bodies_scope_ref() -> None:
+    """Test parsing OpenAPI with requestBodies scope handles $ref in schema."""
+    parser = OpenAPIParser(
+        data_model_field_type=DataModelFieldBase,
+        source=Path(DATA_PATH / "request_bodies_scope.yaml"),
+        openapi_scopes=[OpenAPIScope.RequestBodies, OpenAPIScope.Schemas],
+    )
+    result = parser.parse()
+    assert "UpdatePet" in result
+    assert "PetUpdate" in result
+
+
+def test_openapi_parser_with_request_bodies_scope_empty() -> None:
+    """Test parsing OpenAPI with requestBodies scope when requestBodies is empty."""
+    parser = OpenAPIParser(
+        data_model_field_type=DataModelFieldBase,
+        source=Path(DATA_PATH / "request_bodies_scope_empty.yaml"),
+        openapi_scopes=[OpenAPIScope.RequestBodies],
+    )
+    result = parser.parse()
+    assert result in ({}, "")
+
+
+def test_openapi_parser_with_request_bodies_scope_no_schema() -> None:
+    """Test parsing OpenAPI with requestBodies scope skips content without schema."""
+    parser = OpenAPIParser(
+        data_model_field_type=DataModelFieldBase,
+        source=Path(DATA_PATH / "request_bodies_scope.yaml"),
+        openapi_scopes=[OpenAPIScope.RequestBodies],
+    )
+    result = parser.parse()
+    assert "EmptyContent" not in result
+
+
+def test_openapi_parser_with_request_bodies_scope_body_ref() -> None:
+    """Test parsing OpenAPI with requestBodies scope handles $ref at requestBody level."""
+    parser = OpenAPIParser(
+        data_model_field_type=DataModelFieldBase,
+        source=Path(DATA_PATH / "request_bodies_scope_with_ref.yaml"),
+        openapi_scopes=[OpenAPIScope.RequestBodies],
+    )
+    result = parser.parse()
+    assert "CreatePet" in result or "BasePet" in result
+    assert "name: Optional[str]" in result
